#include <linux/init.h>
#include <linux/kernel.h>
#include <linux/module.h>

#include <kisan/kisan_common.h>

#include <net/sock.h>                        // UDP, netlink
#include <linux/kmod.h>                      // call_usermodehelper

#include <linux/miscdevice.h>				// miscdevice


//unsigned char g_aucDbgPrint[2048];
//EXPORT_SYMBOL(g_aucDbgPrint);

structKernelVersion g_stKernVer;



// 16Ʈ  2 ڿ ȯ
char *U16ToS8(unsigned short usVal)
{
    static char cStr[16 + 1] = {'0', };
    int count = 16;

    do { cStr[--count] = '0' + (char) (usVal & 1);
        usVal = usVal >> 1;
    } while (count);

    return cStr;
}
EXPORT_SYMBOL(U16ToS8);


void BitsDisplay(int nVal, int nBitLen)
{
    int i = 0;
    nBitLen--;

    for(i=nBitLen ; i >=0 ; i--)
        printk(" %2d", i);
    printk("\n");

    for (i=nBitLen; i>=0; i--)
        printk(" %2d", BIT_CHECK(nVal, i)? 1:0);
    printk("\n");
}
EXPORT_SYMBOL(BitsDisplay);


int ksocket_send(struct socket *sock, struct sockaddr_in *addr, unsigned char *buf, int len)
{
    struct msghdr msg;
    struct iovec iov;
    mm_segment_t oldfs;
    int size = 0;

    if (sock->sk == NULL)
       return 0;

    iov.iov_base = buf;
    iov.iov_len = len;

    msg.msg_flags = 0;
    msg.msg_name = addr;
    msg.msg_namelen  = sizeof(struct sockaddr_in);
    msg.msg_control = NULL;
    msg.msg_controllen = 0;
//#if LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
//	msg.msg_iov = &iov;
//	msg.msg_iovlen = 1;
//#else
	iov_iter_init(&msg.msg_iter, READ, &iov, 1, len);
//#endif
    msg.msg_control = NULL;

    oldfs = get_fs();
    set_fs(KERNEL_DS);
//#if LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
//    size = sock_sendmsg(sock, &msg, len);
//#else
	size = sock_sendmsg(sock, &msg);
//#endif
    set_fs(oldfs);

    return size;
}
EXPORT_SYMBOL(ksocket_send);


int ksocket_receive(struct socket* sock, struct sockaddr_in* addr, unsigned char* buf, int len)
{
    struct msghdr msg;
    struct iovec iov;
    mm_segment_t oldfs;
    int size = 0;

    if (sock->sk == NULL)
        return 0;

    iov.iov_base = buf;
    iov.iov_len = len;

    msg.msg_flags = 0;
    msg.msg_name = addr;
    msg.msg_namelen  = sizeof(struct sockaddr_in);
    msg.msg_control = NULL;
    msg.msg_controllen = 0;
//#if LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
//	msg.msg_iov = &iov;
//	msg.msg_iovlen = 1;
//#else
	iov_iter_init(&msg.msg_iter, READ, &iov, 1, len);
//#endif
    msg.msg_control = NULL;

    oldfs = get_fs();
    set_fs(KERNEL_DS);

//#if LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
//    size = sock_recvmsg(sock, &msg, len, msg.msg_flags);
//#else
    size = sock_recvmsg(sock, &msg, msg.msg_flags);
//#endif

    set_fs(oldfs);

    return size;
}
EXPORT_SYMBOL(ksocket_receive);


int SaveUdpMsgToSharedMem(unsigned char *pucBuf, int nSaveDataLen)
{
    void __iomem *iomemAddr;
    unsigned char *pucPtr;

    if(nSaveDataLen > 0x100000) { // 1 MB
        printk(KERN_ERR "[%s:%4d:%s] Over Size to DDR shared memory: (0x%08X) \n",
            __FILENAME__, __LINE__, __FUNCTION__, nSaveDataLen);
        return -1;
    }

    iomemAddr = ioremap(ADDR_DDR_SHARED_DATA_BUF, nSaveDataLen);
    if(!iomemAddr) {
        printk(KERN_ERR "[%s:%4d:%s] Failed to remap memory for iomemAddr. \n",
            __FILENAME__, __LINE__, __FUNCTION__);
        return -1;
    }
    pucPtr = (unsigned char *)iomemAddr;
    memcpy(pucPtr, pucBuf, nSaveDataLen);

    return 0;
}
EXPORT_SYMBOL(SaveUdpMsgToSharedMem);


int SendUdpMsgToUserSpace(unsigned char *pucBuf, int nSendMsgLen)
{
    struct socket *sock;
    struct sockaddr_in addr;
    int nErr = 0;

    struct msghdr msg;
    struct iovec iov;
    mm_segment_t oldfs;
    int size = 0;

    /* create a socket */
    if ( ((nErr = sock_create(AF_INET, SOCK_DGRAM, IPPROTO_UDP, &sock)) < 0) ) {
        printk(KERN_ERR "[%s:%4d:%s] Could not create a datagram socket, err(%d) \n",
            __FILENAME__, __LINE__, __FUNCTION__, -ENXIO);
        return -ENXIO;
    }

    memset(&addr, 0, sizeof(struct sockaddr));
    addr.sin_family      = AF_INET;
    addr.sin_addr.s_addr = htonl(INADDR_ANY);
    addr.sin_port        = htons(DEFAULT_UDP_PORT);


    /* send socket */
    if (sock->sk == NULL)
       return -1;

    iov.iov_base = pucBuf;
    iov.iov_len = nSendMsgLen;

    msg.msg_flags = 0;
    msg.msg_name = &addr;
    msg.msg_namelen  = sizeof(struct sockaddr_in);
    msg.msg_control = NULL;
    msg.msg_controllen = 0;
//#if LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
//	msg.msg_iov = &iov;
//	msg.msg_iovlen = 1;
//#else
	iov_iter_init(&msg.msg_iter, READ, &iov, 1, nSendMsgLen);
//#endif
    msg.msg_control = NULL;

    oldfs = get_fs();
    set_fs(KERNEL_DS);
//#if LINUX_VERSION_CODE < KERNEL_VERSION(3,19,0)
//	  size = sock_sendmsg(sock, &msg, len);
//#else
	size = sock_sendmsg(sock, &msg);
//#endif
    set_fs(oldfs);

    sock_release(sock);
    sock = NULL;

    return 0;
}
EXPORT_SYMBOL(SendUdpMsgToUserSpace);


void execute_shell_command(char* strPath, char* strCommand, char* strArgv1, char* strArgv2, char* strArgv3)
{
    char *argv[5] = { NULL, NULL, NULL, NULL, NULL };
    static char *envp[4] = { "HOME=/", "TERM=linux", "PATH=/sbin:/bin:/usr/sbin:/usr/bin", NULL };

    argv[0] = strPath;
    argv[1] = strCommand;
    argv[2] = strArgv1;
    argv[3] = strArgv2;
    argv[4] = strArgv3;

    printk(KERN_DEBUG "[%s:%4d] Execute shell command > %s, %s, %s, %s, %s \n", 
        __FILENAME__, __LINE__,  argv[0], argv[1], argv[2], argv[3], argv[4]);
    
    call_usermodehelper( argv[0], argv, envp, UMH_WAIT_EXEC );
}
EXPORT_SYMBOL(execute_shell_command);    


static int kisan_common_open(struct inode *inode, struct file *file)
{
    printk(KERN_DEBUG "[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);            
    return 0;
}


static ssize_t kisan_common_read(struct file *filp, char *buf, size_t count, loff_t *f_pos)
{
    printk(KERN_DEBUG "[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);            
    return 0;
} 


static ssize_t kisan_common_write(struct file *filp, const char __user *buf,
		size_t count, loff_t *f_pos)
{
    printk(KERN_DEBUG "[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);            
	return 0;
}


static long kisan_common_ioctl(struct file *filp, unsigned int cmd, unsigned long args)
{
    printk(KERN_DEBUG"[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);            
    return 0;
}


static struct file_operations kisan_common_fops = {
	.owner            = THIS_MODULE,
    .open             = kisan_common_open,
    .read             = kisan_common_read,
    .write            = kisan_common_write,
    .unlocked_ioctl   = kisan_common_ioctl,
};

static struct miscdevice kisan_common_dev = {
    .minor  = KISAN_COMMON_MINOR,
    .name   = "kisan_common",
    .fops   = &kisan_common_fops
};


static int __init kisan_common_init(void)
{
//    int nVal = 0x18;

    if( (misc_register(&kisan_common_dev)) ) {
        printk(KERN_ERR "[%s:%4d:%s] kisan_common misc_register failure... \n",
            __FILENAME__, __LINE__, __FUNCTION__);

        return -ENOMEM;
    }
    else {
        printk(KERN_DEBUG "[%s:%4d:%s] Register a kisan_common char driver. \n",
            __FILENAME__, __LINE__, __FUNCTION__);
    }


//    memset(&g_aucDbgPrint[0], 0x00, sizeof(g_aucDbgPrint));
//    sprintf( (char *)g_aucDbgPrint, "\n\n ================ Global Variable Test: 0x%02X ========================= \n\n", nVal);
//    printk("[Dbg][%s:%3d:%s] %s \n", __FILENAME__, __LINE__, __FUNCTION__, g_aucDbgPrint);


	return 0;
}


static void __exit kisan_common_exit(void)
{
    printk(KERN_DEBUG "[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);            
	misc_deregister(&kisan_common_dev);
}


module_init(kisan_common_init);
module_exit(kisan_common_exit);

MODULE_DESCRIPTION("AM5729 Kisan S2 B/D Common");
MODULE_AUTHOR("hong.yongje@kisane.com");
MODULE_LICENSE("Dual BSD/GPL");


