/**
@file       kisan_gpio_intr.c
@brief      AM5729 S2 B/D Character Device Driver
@details    GPIO Interrupt (/dev/kisan_gpio_intr)
@date       2020-07-10
@author     hong.yongje@kisane.com
*/

#include <linux/module.h>
#include <linux/init.h>
#include <linux/fs.h>
#include <linux/interrupt.h>
#include <linux/irq.h>
#include <linux/sched.h>
#include <linux/pm.h>
#include <linux/slab.h>
#include <linux/sysctl.h>
#include <linux/proc_fs.h>
#include <linux/delay.h>
#include <linux/platform_device.h>
#include <linux/input.h>
#include <linux/gpio_keys.h>
#include <linux/workqueue.h>
#include <linux/gpio.h>
#include <linux/kernel.h>
#include <linux/mm.h>       // mmap

#include <net/sock.h>       // netlink
#include <linux/netlink.h>       // netlink
#include <linux/skbuff.h>       // netlink

#include <asm/uaccess.h>
#include <asm/io.h> // ioremap

#include <linux/miscdevice.h>

#include <linux/netdevice.h>
#include <linux/ip.h>
#include <linux/in.h>
#include <linux/delay.h>
#include <linux/kthread.h>
#include <linux/completion.h>

#include <linux/errno.h>
#include <linux/types.h>

#include <kisan/kisan_common.h>


#define DBG_MSG_ON_KISAN_GPIO_INTR

#define RUN_MODE_GPIO_INTR_MULTI    (0)
#define RUN_MODE_GPIO_INTR_SINGLE   (1)


struct structKisanGpioIntr {
    unsigned char ucRunMode;
};

static unsigned char g_ucRunMode = RUN_MODE_GPIO_INTR_MULTI;

struct stTimer {
	int gpio_num;
	int real_num;
	int debounce_time;
	struct work_struct work;
	struct timer_list timer;
};
static struct stTimer g_astTimerWork[MAX_NUM_OF_GPIO_INTR];

static int g_anGpioNum[MAX_NUM_OF_GPIO_INTR] = {
    GPIO_INTR_DSP, GPIO_INTR_SC
};
static char *g_astrGpioNumToName[MAX_NUM_OF_GPIO_INTR] = { 
    "S2:gpio3_10:dsp1", "S2:gpio3_11:ipu2"
};
static int g_anGpioNumToIrq[MAX_NUM_OF_GPIO_INTR] = { 0 };

#define MODULE_NAME         "KISAN_GPIO_INTR"

struct socket *g_sock_kisan_gpio_intr;
struct sockaddr_in g_addr_kisan_gpio_intr;



extern int ksocket_send(struct socket *sock, struct sockaddr_in *addr, unsigned char *buf, int len);




//#if LINUX_VERSION_CODE < KERNEL_VERSION(4,15,0)
//static void gpio_intr_timer(unsigned long _data)
//#else
static void gpio_intr_timer(struct timer_list *t)
//#endif
{
//#if LINUX_VERSION_CODE < KERNEL_VERSION(4,15,0)
//	struct stTimer *te = (struct stTimer *) _data;
//#else
	struct stTimer *te = from_timer(te, t, timer);
//#endif
	schedule_work(&te->work);
}


static void gpio_intr_work_func(struct work_struct *work)
{
    void __iomem *iomemAddr;
    unsigned char *pucPtr;

	struct stTimer *tt = container_of(work, struct stTimer, work);

//    unsigned char ucUdpCmd = UDP_CMD_KISAN_APL_NOTI;
    unsigned char aucSendBuf[LENGTH_OF_DDR_SHM_DATA_KEY] = {0x00, };

    int i=0;

    aucSendBuf[0] = 0x01;             // CMD

    switch(g_ucRunMode)
    {
        case RUN_MODE_GPIO_INTR_MULTI:
            for(i=0; i<MAX_NUM_OF_GPIO_INTR; i++) {
                if(tt->gpio_num == g_anGpioNum[i])
                    break;
            }

            aucSendBuf[1] = tt->real_num;     // DATA (key)
            // Status (Push(0)/Release(1))
            if((gpio_get_value(tt->gpio_num) ? __HI__ : __LO__)) {
                aucSendBuf[2] = __HI__;
            }
            else {
                aucSendBuf[2] = __LO__;
            }
            break;

        case RUN_MODE_GPIO_INTR_SINGLE:
        default:
            // Status (Push(0)/Release(1))
            if((gpio_get_value(tt->gpio_num) ? __HI__ : __LO__)) {
                aucSendBuf[1] = __HI__;
            }
            else {
                aucSendBuf[1] = __LO__;
            }
            aucSendBuf[2] = 0x00;
            break;
    }

#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
    printk(KERN_DEBUG "[%s:%4d:%s] Send UDP(Key): [0x%02X, 0x%02X, 0x%02X] \n",
        __FILENAME__, __LINE__, __FUNCTION__, aucSendBuf[0], aucSendBuf[1], aucSendBuf[2]);
#endif  // #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

    /* sending */
//    ksocket_send(g_sock_kisan_gpio_intr, &g_addr_kisan_gpio_intr, &ucUdpCmd, 1);
    ksocket_send(g_sock_kisan_gpio_intr, &g_addr_kisan_gpio_intr, &aucSendBuf[0], LENGTH_OF_DDR_SHM_DATA_KEY);


    // Save data to Shared Buffer
    iomemAddr = ioremap(ADDR_DDR_SHARED_DATA_BUF, LENGTH_OF_DDR_SHM_DATA_KEY);
    if(!iomemAddr) {
        printk(KERN_ERR "[%s:%4d:%s] Failed to remap memory for iomemAddr. \n",
            __FILENAME__, __LINE__, __FUNCTION__);
        return;
    }
    pucPtr = (unsigned char *)iomemAddr;
    memcpy(pucPtr, aucSendBuf, LENGTH_OF_DDR_SHM_DATA_KEY);

    iounmap(iomemAddr);
}


static irqreturn_t kisan_gpio_intr_isr(int irq, void *dev_id)
{
	struct stTimer *tt = dev_id;

	mod_timer(&tt->timer, jiffies + msecs_to_jiffies(tt->debounce_time));

	if((gpio_get_value(tt->gpio_num) ? __HI__ : __LO__))
    {
#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
        printk(KERN_DEBUG "[%s:%4d:%s] HI \n", __FILENAME__, __LINE__, __FUNCTION__);
#endif  // #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

        irq_set_irq_type(irq, IRQ_TYPE_EDGE_FALLING);
	}
	else {
#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
        printk(KERN_DEBUG "[%s:%4d:%s] LO \n", __FILENAME__, __LINE__, __FUNCTION__);
#endif  // #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

        irq_set_irq_type(irq, IRQ_TYPE_EDGE_RISING);
	}

	return IRQ_HANDLED;
}


static int kisan_gpio_intr_open(struct inode *inode, struct file *file)
{
#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
    printk(KERN_DEBUG "[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);
#endif  // #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

    return 0;
}


static ssize_t kisan_gpio_intr_read(struct file *filp, char *buf, size_t count, loff_t *f_pos)
{
#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
    printk(KERN_DEBUG "[%s:%4d:%s] \n", __FILENAME__, __LINE__, __FUNCTION__);
#endif  // #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

    return 0;
} 


static long kisan_gpio_intr_ioctl(struct file *filp, unsigned int cmd, unsigned long args)
{
    void __user *argp = (void __user *) args;
    struct structKisanGpioIntr stKisanGpioIntr;

    if(copy_from_user(&stKisanGpioIntr, argp, sizeof(struct structKisanGpioIntr))) {
        printk(KERN_ERR "[%s:%4d:%s] copy_from_user. \n", __FILENAME__, __LINE__, __FUNCTION__);
        return -EFAULT;
    }

    g_ucRunMode = stKisanGpioIntr.ucRunMode;

#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
    printk(KERN_DEBUG "[%s:%4d:%s] Running Mode: %s \n", __FILENAME__, __LINE__, __FUNCTION__,
	        g_ucRunMode ? "Single GPIO Interrupt" : "Multi GPIO Interrupt");
#endif  // #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

    return 0;
}


static struct file_operations st_kisan_gpio_intr_fops = {
	.owner   		= THIS_MODULE,
    .open    		= kisan_gpio_intr_open,
    .read    		= kisan_gpio_intr_read,    
    .unlocked_ioctl = kisan_gpio_intr_ioctl,
};


static struct miscdevice st_miscdev_kisan_gpio_intr = {
    .minor  = KISAN_GPIO_INTR_MINOR,		// ./kernel_root/include/linux/miscdevice.h
    .name   = "kisan_gpio_intr",
    .fops   = &st_kisan_gpio_intr_fops
};


static int SetGpioRegisterValues(void)
{
    unsigned int unRegVal = 0x0;

    void __iomem *cm_per;
    void __iomem *iomem;

	int nGpioNum = 0;
//    int i = 0;
	
    /*
     Enable GPIO3 clock

	 TRM Pg. 1072
	 Address Offset  : 0x0000_0068	(CSL_MPU_L4PER_CM_CORE_REGS 0x4a009700)
	 Physical Address: 0x4A00_9768
    */
    cm_per = ioremap(CSL_MPU_L4PER_CM_CORE_REGS, CSL_MPU_L4PER_CM_CORE_SIZE);
    if(!cm_per) {
      printk(KERN_ERR "[%s:%4d:%s] Failed to remap memory for CM_PER.\n", 
        __FILENAME__, __LINE__, __FUNCTION__);
      return 0;
    }
    iowrite32(0x02, cm_per + 0x68); // MODULEMODE:  0x0=DISABLED,  0x2=ENABLED
    iounmap(cm_per);


    /*
     Setup the IRQ registers with the appropriate values.

 	 TRM Pg. 7109 ~ 7110
	 Address Offset	: 0x0000_002C  (CSL_MPU_GPIO3_REGS 0x48057000)
	 Physical Address: 0x4A805_702C
	 ...
    */
    iomem = ioremap(CSL_MPU_GPIO3_REGS, CSL_MPU_GPIO3_SIZE);
    if(!iomem) {
        printk(KERN_ERR "[%s:%4d:%s] Failed to remap memory for GPIO Bank 3 IRQ pin configuration.\n",
            __FILENAME__, __LINE__, __FUNCTION__);
        return 0;
    }


#if 0
	// Execute sw reset
	iowrite32(0x02, iomem + GPIO_SYSCONFIG);

	// Wait until reset complete
	while(1) {
		unRegVal = ioread32(iomem + GPIO_SYSSTATUS);
		if(unRegVal == 1)
			break;
	}
#endif


	// Configure idle mode
	unRegVal = ioread32(iomem + GPIO_SYSCONFIG);
	BIT_CLR(unRegVal, 3);
	BIT_CLR(unRegVal, 4);
	iowrite32 (unRegVal, iomem + GPIO_SYSCONFIG);


	// Configure GPIO3_12 as output
	nGpioNum = 12;
	unRegVal = ioread32 (iomem + GPIO_OE);
	BIT_CLR(unRegVal, nGpioNum);
	iowrite32 (unRegVal, iomem + GPIO_OE);


	// for GPIO3_10, GPIO_3_11
	for(nGpioNum = 10 ; nGpioNum <= 11 ; nGpioNum++)
	{	
		// Configure GPIO channels as input
		unRegVal = ioread32 (iomem + GPIO_OE);
        BIT_SET(unRegVal, nGpioNum);
	    iowrite32 (unRegVal, iomem + GPIO_OE);

		// Configure detection events
		unRegVal = ioread32 (iomem + GPIO_RISINGDETECT);
		BIT_SET(unRegVal, nGpioNum);
		iowrite32 (unRegVal, iomem + GPIO_RISINGDETECT);

		unRegVal = ioread32 (iomem + GPIO_FALLINGDETECT);
		BIT_SET(unRegVal, nGpioNum);
		iowrite32 (unRegVal, iomem + GPIO_FALLINGDETECT);
	}

	
	// Clear interrupt status
	unRegVal = 0xFFFFFFFF;
	iowrite32 (unRegVal, iomem + GPIO_IRQSTATUS(0));

	// Enable interrupts for desired input lines
	unRegVal = ioread32 (iomem + GPIO_IRQSTATUS_SET(0));
	BIT_SET(unRegVal, 10);
	iowrite32 (unRegVal, iomem + GPIO_IRQSTATUS_SET(0)); 	
#if 0
		for(i = 0 ; i < 2 ; i++)
		{
			// Enable interrupts for desired input lines
			unRegVal = ioread32 (iomem + GPIO_IRQSTATUS_SET(i));
			BIT_SET(unRegVal, nGpioNum);
			iowrite32 (unRegVal, iomem + GPIO_IRQSTATUS_SET(i)); 
		}
#endif


    iounmap(iomem);

    return 0;
}


static int kisan_gpio_intr_probe(struct platform_device *device)
{
    int nErr = 0;

    /* create a socket */
    if ( ((nErr = sock_create(AF_INET, SOCK_DGRAM, IPPROTO_UDP, &g_sock_kisan_gpio_intr)) < 0) ) {
        printk(KERN_INFO MODULE_NAME": Could not create a datagram socket, error = %d \n", -ENXIO);
        return -ENXIO;
    }

    memset(&g_addr_kisan_gpio_intr, 0, sizeof(struct sockaddr));
    g_addr_kisan_gpio_intr.sin_family      = AF_INET;
    g_addr_kisan_gpio_intr.sin_addr.s_addr = htonl(INADDR_ANY);
    g_addr_kisan_gpio_intr.sin_port        = htons(DEFAULT_UDP_PORT);

	printk(KERN_DEBUG "[%s:%4d:%s] Created UDP Socket for kisan_gpio_intr char driver. \n",
			__FILENAME__, __LINE__, __FUNCTION__);

#if 0
    if ( ( (nErr = kthread->sock->ops->bind(kthread->sock, (struct sockaddr *)&g_addr_kisan_gpio_intr, sizeof(struct sockaddr) ) ) < 0)) {
        printk(KERN_INFO MODULE_NAME": Could not bind or connect to socket, error = %d\n", -nErr);
        goto close_and_out;
    }
    printk(KERN_INFO MODULE_NAME": listening on port %d\n", DEFAULT_UDP_PORT);
#endif

#if 0
    void __iomem *cm_per;
    unsigned int *punPtr;

    // Enable EMIF Clock
    {
        cm_per = ioremap(CM_PER_START_ADDR, CM_PER_SIZE);
        if(!cm_per) {
            printk ("[Err][%s:%4d:%s] Failed to remap memory for CM_PER.\n",
                __FILENAME__, __LINE__, __FUNCTION__);
            return -1;
        }
        punPtr = cm_per + OFFSET_CMPER_EMIF_CLKCTRL;
        *punPtr = 0x00000002;  // enable the module
        udelay(1000);
        iounmap(cm_per);
    }
#endif

    return 0;
}


static int __init kisan_gpio_intr_init(void)
{
	int nErr = 0;
    int i=0;

    g_ucRunMode = RUN_MODE_GPIO_INTR_MULTI;

    nErr = misc_register(&st_miscdev_kisan_gpio_intr);
    if( nErr ) {
        printk(KERN_ERR "[%s:%4d:%s] kisan_gpio_intr misc_register failure... \n",
	            __FILENAME__, __LINE__, __FUNCTION__);
        return -ENOMEM;
    }
    else {
        printk(KERN_DEBUG "[%s:%4d:%s] Register a kisan_gpio_intr char driver. \n",
    	        __FILENAME__, __LINE__, __FUNCTION__);
    }

/*
	int nGpioNum = ((32*3)+12);

	nErr = gpio_request_one(nGpioNum, GPIOF_OUT_INIT_LOW, "S2:gpio3_12:TestIntr");
	if( nErr ) {
		printk(KERN_ERR "[%s:%4d:%s] Failed to request GPIO pin#%i for IRQ (err %i) \n", 
				__FILENAME__, __LINE__, __FUNCTION__, nGpioNum, nErr);
		return -EIO;
	}
*/


    if(g_ucRunMode == RUN_MODE_GPIO_INTR_SINGLE)
    {
        if(!gpio_is_valid(GPIO_INTR_DSP)) {
            printk(KERN_ERR "[%s:%4d:%s] Invalid GPIO... (%d) \n", 
        	        __FILENAME__, __LINE__, __FUNCTION__, GPIO_INTR_DSP);
            return -EIO;
        }
        else {
            nErr = gpio_request_one(GPIO_INTR_DSP, GPIOF_IN, g_astrGpioNumToName[0]);
            if( nErr ) {
                printk(KERN_ERR "[%s:%4d:%s] Failed to request GPIO pin#%i for IRQ (err %i) \n", 
            	        __FILENAME__, __LINE__, __FUNCTION__, GPIO_INTR_DSP, nErr);
                return -EIO;
            }
        }

        g_anGpioNumToIrq[0] = gpio_to_irq(GPIO_INTR_DSP);
        if(g_anGpioNumToIrq[0] < 0) {
            printk(KERN_ERR "[%s:%4d:%s] Failed to gpio #%d to irq (%s) \n", 
                	__FILENAME__, __LINE__, __FUNCTION__, GPIO_INTR_DSP, g_astrGpioNumToName[0]);
            gpio_free(GPIO_INTR_DSP);
            return -EIO;
        }

        g_astTimerWork[0].gpio_num = GPIO_INTR_DSP;
        g_astTimerWork[0].real_num = 1;
        g_astTimerWork[0].debounce_time = 25;

        INIT_WORK(&(g_astTimerWork[0].work), gpio_intr_work_func);

//#if LINUX_VERSION_CODE < KERNEL_VERSION(4,15,0)
		//setup_timer(&(g_astTimerWork[0].timer), gpio_intr_timer, (unsigned long)&g_astTimerWork[0]);
//#else
		timer_setup(&(g_astTimerWork[0].timer), gpio_intr_timer, 0);
//#endif

        nErr = request_irq(g_anGpioNumToIrq[0], kisan_gpio_intr_isr, IRQF_TRIGGER_RISING | IRQF_TRIGGER_FALLING, 
        					g_astrGpioNumToName[0], &g_astTimerWork[0]/*NULL*/);
		//irq_set_irq_type ( g_anGpioNumToIrq[0], IRQ_TYPE_EDGE_FALLING );

        if (nErr) {
            printk(KERN_ERR "[%s:%4d:%s] The requested IRQ line#%i from GPIO#%i (err %i)\n",
				    __FILENAME__, __LINE__, __FUNCTION__, g_anGpioNumToIrq[0], GPIO_INTR_DSP, nErr);
            return -EIO;
        }
    }
    else
    {
        for(i=0 ; i< MAX_NUM_OF_GPIO_INTR ; i++) {
            if(!gpio_is_valid(g_anGpioNum[i])) {
                printk(KERN_ERR "[%s:%4d:%s] Invalid GPIO... (%d) \n", 
	                    __FILENAME__, __LINE__, __FUNCTION__, g_anGpioNum[i]);
                return -EIO;
            }
            else {
                nErr = gpio_request_one(g_anGpioNum[i], GPIOF_IN, g_astrGpioNumToName[i]);
                if( nErr ) {
                    printk(KERN_ERR "[%s:%4d:%s] Failed to request GPIO pin#%i for IRQ (err %i) \n", 
    	                    __FILENAME__, __LINE__, __FUNCTION__, g_anGpioNum[i], nErr);
                    return -EIO;
                }
            }

            g_anGpioNumToIrq[i] = gpio_to_irq(g_anGpioNum[i]);
            if(g_anGpioNumToIrq[i] < 0) {
                printk(KERN_ERR "[%s:%4d:%s] Failed to gpio #%d to irq (err %i) \n", 
	                    __FILENAME__, __LINE__, __FUNCTION__, g_anGpioNum[i], g_anGpioNumToIrq[i]);
                gpio_free(g_anGpioNum[i]);
                return -EIO;
            }

#if defined( DBG_MSG_ON_KISAN_GPIO_INTR )
			printk(KERN_DEBUG "[%s:%4d:%s] %s, Irq = %d \n",
					__FILENAME__, __LINE__, __FUNCTION__, g_astrGpioNumToName[i], g_anGpioNumToIrq[i]);
#endif	// #if defined( DBG_MSG_ON_KISAN_GPIO_INTR )

            g_astTimerWork[i].gpio_num = g_anGpioNum[i];
            g_astTimerWork[i].real_num = i + 1;
            g_astTimerWork[i].debounce_time = 25;

            INIT_WORK(&(g_astTimerWork[i].work), gpio_intr_work_func);
//#if LINUX_VERSION_CODE < KERNEL_VERSION(4,15,0)
			//setup_timer(&(g_astTimerWork[i].timer), gpio_intr_timer, (unsigned long)&g_astTimerWork[i]);
//#else
            timer_setup(&(g_astTimerWork[i].timer), gpio_intr_timer, 0);
//#endif

            nErr = request_irq(g_anGpioNumToIrq[i], kisan_gpio_intr_isr, IRQF_TRIGGER_RISING | IRQF_TRIGGER_FALLING,
            					g_astrGpioNumToName[i], &g_astTimerWork[i]/*NULL*/);
		    //irq_set_irq_type ( g_anGpioNumToIrq[i], IRQ_TYPE_EDGE_FALLING );

            if (nErr) {
                printk(KERN_ERR "[%s:%4d:%s] The requested IRQ line#%i from GPIO#%i (err %i)\n",
	                    __FILENAME__, __LINE__, __FUNCTION__, g_anGpioNumToIrq[i], g_anGpioNum[i], nErr);
                return -EIO;
            }
	//        else {
	//            printk(KERN_DEBUG "[%s:%4d:%s] Initialized GPIO #%i to IRQ #%i, Value:(%d) \n",
	//                __FILENAME__, __LINE__, __FUNCTION__, g_anGpioNum[i], g_anGpioNumToIrq[i], gpio_get_value(g_anGpioNum[i]));
	//        }
        }
    }

    SetGpioRegisterValues();

	return 0;
}


void __exit kisan_gpio_intr_exit(void)
{
    int i=0;
    
    if(g_ucRunMode == RUN_MODE_GPIO_INTR_SINGLE)
    {
        free_irq(g_anGpioNumToIrq[0], NULL);
        gpio_free(g_anGpioNum[0]);
        del_timer(&(g_astTimerWork[0].timer));
    }
    else
    {
    	for(i = 0; i < MAX_NUM_OF_GPIO_INTR; i++) {
    		free_irq(g_anGpioNumToIrq[i], NULL);
    		gpio_free(g_anGpioNum[i]);
            del_timer(&(g_astTimerWork[i].timer));
    	}
    }

	misc_deregister(&st_miscdev_kisan_gpio_intr);

    sock_release(g_sock_kisan_gpio_intr);
    g_sock_kisan_gpio_intr = NULL;

    printk(KERN_INFO MODULE_NAME": module unloaded. \n");
}


#if IS_ENABLED(CONFIG_OF)  
static const struct of_device_id st_kisan_gpio_intr_of_match[] = {  
    {.compatible = "kisan_gpio_intr", },  
    {},  
};
MODULE_DEVICE_TABLE(of, st_kisan_gpio_intr_of_match);  
#endif 


static struct platform_driver st_kisan_gpio_intr = {
	.probe   = kisan_gpio_intr_probe,
//	.remove  = kisan_gpio_intr_remove,
//	.suspend = kisan_gpio_intr_suspend,
//	.resume  = kisan_gpio_intr_resume,
	.driver  = {
        .name           = "kisan_gpio_intr",
        .owner          = THIS_MODULE,
        .of_match_table = of_match_ptr(st_kisan_gpio_intr_of_match), 
    },
};
module_platform_driver(st_kisan_gpio_intr);

module_init(kisan_gpio_intr_init);
module_exit(kisan_gpio_intr_exit);

MODULE_DESCRIPTION("AM5729 GPIO Interrupt Driver");
MODULE_AUTHOR("hong.yongje@kisane.com");
MODULE_LICENSE("Dual BSD/GPL");


