/**
@file       kisan_common.h
@brief      am3356 device driver  
@details    am3356 device driver  
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

#ifndef _LINUX_KISAN_H
#define _LINUX_KISAN_H


#include <kisan/cslr_soc_mpu_baseaddress.h>



#if !defined(TRUE)
#define TRUE 	(1)
#endif	// #if !defined(TRUE)
#if !defined(FALSE)
#define FALSE 	(0)
#endif	// #if !defined(FALSE)

#define __ON__      (1)
#define __OFF__     (0)

#define __YES__      (1)
#define __NO__     (0)

#define __HI__      (1)
#define __LO__     (0)

#define __IN__     (1)
#define __OUT__      (0)

#define __FILENAME__ (strrchr(__FILE__, '/') ? strrchr(__FILE__, '/') + 1 : __FILE__)



/**
@def        Macros
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

/*  Ʈ Ŭ */
#define BIT_CLR(data, loc)    ((data) &= ~(0x1 << (loc)))
/* ӵ  Ʈ Ŭ */
#define BITS_CLR(data, area, loc)     ((data) &= ~((area) << (loc)))

/*  Ʈ  */
#define BIT_SET(data, loc)      ((data) |= (0x1 << (loc)))
/* ӵ  Ʈ  */
#define BITS_SET(data, area, loc)  ((data) |= ((area) << (loc)))

/*  Ʈ  */
#define BIT_INVERT(data, loc)   ((data) ^= (0x1 << (loc)))
/* ӵ  Ʈ  */
#define BITS_INVERT(data, area, loc)    ((data) ^= ((area) << (loc)))

/* Ʈ ˻ */
#define BIT_CHECK(data, loc)    ((data) & (0x1 << (loc)))

/* Ʈ  */
#define BITS_EXTRACT(data, area, loc)   (((data) >> (loc)) & (area))




#define GPIO_TO_BANK(gpio)	((gpio) / 32)
#define GPIO_TO_PINS(gpio)	((gpio) % 32)




//*****************************************************************************
//
// Macros for hardware access, both direct and via the bit-band region.
//
//*****************************************************************************
#define HWREG(x)                                                              \
        (*((volatile unsigned int *)(x)))
#define HWREGH(x)                                                             \
        (*((volatile unsigned short *)(x)))
#define HWREGB(x)                                                             \
        (*((volatile unsigned char *)(x)))
#define HWREGBITW(x, b)                                                       \
        HWREG(((unsigned int)(x) & 0xF0000000) | 0x02000000 |                \
              (((unsigned int)(x) & 0x000FFFFF) << 5) | ((b) << 2))
#define HWREGBITH(x, b)                                                       \
        HWREGH(((unsigned int)(x) & 0xF0000000) | 0x02000000 |               \
               (((unsigned int)(x) & 0x000FFFFF) << 5) | ((b) << 2))
#define HWREGBITB(x, b)                                                       \
        HWREGB(((unsigned int)(x) & 0xF0000000) | 0x02000000 |               \
               (((unsigned int)(x) & 0x000FFFFF) << 5) | ((b) << 2))






/**
@def        am3356 registers definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

// Interrupt Controller Registers
#define INTC_START_ADDR                 (0x48200000)
#define INTC_SIZE                       (0x1000)
#define OFFSET_INTC_SYSCONFIG           (0x10)
#define OFFSET_INTC_CONTROL             (0x48)


// Power Reset Module Interrupt Registers
#define PRM_IRQ_START_ADDR          (0x44e00b00)
#define PRM_IRQ_SIZE                (0x100)

// Power Reset Module Peripheral Registers
#define PRM_PER_START_ADDR          (0x44e00c00)
#define PRM_PER_SIZE                (0x100)

// CM_PER (Clock Module Peripheral Registers)
#define CM_PER_START_ADDR           (0x44e00000)
#define CM_PER_SIZE                 (0x400)     // 1K



#define CM_PER_L4LS_CLKSTCTRL   (0x0)
#define CM_PER_L3S_CLKSTCTRL   (0x4)
#define CM_PER_L4FW_CLKSTCTRL   (0x8)
#define CM_PER_L3_CLKSTCTRL   (0xc)
#define CM_PER_CPGMAC0_CLKCTRL   (0x14)
#define CM_PER_LCDC_CLKCTRL   (0x18)
#define CM_PER_USB0_CLKCTRL   (0x1c)
#define CM_PER_MLB_CLKCTRL   (0x20)
#define CM_PER_TPTC0_CLKCTRL   (0x24)
#define CM_PER_EMIF_CLKCTRL   (0x28)
#define CM_PER_OCMCRAM_CLKCTRL   (0x2c)
#define CM_PER_GPMC_CLKCTRL   (0x30)
#define CM_PER_MCASP0_CLKCTRL   (0x34)
#define CM_PER_UART5_CLKCTRL   (0x38)
#define CM_PER_MMC0_CLKCTRL   (0x3c)
#define CM_PER_ELM_CLKCTRL   (0x40)
#define CM_PER_I2C2_CLKCTRL   (0x44)
#define CM_PER_I2C1_CLKCTRL   (0x48)
#define CM_PER_SPI0_CLKCTRL   (0x4c)
#define CM_PER_SPI1_CLKCTRL   (0x50)
#define CM_PER_L4LS_CLKCTRL   (0x60)
#define CM_PER_L4FW_CLKCTRL   (0x64)
#define CM_PER_MCASP1_CLKCTRL   (0x68)
#define CM_PER_UART1_CLKCTRL   (0x6c)
#define CM_PER_UART2_CLKCTRL   (0x70)
#define CM_PER_UART3_CLKCTRL   (0x74)
#define CM_PER_UART4_CLKCTRL   (0x78)
#define CM_PER_TIMER7_CLKCTRL   (0x7c)
#define CM_PER_TIMER2_CLKCTRL   (0x80)
#define CM_PER_TIMER3_CLKCTRL   (0x84)
#define CM_PER_TIMER4_CLKCTRL   (0x88)
#define CM_PER_RNG_CLKCTRL   (0x90)
#define CM_PER_AES0_CLKCTRL   (0x94)
#define CM_PER_SHA0_CLKCTRL   (0xa0)
#define CM_PER_PKA_CLKCTRL   (0xa4)
#define CM_PER_GPIO0_CLKCTRL   (0xa8)
#define CM_PER_GPIO1_CLKCTRL   (0xac)
#define CM_PER_GPIO2_CLKCTRL   (0xb0)
#define CM_PER_GPIO3_CLKCTRL   (0xb4)
#define CM_PER_TPCC_CLKCTRL   (0xbc)
#define CM_PER_DCAN0_CLKCTRL   (0xc0)
#define CM_PER_DCAN1_CLKCTRL   (0xc4)
#define CM_PER_EPWMSS1_CLKCTRL   (0xcc)
#define CM_PER_EMIF_FW_CLKCTRL   (0xd0)
#define CM_PER_EPWMSS0_CLKCTRL   (0xd4)
#define CM_PER_EPWMSS2_CLKCTRL   (0xd8)
#define CM_PER_L3_INSTR_CLKCTRL   (0xdc)
#define CM_PER_L3_CLKCTRL   (0xe0)
#define CM_PER_IEEE5000_CLKCTRL   (0xe4)
#define CM_PER_ICSS_CLKCTRL   (0xe8)
#define CM_PER_TIMER5_CLKCTRL   (0xec)
#define CM_PER_TIMER6_CLKCTRL   (0xf0)
#define CM_PER_MMC1_CLKCTRL   (0xf4)
#define CM_PER_MMC2_CLKCTRL   (0xf8)
#define CM_PER_TPTC1_CLKCTRL   (0xfc)
#define CM_PER_TPTC2_CLKCTRL   (0x100)
#define CM_PER_SPINLOCK_CLKCTRL   (0x10c)
#define CM_PER_MAILBOX0_CLKCTRL   (0x110)
#define CM_PER_L4HS_CLKSTCTRL   (0x11c)
#define CM_PER_L4HS_CLKCTRL   (0x120)
#define CM_PER_MSTR_EXPS_CLKCTRL   (0x124)
#define CM_PER_SLV_EXPS_CLKCTRL   (0x128)
#define CM_PER_OCPWP_L3_CLKSTCTRL   (0x12c)
#define CM_PER_OCPWP_CLKCTRL   (0x130)
#define CM_PER_ICSS_CLKSTCTRL   (0x140)
#define CM_PER_CPSW_CLKSTCTRL   (0x144)
#define CM_PER_LCDC_CLKSTCTRL   (0x148)
#define CM_PER_CLKDIV32K_CLKCTRL   (0x14c)
#define CM_PER_CLK_24MHZ_CLKSTCTRL   (0x150)



/* GPIO1_CLKCTRL */
#define CM_PER_GPIO1_CLKCTRL_IDLEST   (0x00030000u)
#define CM_PER_GPIO1_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_PER_GPIO1_CLKCTRL_IDLEST_DISABLED   (0x3u)
#define CM_PER_GPIO1_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_PER_GPIO1_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_PER_GPIO1_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_PER_GPIO1_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_PER_GPIO1_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_PER_GPIO1_CLKCTRL_MODULEMODE_DISABLE   (0x0u)
#define CM_PER_GPIO1_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_PER_GPIO1_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_PER_GPIO1_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)

#define CM_PER_GPIO1_CLKCTRL_OPTFCLKEN_GPIO_1_GDBCLK   (0x00040000u)
#define CM_PER_GPIO1_CLKCTRL_OPTFCLKEN_GPIO_1_GDBCLK_SHIFT   (0x00000012u)
#define CM_PER_GPIO1_CLKCTRL_OPTFCLKEN_GPIO_1_GDBCLK_FCLK_DIS   (0x0u)
#define CM_PER_GPIO1_CLKCTRL_OPTFCLKEN_GPIO_1_GDBCLK_FCLK_EN   (0x1u)


/* GPIO2_CLKCTRL */
#define CM_PER_GPIO2_CLKCTRL_IDLEST   (0x00030000u)
#define CM_PER_GPIO2_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_PER_GPIO2_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_PER_GPIO2_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_PER_GPIO2_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_PER_GPIO2_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_PER_GPIO2_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_PER_GPIO2_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_PER_GPIO2_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_PER_GPIO2_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_PER_GPIO2_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_PER_GPIO2_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)

#define CM_PER_GPIO2_CLKCTRL_OPTFCLKEN_GPIO_2_GDBCLK   (0x00040000u)
#define CM_PER_GPIO2_CLKCTRL_OPTFCLKEN_GPIO_2_GDBCLK_SHIFT   (0x00000012u)
#define CM_PER_GPIO2_CLKCTRL_OPTFCLKEN_GPIO_2_GDBCLK_FCLK_DIS   (0x0u)
#define CM_PER_GPIO2_CLKCTRL_OPTFCLKEN_GPIO_2_GDBCLK_FCLK_EN   (0x1u)


/* GPIO3_CLKCTRL */
#define CM_PER_GPIO3_CLKCTRL_IDLEST   (0x00030000u)
#define CM_PER_GPIO3_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_PER_GPIO3_CLKCTRL_IDLEST_DISABLED   (0x3u)
#define CM_PER_GPIO3_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_PER_GPIO3_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_PER_GPIO3_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_PER_GPIO3_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_PER_GPIO3_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_PER_GPIO3_CLKCTRL_MODULEMODE_DISABLE   (0x0u)
#define CM_PER_GPIO3_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_PER_GPIO3_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_PER_GPIO3_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)

#define CM_PER_GPIO3_CLKCTRL_OPTFCLKEN_GPIO_3_GDBCLK   (0x00040000u)
#define CM_PER_GPIO3_CLKCTRL_OPTFCLKEN_GPIO_3_GDBCLK_SHIFT   (0x00000012u)
#define CM_PER_GPIO3_CLKCTRL_OPTFCLKEN_GPIO_3_GDBCLK_FCLK_DIS   (0x0u)
#define CM_PER_GPIO3_CLKCTRL_OPTFCLKEN_GPIO_3_GDBCLK_FCLK_EN   (0x1u)


/* L4LS_CLKSTCTRL */
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_1_GDBCLK   (0x00080000u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_1_GDBCLK_SHIFT   (0x00000013u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_1_GDBCLK_ACT   (0x1u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_1_GDBCLK_INACT   (0x0u)

#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_2_GDBCLK   (0x00100000u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_2_GDBCLK_SHIFT   (0x00000014u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_2_GDBCLK_ACT   (0x1u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_2_GDBCLK_INACT   (0x0u)

#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_3_GDBCLK   (0x00200000u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_3_GDBCLK_SHIFT   (0x00000015u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_3_GDBCLK_ACT   (0x1u)
#define CM_PER_L4LS_CLKSTCTRL_CLKACTIVITY_GPIO_3_GDBCLK_INACT   (0x0u)





/** @brief Base addresses of PRCM memory mapped registers                     */
#define SOC_PRCM_REGS                        (CM_PER_START_ADDR)
#define SOC_CM_PER_REGS                      (SOC_PRCM_REGS + 0)
#define SOC_CM_WKUP_REGS                     (SOC_PRCM_REGS + 0x400)
#define SOC_CM_DPLL_REGS                     (SOC_PRCM_REGS + 0x500)
#define SOC_CM_MPU_REGS                      (SOC_PRCM_REGS + 0x600)
#define SOC_CM_DEVICE_REGS                   (SOC_PRCM_REGS + 0x700)
#define SOC_CM_RTC_REGS                      (SOC_PRCM_REGS + 0x800)
#define SOC_CM_GFX_REGS                      (SOC_PRCM_REGS + 0x900)
#define SOC_CM_CEFUSE_REGS                   (SOC_PRCM_REGS + 0xA00)
#define SOC_OCP_SOCKET_RAM_REGS              (SOC_PRCM_REGS + 0xB00)
#define SOC_PRM_PER_REGS                     (SOC_PRCM_REGS + 0xC00)
#define SOC_PRM_WKUP_REGS                    (SOC_PRCM_REGS + 0xD00)
#define SOC_PRM_MPU_REGS                     (SOC_PRCM_REGS + 0xE00)
#define SOC_PRM_DEVICE_REGS                  (SOC_PRCM_REGS + 0xF00)
#define SOC_PRM_RTC_REGS                     (SOC_PRCM_REGS + 0x1000)
#define SOC_PRM_GFX_REGS                     (SOC_PRCM_REGS + 0x1100)
#define SOC_PRM_CEFUSE_REGS                  (SOC_PRCM_REGS + 0x1200)


/** @brief Base address of control module memory mapped registers             */
#define SOC_CONTROL_REGS                     (0x44E10000)







#define CONTROL_REVISION   (0x0)
#define CONTROL_HWINFO   (0x4)
#define CONTROL_SYSCONFIG   (0x10)
#define CONTROL_STATUS   (0x40)
#define CONTROL_BOOTSTAT   (0x44)
#define CONTROL_SEC_CTRL   (0x100)
#define CONTROL_SEC_SW   (0x104)
#define CONTROL_SEC_EMU   (0x108)
#define CONTROL_SECURE_EMIF_SDRAM_CONFIG   (0x110)
#define CONTROL_SECURE_EMIF_SDRAM_CONFIG_2   (0x114)
#define CONTROL_SW_CFG   (0x118)
#define CONTROL_SW_CCFG   (0x11c)
#define CONTROL_MPK(n)   (0x120 + (n * 4))
#define CONTROL_SWRV(n)   (0x140 + (n * 4))
#define CONTROL_SEC_TAP   (0x180)
#define CONTROL_SEC_TAP_CMDIN   (0x184)
#define CONTROL_SEC_TAP_CMDOUT   (0x188)
#define CONTROL_SEC_TAP_DATIN   (0x18c)
#define CONTROL_SEC_TAP_DATOUT   (0x190)
#define CONTROL_MREQDOMAIN_EXP1   (0x198)
#define CONTROL_MREQDOMAIN_EXP2   (0x19c)
#define CONTROL_L3_HW_FW_EXP_VAL_CONF0   (0x1a0)
#define CONTROL_L3_HW_FW_EXP_VAL_CONF1   (0x1a4)
#define CONTROL_L4_HW_FW_EXP_VAL_CONF   (0x1a8)
#define CONTROL_SEC_LOAD_FW_EXP_VAL   (0x1ac)
#define CONTROL_SEC_CTRL_RO   (0x1b4)
#define CONTROL_EMIF_OBFUSCATION_KEY   (0x1b8)
#define CONTROL_SEC_CLK_CTRL   (0x1bc)
#define CONTROL_MREQDOMAIN_EXP3   (0x1d4)
#define CONTROL_CEK(n)   (0x200 + (n * 4))
#define CONTROL_CEK_BCH(n)   (0x210 + (n * 4))
#define CONTROL_MSV_0   (0x224)
#define CONTROL_MSV_BCH(n)   (0x228 + (n * 4))
#define CONTROL_SEC_STATUS   (0x240)
#define CONTROL_SECMEM_STATUS   (0x244)
#define CONTROL_SEC_ERR_STAT_FUNC(n)   (0x248 + (n * 4))
#define CONTROL_SEC_ERR_STAT_DBUG(n)   (0x250 + (n * 4))
#define CONTROL_KEK_SW(n)   (0x260 + (n * 4))
#define CONTROL_CMPK_BCH(n)   (0x280 + (n * 4))
#define CONTROL_CMPK(n)   (0x2b0 + (n * 4))
#define CONTROL_SSM_END_FAST_SECRAM   (0x300)
#define CONTROL_SSM_FIREWALL_CONTROLLER   (0x304)
#define CONTROL_SSM_START_SECURE_STACKED_RAM   (0x308)
#define CONTROL_SSM_END_SECURE_STACKED_RAM   (0x30c)
#define CONTROL_SSM_START_SPM_STACK   (0x310)
#define CONTROL_SSM_END_SPM_STACK   (0x314)
#define CONTROL_SSM_START_MONITOR_RAMCODE   (0x318)
#define CONTROL_SSM_END_MONITOR_RAMCODE   (0x31c)
#define CONTROL_SSM_END_MONITOR_RAMDATA   (0x320)
#define CONTROL_SSM_START_MONITOR_CODE   (0x324)
#define CONTROL_SSM_END_MONITOR_CODE   (0x328)
#define CONTROL_SSM_START_MONITOR_PERIPH   (0x32c)
#define CONTROL_SSM_END_MONITOR_PERIPH   (0x330)
#define CONTROL_SSM_START_MONITOR_STACK   (0x334)
#define CONTROL_SSM_END_MONITOR_STACK   (0x338)
#define CONTROL_SSM_START_MONITOR_RAMCODE_ETM   (0x33c)
#define CONTROL_SSM_END_MONITOR_RAMCODE_ETM   (0x340)
#define CONTROL_SSM_END_MONITOR_RAMDATA_ETM   (0x344)
#define CONTROL_SSM_START_MONITOR_CODE_ETM   (0x348)
#define CONTROL_SSM_END_MONITOR_CODE_ETM   (0x34c)
#define CONTROL_SSM_START_MONITOR_STACK_ETM   (0x350)
#define CONTROL_SSM_END_MONITOR_STACK_ETM   (0x354)
#define CONTROL_SSM_START_MONITOR_SHARED_ETM   (0x358)
#define CONTROL_SSM_END_MONITOR_SHARED_ETM   (0x35c)
#define CONTROL_SSM_START_MONITOR_PERIPH_ETM   (0x360)
#define CONTROL_SSM_END_MONITOR_PERIPH_ETM   (0x364)
#define CONTROL_SSM_CPSR_MODE_ENFC   (0x368)
#define CONTROL_SSM_END_L3_SECRAM   (0x36c)
#define CONTROL_CORTEX_VBBLDO_CTRL   (0x41c)
#define CONTROL_CORE_SLDO_CTRL   (0x428)
#define CONTROL_MPU_SLDO_CTRL   (0x42c)
#define CONTROL_REFCLK_LJCBLDO_CTRL   (0x440)
#define CONTROL_CLK32KDIVRATIO_CTRL   (0x444)
#define CONTROL_BANDGAP_CTRL   (0x448)
#define CONTROL_BANDGAP_TRIM   (0x44c)
#define CONTROL_PLL_CLKINPULOW_CTRL   (0x458)
#define CONTROL_MOSC_CTRL   (0x468)
#define CONTROL_RCOSC_CTRL   (0x46c)
#define CONTROL_DEEPSLEEP_CTRL   (0x470)
#define CONTROL_PE_SCRATCHPAD(n)   (0x500 + (n * 4))
#define CONTROL_DEVICE_ID   (0x600)
#define CONTROL_DEV_FEATURE   (0x604)
#define CONTROL_INIT_PRIORITY(n)   (0x608 + (n * 4))
#define CONTROL_MMU_CFG   (0x610)
#define CONTROL_TPTC_CFG   (0x614)
#define CONTROL_OCMC_CFG   (0x618)
#define CONTROL_USB_CTRL(n)   (0x620 + (n * 8))
#define CONTROL_USB_STS(n)   (0x624 + (n * 8))
#define CONTROL_MAC_ID_LO(n)   (0x630 + (n * 8))
#define CONTROL_MAC_ID_HI(n)   (0x634 + (n * 8))
#define CONTROL_DCAN_RAMINIT   (0x644)
#define CONTROL_USB_WKUP_CTRL   (0x648)
#define CONTROL_GMII_SEL   (0x650)
#define CONTROL_PWMSS_CTRL   (0x664)
#define CONTROL_MREQPRIO(n)   (0x670 + (n * 4))
#define CONTROL_HW_EVENT_SEL_GRP(n)   (0x690 + (n * 4))
#define CONTROL_SMRT_CTRL   (0x6a0)
#define CONTROL_SABTOOTH_HW_DEBUG_SEL   (0x6a4)
#define CONTROL_SABTOOTH_HW_DBG_INFO   (0x6a8)
#define CONTROL_MRGN_MODE(n)   (0x6c0 + (n * 4))
#define CONTROL_VDD_MPU_OPP(n)   (0x770 + (n * 4))
#define CONTROL_VDD_MPU_OPP_TURBO   (0x77c)
#define CONTROL_VDD_CORE_OPP(n)   (0x7b8 + (n * 4))
#define CONTROL_BB_SCALE   (0x7d0)
#define CONTROL_USB_VID_PID   (0x7f4)
#define CONTROL_EFUSE_SMA   (0x7fc)
#define CONTROL_CONF_GPMC_AD(n)   (0x800 + (n * 4))
#define CONTROL_CONF_GPMC_A(n)   (0x840 + (n * 4))
#define CONTROL_CONF_GPMC_WAIT0   (0x870)
#define CONTROL_CONF_GPMC_WPN   (0x874)
#define CONTROL_CONF_GPMC_BE1N   (0x878)
#define CONTROL_CONF_GPMC_CSN(n)   (0x87c + (n * 4))
#define CONTROL_CONF_GPMC_CLK   (0x88c)
#define CONTROL_CONF_GPMC_ADVN_ALE   (0x890)
#define CONTROL_CONF_GPMC_OEN_REN   (0x894)
#define CONTROL_CONF_GPMC_WEN   (0x898)
#define CONTROL_CONF_GPMC_BE0N_CLE   (0x89c)
#define CONTROL_CONF_LCD_DATA(n)   (0x8a0 + (n * 4))
#define CONTROL_CONF_LCD_VSYNC   (0x8e0)
#define CONTROL_CONF_LCD_HSYNC   (0x8e4)
#define CONTROL_CONF_LCD_PCLK   (0x8e8)
#define CONTROL_CONF_LCD_AC_BIAS_EN   (0x8ec)
#define CONTROL_CONF_MMC0_DAT3   (0x8f0)
#define CONTROL_CONF_MMC0_DAT2   (0x8f4)
#define CONTROL_CONF_MMC0_DAT1   (0x8f8)
#define CONTROL_CONF_MMC0_DAT0   (0x8fc)
#define CONTROL_CONF_MMC0_CLK   (0x900)
#define CONTROL_CONF_MMC0_CMD   (0x904)
#define CONTROL_CONF_MII1_COL   (0x908)
#define CONTROL_CONF_MII1_CRS   (0x90c)
#define CONTROL_CONF_MII1_RXERR   (0x910)
#define CONTROL_CONF_MII1_TXEN   (0x914)
#define CONTROL_CONF_MII1_RXDV   (0x918)
#define CONTROL_CONF_MII1_TXD3   (0x91c)
#define CONTROL_CONF_MII1_TXD2   (0x920)
#define CONTROL_CONF_MII1_TXD1   (0x924)
#define CONTROL_CONF_MII1_TXD0   (0x928)
#define CONTROL_CONF_MII1_TXCLK   (0x92c)
#define CONTROL_CONF_MII1_RXCLK   (0x930)
#define CONTROL_CONF_MII1_RXD3   (0x934)
#define CONTROL_CONF_MII1_RXD2   (0x938)
#define CONTROL_CONF_MII1_RXD1   (0x93c)
#define CONTROL_CONF_MII1_RXD0   (0x940)
#define CONTROL_CONF_RMII1_REFCLK   (0x944)
#define CONTROL_CONF_MDIO_DATA   (0x948)
#define CONTROL_CONF_MDIO_CLK   (0x94c)
#define CONTROL_CONF_SPI0_SCLK   (0x950)
#define CONTROL_CONF_SPI0_D0   (0x954)
#define CONTROL_CONF_SPI0_D1   (0x958)
#define CONTROL_CONF_SPI0_CS0   (0x95c)
#define CONTROL_CONF_SPI0_CS1   (0x960)
#define CONTROL_CONF_ECAP0_IN_PWM0_OUT   (0x964)
#define CONTROL_CONF_UART_CTSN(n)   (0x968 + ((n) * 0x10))
#define CONTROL_CONF_UART_RTSN(n)   (0x96c + ((n) * 0x10))
#define CONTROL_CONF_UART_RXD(n)   (0x970 + ((n) * 0x10))
#define CONTROL_CONF_UART_TXD(n)   (0x974 + ((n) * 0x10))
#define CONTROL_CONF_I2C0_SDA   (0x988)
#define CONTROL_CONF_I2C0_SCL   (0x98c)
#define CONTROL_CONF_MCASP0_ACLKX   (0x990)
#define CONTROL_CONF_MCASP0_FSX   (0x994)
#define CONTROL_CONF_MCASP0_AXR0   (0x998)
#define CONTROL_CONF_MCASP0_AHCLKR   (0x99c)
#define CONTROL_CONF_MCASP0_ACLKR   (0x9a0)
#define CONTROL_CONF_MCASP0_FSR   (0x9a4)
#define CONTROL_CONF_MCASP0_AXR1   (0x9a8)
#define CONTROL_CONF_MCASP0_AHCLKX   (0x9ac)
#define CONTROL_CONF_XDMA_EVENT_INTR(n)   (0x9b0 + (n * 4))
#define CONTROL_CONF_NRESETIN_OUT   (0x9b8)
#define CONTROL_CONF_PORZ   (0x9bc)
#define CONTROL_CONF_NNMI   (0x9c0)
#define CONTROL_CONF_OSC_IN(n)   (0x9c4 + (n * 0x24))
#define CONTROL_CONF_OSC_OUT(n)   (0x9c8 + (n * 0x24))
#define CONTROL_CONF_OSC_VSS(n)   (0x9cc + (n * 0x24))
#define CONTROL_CONF_TMS   (0x9d0)
#define CONTROL_CONF_TDI   (0x9d4)
#define CONTROL_CONF_TDO   (0x9d8)
#define CONTROL_CONF_TCK   (0x9dc)
#define CONTROL_CONF_NTRST   (0x9e0)
#define CONTROL_CONF_EMU(n)   (0x9e4 + (n * 4))
#define CONTROL_CONF_RTC_PORZ   (0x9f8)
#define CONTROL_CONF_PMIC_POWER_EN   (0x9fc)
#define CONTROL_CONF_EXT_WAKEUP   (0xa00)
#define CONTROL_CONF_ENZ_KALDO_1P8V   (0xa04)
#define CONTROL_CONF_USB_DM(n)   (0xa08 + ((n) * 0x18))
#define CONTROL_CONF_USB_DP(n)   (0xa0c + ((n) * 0x18))
#define CONTROL_CONF_USB_CE(n)   (0xa10 + ((n) * 0x18))
#define CONTROL_CONF_USB_ID(n)   (0xa14 + ((n) * 0x18))
#define CONTROL_CONF_USB_VBUS(n)   (0xa18 + ((n) * 0x18))
#define CONTROL_CONF_USB_DRVVBUS(n)   (0xa1c + ((n) * 0x18))
#define CONTROL_CONF_DDR_RESETN   (0xa38)
#define CONTROL_CONF_DDR_CSN0   (0xa3c)
#define CONTROL_CONF_DDR_CKE   (0xa40)
#define CONTROL_CONF_DDR_CK    (0xa44)
#define CONTROL_CONF_DDR_NCK   (0xa48)
#define CONTROL_CONF_DDR_CASN   (0xa4c)
#define CONTROL_CONF_DDR_RASN   (0xa50)
#define CONTROL_CONF_DDR_WEN   (0xa54)
#define CONTROL_CONF_DDR_BA(n)   (0xa58 + (n * 4))
#define CONTROL_CONF_DDR_A(n)   (0xa64 + (n * 4))
#define CONTROL_CONF_DDR_ODT   (0xaa4)
#define CONTROL_CONF_DDR_D(n)   (0xaa8 + (n * 4))
#define CONTROL_CONF_DDR_DQM(n)   (0xae8 + (n * 4))
#define CONTROL_CONF_DDR_DQS(n)   (0xaf0 + (n * 8))
#define CONTROL_CONF_DDR_DQSN(n)   (0xaf4 + (n * 8))
#define CONTROL_CONF_DDR_VREF   (0xb00)
#define CONTROL_CONF_DDR_VTP   (0xb04)
#define CONTROL_CONF_DDR_STRBEN(n)   (0xb08 + (n * 4))
#define CONTROL_CONF_AIN0    (0xb2c)
#define CONTROL_CONF_AIN1    (0xb28)
#define CONTROL_CONF_AIN2    (0xb24)
#define CONTROL_CONF_AIN3    (0xb20)
#define CONTROL_CONF_AIN4    (0xb1c)
#define CONTROL_CONF_AIN5    (0xb18)
#define CONTROL_CONF_AIN6    (0xb14)
#define CONTROL_CONF_AIN7    (0xb10)
#define CONTROL_CONF_VREFP   (0xb30)
#define CONTROL_CONF_VREFN   (0xb34)
#define CONTROL_CONF_AVDD   (0xb38)
#define CONTROL_CONF_AVSS   (0xb3c)
#define CONTROL_CONF_IFORCE   (0xb40)
#define CONTROL_CONF_VSENSE   (0xb44)
#define CONTROL_CONF_TESTOUT   (0xb48)
#define CONTROL_CQDETECT_STATUS   (0xe00)
#define CONTROL_DDR_IO_CTRL   (0xe04)
#define CONTROL_VTP_CTRL   (0xe0c)
#define CONTROL_VREF_CTRL   (0xe14)
#define CONTROL_SERDES_REFCLK_CTL   (0xe24)
#define CONTROL_TPCC_EVT_MUX_0_3   (0xf90)
#define CONTROL_TPCC_EVT_MUX_4_7   (0xf94)
#define CONTROL_TPCC_EVT_MUX_8_11   (0xf98)
#define CONTROL_TPCC_EVT_MUX_12_15   (0xf9c)
#define CONTROL_TPCC_EVT_MUX_16_19   (0xfa0)
#define CONTROL_TPCC_EVT_MUX_20_23   (0xfa4)
#define CONTROL_TPCC_EVT_MUX_24_27   (0xfa8)
#define CONTROL_TPCC_EVT_MUX_28_31   (0xfac)
#define CONTROL_TPCC_EVT_MUX_32_35   (0xfb0)
#define CONTROL_TPCC_EVT_MUX_36_39   (0xfb4)
#define CONTROL_TPCC_EVT_MUX_40_43   (0xfb8)
#define CONTROL_TPCC_EVT_MUX_44_47   (0xfbc)
#define CONTROL_TPCC_EVT_MUX_48_51   (0xfc0)
#define CONTROL_TPCC_EVT_MUX_52_55   (0xfc4)
#define CONTROL_TPCC_EVT_MUX_56_59   (0xfc8)
#define CONTROL_TPCC_EVT_MUX_60_63   (0xfcc)
#define CONTROL_TIMER_EVT_CAPT   (0xfd0)
#define CONTROL_ECAP_EVT_CAPT   (0xfd4)
#define CONTROL_ADC_EVT_CAPT   (0xfd8)
#define CONTROL_RESET_ISO   (0x1000)
#define CONTROL_SMA(n)   (0x1318 + (n * 8))
#define CONTROL_DDR_CKE_CTRL   (0x131c)
#define CONTROL_M3_TXEV_EOI   (0x1324)
#define CONTROL_IPC_MSG_REG(n)   (0x1328 + (n * 4))
#define CONTROL_DDR_CMD_IOCTRL(n)   (0x1404 + (n * 4))
#define CONTROL_DDR_DATA_IOCTRL(n)   (0x1440 + (n * 4))


#define CONTROL_CONF_PULLUDDISABLE     0x00000008 
#define CONTROL_CONF_PULLUPSEL         0x00000010
#define CONTROL_CONF_RXACTIVE          0x00000020 
#define CONTROL_CONF_SLOWSLEW          0x00000040
#define CONTROL_CONF_MUXMODE(n)        (n)



/* PWMSS_CTRL */
#define CONTROL_PWMSS_CTRL_PWMSS1_TBCLKEN   (0x00000002u)
#define CONTROL_PWMSS_CTRL_PWMSS1_TBCLKEN_SHIFT   (0x00000001u)

#define CONTROL_PWMSS_CTRL_PWMSS0_TBCLKEN   (0x00000001u)
#define CONTROL_PWMSS_CTRL_PWMSS0_TBCLKEN_SHIFT   (0x00000000u)

#define CONTROL_PWMSS_CTRL_PWMSS2_TBCLKEN   (0x00000004u)
#define CONTROL_PWMSS_CTRL_PWMSS2_TBCLKEN_SHIFT   (0x00000002u)









/*************************************************************************\
 * Registers Definition
\*************************************************************************/

#define CM_WKUP_CLKSTCTRL   (0x0)
#define CM_WKUP_CONTROL_CLKCTRL   (0x4)
#define CM_WKUP_GPIO0_CLKCTRL   (0x8)
#define CM_WKUP_L4WKUP_CLKCTRL   (0xc)
#define CM_WKUP_TIMER0_CLKCTRL   (0x10)
#define CM_WKUP_DEBUGSS_CLKCTRL   (0x14)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL   (0x18)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU   (0x1c)
#define CM_WKUP_CM_IDLEST_DPLL_MPU   (0x20)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_MPU   (0x24)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_MPU   (0x28)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU   (0x2c)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR   (0x30)
#define CM_WKUP_CM_IDLEST_DPLL_DDR   (0x34)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_DDR   (0x38)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DDR   (0x3c)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR   (0x40)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP   (0x44)
#define CM_WKUP_CM_IDLEST_DPLL_DISP   (0x48)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_DISP   (0x4c)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DISP   (0x50)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP   (0x54)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE   (0x58)
#define CM_WKUP_CM_IDLEST_DPLL_CORE   (0x5c)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_CORE   (0x60)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_CORE   (0x64)
#define CM_WKUP_CM_CLKSEL_DPLL_CORE   (0x68)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER   (0x6c)
#define CM_WKUP_CM_IDLEST_DPLL_PER   (0x70)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_PER   (0x74)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_PER   (0x78)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER   (0x7c)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE   (0x80)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE   (0x84)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU   (0x88)
#define CM_WKUP_CM_CLKMODE_DPLL_PER   (0x8c)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE   (0x90)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR   (0x94)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP   (0x98)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH   (0x9c)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR   (0xa0)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP   (0xa4)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU   (0xa8)
#define CM_WKUP_CM_DIV_M2_DPLL_PER   (0xac)
#define CM_WKUP_WKUP_M3_CLKCTRL   (0xb0)
#define CM_WKUP_UART0_CLKCTRL   (0xb4)
#define CM_WKUP_I2C0_CLKCTRL   (0xb8)
#define CM_WKUP_ADC_TSC_CLKCTRL   (0xbc)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL   (0xc0)
#define CM_WKUP_TIMER1_CLKCTRL   (0xc4)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL   (0xc8)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL   (0xcc)
#define CM_WKUP_WDT0_CLKCTRL   (0xd0)
#define CM_WKUP_WDT1_CLKCTRL   (0xd4)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE   (0xd8)

/**************************************************************************\ 
 * Field Definition Macros
\**************************************************************************/

/* CLKSTCTRL */
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_ADC_FCLK   (0x00004000u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_ADC_FCLK_SHIFT   (0x0000000Eu)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_ADC_FCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_ADC_FCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_GPIO0_GDBCLK   (0x00000100u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_GPIO0_GDBCLK_SHIFT   (0x00000008u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_GPIO0_GDBCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_GPIO0_GDBCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_I2C0_GFCLK   (0x00000800u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_I2C0_GFCLK_SHIFT   (0x0000000Bu)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_I2C0_GFCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_I2C0_GFCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_L4_WKUP_GCLK   (0x00000004u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_L4_WKUP_GCLK_SHIFT   (0x00000002u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_L4_WKUP_GCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_L4_WKUP_GCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_SR_SYSCLK   (0x00000008u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_SR_SYSCLK_SHIFT   (0x00000003u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_SR_SYSCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_SR_SYSCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER0_GCLK   (0x00000400u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER0_GCLK_SHIFT   (0x0000000Au)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER0_GCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER0_GCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER1_GCLK   (0x00002000u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER1_GCLK_SHIFT   (0x0000000Du)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER1_GCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_TIMER1_GCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_UART0_GFCLK   (0x00001000u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_UART0_GFCLK_SHIFT   (0x0000000Cu)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_UART0_GFCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_UART0_GFCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT0_GCLK   (0x00000200u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT0_GCLK_SHIFT   (0x00000009u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT0_GCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT0_GCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT1_GCLK   (0x00000010u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT1_GCLK_SHIFT   (0x00000004u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT1_GCLK_ACT   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKACTIVITY_WDT1_GCLK_INACT   (0x0u)

#define CM_WKUP_CLKSTCTRL_CLKTRCTRL   (0x00000003u)
#define CM_WKUP_CLKSTCTRL_CLKTRCTRL_SHIFT   (0x00000000u)
#define CM_WKUP_CLKSTCTRL_CLKTRCTRL_HW_AUTO   (0x3u)
#define CM_WKUP_CLKSTCTRL_CLKTRCTRL_NO_SLEEP   (0x0u)
#define CM_WKUP_CLKSTCTRL_CLKTRCTRL_SW_SLEEP   (0x1u)
#define CM_WKUP_CLKSTCTRL_CLKTRCTRL_SW_WKUP   (0x2u)


/* CONTROL_CLKCTRL */
#define CM_WKUP_CONTROL_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_CONTROL_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_CONTROL_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_CONTROL_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_CONTROL_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_CONTROL_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_CONTROL_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_CONTROL_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_CONTROL_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_CONTROL_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_CONTROL_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_CONTROL_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* GPIO0_CLKCTRL */
#define CM_WKUP_GPIO0_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_GPIO0_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_GPIO0_CLKCTRL_IDLEST_DISABLED   (0x3u)
#define CM_WKUP_GPIO0_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_GPIO0_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_GPIO0_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_GPIO0_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_GPIO0_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_GPIO0_CLKCTRL_MODULEMODE_DISABLE   (0x0u)
#define CM_WKUP_GPIO0_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_GPIO0_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_GPIO0_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)

#define CM_WKUP_GPIO0_CLKCTRL_OPTFCLKEN_GPIO0_GDBCLK   (0x00040000u)
#define CM_WKUP_GPIO0_CLKCTRL_OPTFCLKEN_GPIO0_GDBCLK_SHIFT   (0x00000012u)
#define CM_WKUP_GPIO0_CLKCTRL_OPTFCLKEN_GPIO0_GDBCLK_FCLK_DIS   (0x0u)
#define CM_WKUP_GPIO0_CLKCTRL_OPTFCLKEN_GPIO0_GDBCLK_FCLK_EN   (0x1u)


/* L4WKUP_CLKCTRL */
#define CM_WKUP_L4WKUP_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_L4WKUP_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_L4WKUP_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_L4WKUP_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_L4WKUP_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_L4WKUP_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_L4WKUP_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_L4WKUP_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_L4WKUP_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_L4WKUP_CLKCTRL_MODULEMODE_DISABLE  (0x0u)


/* TIMER0_CLKCTRL */
#define CM_WKUP_TIMER0_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_TIMER0_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_TIMER0_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_TIMER0_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_TIMER0_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_TIMER0_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_TIMER0_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_TIMER0_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_TIMER0_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_TIMER0_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_TIMER0_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_TIMER0_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* DEBUGSS_CLKCTRL */
#define CM_WKUP_DEBUGSS_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_DEBUGSS_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_DEBUGSS_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_DEBUGSS_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_DEBUGSS_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_DEBUGSS_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_DEBUGSS_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_DEBUGSS_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_DEBUGSS_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_DEBUGSS_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)

#define CM_WKUP_DEBUGSS_CLKCTRL_OPTCLK_DEBUG_CLKA   (0x40000000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_OPTCLK_DEBUG_CLKA_SHIFT   (0x0000001Eu)

#define CM_WKUP_DEBUGSS_CLKCTRL_OPTFCLKEN_DBGSYSCLK   (0x00080000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_OPTFCLKEN_DBGSYSCLK_SHIFT   (0x00000013u)
#define CM_WKUP_DEBUGSS_CLKCTRL_OPTFCLKEN_DBGSYSCLK_FCLK_DIS   (0x0u)
#define CM_WKUP_DEBUGSS_CLKCTRL_OPTFCLKEN_DBGSYSCLK_FCLK_EN   (0x1u)

#define CM_WKUP_DEBUGSS_CLKCTRL_STBYST   (0x00040000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_STBYST_SHIFT   (0x00000012u)
#define CM_WKUP_DEBUGSS_CLKCTRL_STBYST_FUNC   (0x0u)
#define CM_WKUP_DEBUGSS_CLKCTRL_STBYST_STANDBY   (0x1u)

#define CM_WKUP_DEBUGSS_CLKCTRL_STM_PMD_CLKDIVSEL   (0x38000000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_STM_PMD_CLKDIVSEL_SHIFT   (0x0000001Bu)

#define CM_WKUP_DEBUGSS_CLKCTRL_STM_PMD_CLKSEL   (0x00C00000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_STM_PMD_CLKSEL_SHIFT   (0x00000016u)

#define CM_WKUP_DEBUGSS_CLKCTRL_TRC_PMD_CLKDIVSEL   (0x07000000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_TRC_PMD_CLKDIVSEL_SHIFT   (0x00000018u)

#define CM_WKUP_DEBUGSS_CLKCTRL_TRC_PMD_CLKSEL   (0x00300000u)
#define CM_WKUP_DEBUGSS_CLKCTRL_TRC_PMD_CLKSEL_SHIFT   (0x00000014u)


/* CM_L3_AON_CLKSTCTRL */
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_DBGSYSCLK   (0x00000004u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_DBGSYSCLK_SHIFT   (0x00000002u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_DBGSYSCLK_ACT   (0x1u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_DBGSYSCLK_INACT   (0x0u)

#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_DEBUG_CLKA   (0x00000010u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_DEBUG_CLKA_SHIFT   (0x00000004u)

#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_L3_AON_GCLK   (0x00000008u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_L3_AON_GCLK_SHIFT   (0x00000003u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_L3_AON_GCLK_ACT   (0x1u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKACTIVITY_L3_AON_GCLK_INACT   (0x0u)

#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKTRCTRL   (0x00000003u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKTRCTRL_SHIFT   (0x00000000u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKTRCTRL_HW_AUTO   (0x3u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKTRCTRL_NO_SLEEP   (0x0u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKTRCTRL_SW_SLEEP   (0x1u)
#define CM_WKUP_CM_L3_AON_CLKSTCTRL_CLKTRCTRL_SW_WKUP   (0x2u)


/* CM_AUTOIDLE_DPLL_MPU */
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE   (0x00000007u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_SHIFT   (0x00000000u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_AUTO_CTL_DISABLE   (0x0u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_AUTO_LP_BYP   (0x5u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_AUTO_LP_STOP   (0x1u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_RESERVED2   (0x2u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_RESERVED3   (0x3u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_RESERVED4   (0x4u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_RESERVED6   (0x6u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_MPU_AUTO_DPLL_MODE_RESERVED7   (0x7u)


/* CM_IDLEST_DPLL_MPU */
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_DPLL_CLK   (0x00000001u)
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_DPLL_CLK_SHIFT   (0x00000000u)
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_DPLL_CLK_DPLL_LOCKED   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_DPLL_CLK_DPLL_UNLOCKED   (0x0u)

#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_MN_BYPASS   (0x00000100u)
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_MN_BYPASS_SHIFT   (0x00000008u)
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_MN_BYPASS_MN_BYPASS   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_MPU_ST_MN_BYPASS_NO_MNBYPASS   (0x0u)


/* CM_SSC_DELTAMSTEP_DPLL_MPU */
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_MPU_DELTAMSTEP   (0x000FFFFFu)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_MPU_DELTAMSTEP_SHIFT   (0x00000000u)


/* CM_SSC_MODFREQDIV_DPLL_MPU */
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_MPU_MODFREQDIV_EXPONENT   (0x00000700u)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_MPU_MODFREQDIV_EXPONENT_SHIFT   (0x00000008u)

#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_MPU_MODFREQDIV_MANTISSA   (0x0000007Fu)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_MPU_MODFREQDIV_MANTISSA_SHIFT   (0x00000000u)


/* CM_CLKSEL_DPLL_MPU */
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_BYP_CLKSEL   (0x00800000u)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_BYP_CLKSEL_SHIFT   (0x00000017u)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_BYP_CLKSEL_SEL0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_BYP_CLKSEL_SEL1   (0x1u)

#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_DIV   (0x0000007Fu)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_DIV_SHIFT   (0x00000000u)

#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_MULT   (0x0007FF00u)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_MULT_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_MULT_0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_MPU_DPLL_MULT_1   (0x1u)


/* CM_AUTOIDLE_DPLL_DDR */
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE   (0x00000007u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_SHIFT   (0x00000000u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_AUTO_CTL_DISABLE   (0x0u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_AUTO_LP_BYP   (0x5u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_AUTO_LP_STOP   (0x1u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_RESERVED2   (0x2u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_RESERVED3   (0x3u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_RESERVED4   (0x4u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_RESERVED6   (0x6u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DDR_AUTO_DPLL_MODE_RESERVED7   (0x7u)


/* CM_IDLEST_DPLL_DDR */
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_DPLL_CLK   (0x00000001u)
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_DPLL_CLK_SHIFT   (0x00000000u)
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_DPLL_CLK_DPLL_LOCKED   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_DPLL_CLK_DPLL_UNLOCKED   (0x0u)

#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_MN_BYPASS   (0x00000100u)
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_MN_BYPASS_SHIFT   (0x00000008u)
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_MN_BYPASS_MN_BYPASS   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_DDR_ST_MN_BYPASS_NO_MNBYPASS   (0x0u)


/* CM_SSC_DELTAMSTEP_DPLL_DDR */
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_DDR_DELTAMSTEP   (0x000FFFFFu)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_DDR_DELTAMSTEP_SHIFT   (0x00000000u)


/* CM_SSC_MODFREQDIV_DPLL_DDR */
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DDR_MODFREQDIV_EXPONENT   (0x00000700u)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DDR_MODFREQDIV_EXPONENT_SHIFT   (0x00000008u)

#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DDR_MODFREQDIV_MANTISSA   (0x0000007Fu)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DDR_MODFREQDIV_MANTISSA_SHIFT   (0x00000000u)


/* CM_CLKSEL_DPLL_DDR */
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_BYP_CLKSEL   (0x00800000u)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_BYP_CLKSEL_SHIFT   (0x00000017u)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_BYP_CLKSEL_SEL0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_BYP_CLKSEL_SEL1   (0x1u)

#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_DIV   (0x0000007Fu)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_DIV_SHIFT   (0x00000000u)

#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_MULT   (0x0007FF00u)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_MULT_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_MULT_0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_DDR_DPLL_MULT_1   (0x1u)


/* CM_AUTOIDLE_DPLL_DISP */
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE   (0x00000007u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_SHIFT   (0x00000000u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_AUTO_CTL_DISABLE   (0x0u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_AUTO_LP_BYP   (0x5u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_AUTO_LP_STOP   (0x1u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_RESERVED2   (0x2u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_RESERVED3   (0x3u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_RESERVED4   (0x4u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_RESERVED6   (0x6u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_DISP_AUTO_DPLL_MODE_RESERVED7   (0x7u)


/* CM_IDLEST_DPLL_DISP */
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_DPLL_CLK   (0x00000001u)
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_DPLL_CLK_SHIFT   (0x00000000u)
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_DPLL_CLK_DPLL_LOCKED   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_DPLL_CLK_DPLL_UNLOCKED   (0x0u)

#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_MN_BYPASS   (0x00000100u)
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_MN_BYPASS_SHIFT   (0x00000008u)
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_MN_BYPASS_MN_BYPASS   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_DISP_ST_MN_BYPASS_NO_MNBYPASS   (0x0u)


/* CM_SSC_DELTAMSTEP_DPLL_DISP */
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_DISP_DELTAMSTEP   (0x000FFFFFu)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_DISP_DELTAMSTEP_SHIFT   (0x00000000u)


/* CM_SSC_MODFREQDIV_DPLL_DISP */
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DISP_MODFREQDIV_EXPONENT   (0x00000700u)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DISP_MODFREQDIV_EXPONENT_SHIFT   (0x00000008u)

#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DISP_MODFREQDIV_MANTISSA   (0x0000007Fu)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_DISP_MODFREQDIV_MANTISSA_SHIFT   (0x00000000u)


/* CM_CLKSEL_DPLL_DISP */
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_BYP_CLKSEL   (0x00800000u)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_BYP_CLKSEL_SHIFT   (0x00000017u)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_BYP_CLKSEL_SEL0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_BYP_CLKSEL_SEL1   (0x1u)

#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_DIV   (0x0000007Fu)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_DIV_SHIFT   (0x00000000u)

#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_MULT   (0x0007FF00u)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_MULT_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_MULT_0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_DISP_DPLL_MULT_1   (0x1u)


/* CM_AUTOIDLE_DPLL_CORE */
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE   (0x00000007u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_SHIFT   (0x00000000u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_AUTO_CTL_DISABLE   (0x0u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_AUTO_LP_BYP   (0x5u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_AUTO_LP_STOP   (0x1u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_RESERVED2   (0x2u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_RESERVED3   (0x3u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_RESERVED4   (0x4u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_RESERVED6   (0x6u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_CORE_AUTO_DPLL_MODE_RESERVED7   (0x7u)


/* CM_IDLEST_DPLL_CORE */
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_DPLL_CLK   (0x00000001u)
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_DPLL_CLK_SHIFT   (0x00000000u)
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_DPLL_CLK_DPLL_LOCKED   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_DPLL_CLK_DPLL_UNLOCKED   (0x0u)

#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_MN_BYPASS   (0x00000100u)
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_MN_BYPASS_SHIFT   (0x00000008u)
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_MN_BYPASS_MN_BYPASS   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_CORE_ST_MN_BYPASS_NO_MNBYPASS   (0x0u)


/* CM_SSC_DELTAMSTEP_DPLL_CORE */
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_CORE_DELTAMSTEP   (0x000FFFFFu)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_CORE_DELTAMSTEP_SHIFT   (0x00000000u)


/* CM_SSC_MODFREQDIV_DPLL_CORE */
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_CORE_MODFREQDIV_EXPONENT   (0x00000700u)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_CORE_MODFREQDIV_EXPONENT_SHIFT   (0x00000008u)

#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_CORE_MODFREQDIV_MANTISSA   (0x0000007Fu)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_CORE_MODFREQDIV_MANTISSA_SHIFT   (0x00000000u)


/* CM_CLKSEL_DPLL_CORE */
#define CM_WKUP_CM_CLKSEL_DPLL_CORE_DPLL_DIV   (0x0000007Fu)
#define CM_WKUP_CM_CLKSEL_DPLL_CORE_DPLL_DIV_SHIFT   (0x00000000u)

#define CM_WKUP_CM_CLKSEL_DPLL_CORE_DPLL_MULT   (0x0007FF00u)
#define CM_WKUP_CM_CLKSEL_DPLL_CORE_DPLL_MULT_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKSEL_DPLL_CORE_DPLL_MULT_RESERVED_0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_CORE_DPLL_MULT_RESERVED_1   (0x1u)


/* CM_AUTOIDLE_DPLL_PER */
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE   (0x00000007u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_SHIFT   (0x00000000u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_AUTO_CTL_DISABLE   (0x0u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_AUTO_LP_BYP   (0x5u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_AUTO_LP_STOP   (0x1u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_RESERVED2   (0x2u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_RESERVED3   (0x3u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_RESERVED4   (0x4u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_RESERVED6   (0x6u)
#define CM_WKUP_CM_AUTOIDLE_DPLL_PER_AUTO_DPLL_MODE_RESERVED7   (0x7u)


/* CM_IDLEST_DPLL_PER */
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_DPLL_CLK   (0x00000001u)
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_DPLL_CLK_SHIFT   (0x00000000u)
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_DPLL_CLK_DPLL_LOCKED   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_DPLL_CLK_DPLL_UNLOCKED   (0x0u)

#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_MN_BYPASS   (0x00000100u)
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_MN_BYPASS_SHIFT   (0x00000008u)
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_MN_BYPASS_MN_BYPASS   (0x1u)
#define CM_WKUP_CM_IDLEST_DPLL_PER_ST_MN_BYPASS_NO_MNBYPASS   (0x0u)


/* CM_SSC_DELTAMSTEP_DPLL_PER */
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_PER_DELTAMSTEP   (0x000FFFFFu)
#define CM_WKUP_CM_SSC_DELTAMSTEP_DPLL_PER_DELTAMSTEP_SHIFT   (0x00000000u)


/* CM_SSC_MODFREQDIV_DPLL_PER */
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_PER_MODFREQDIV_EXPONENT   (0x00000700u)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_PER_MODFREQDIV_EXPONENT_SHIFT   (0x00000008u)

#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_PER_MODFREQDIV_MANTISSA   (0x0000007Fu)
#define CM_WKUP_CM_SSC_MODFREQDIV_DPLL_PER_MODFREQDIV_MANTISSA_SHIFT   (0x00000000u)


/* CM_CLKDCOLDO_DPLL_PER */
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_PWDN   (0x00001000u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_PWDN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_PWDN_ALWAYS_ACTIVE   (0x0u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_DPLL_CLKDCOLDO_PWDN_AUTO_PWDN   (0x1u)

#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_ST_DPLL_CLKDCOLDO   (0x00000200u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_ST_DPLL_CLKDCOLDO_SHIFT   (0x00000009u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_ST_DPLL_CLKDCOLDO_CLK_ENABLED   (0x0u)
#define CM_WKUP_CM_CLKDCOLDO_DPLL_PER_ST_DPLL_CLKDCOLDO_CLK_GATED   (0x1u)


/* CM_DIV_M4_DPLL_CORE */
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_DIV   (0x0000001Fu)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_DIVCHACK   (0x00000020u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_DIVCHACK_SHIFT   (0x00000005u)

#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_PWDN   (0x00001000u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_PWDN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_PWDN_ALWAYS_ACTIVE   (0x0u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_HSDIVIDER_CLKOUT1_PWDN_AUTO_PWDN   (0x1u)

#define CM_WKUP_CM_DIV_M4_DPLL_CORE_ST_HSDIVIDER_CLKOUT1   (0x00000200u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_ST_HSDIVIDER_CLKOUT1_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_ST_HSDIVIDER_CLKOUT1_CLK_ENABLED   (0x0u)
#define CM_WKUP_CM_DIV_M4_DPLL_CORE_ST_HSDIVIDER_CLKOUT1_CLK_GATED   (0x1u)


/* CM_DIV_M5_DPLL_CORE */
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_DIV   (0x0000001Fu)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_DIVCHACK   (0x00000020u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_DIVCHACK_SHIFT   (0x00000005u)

#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_PWDN   (0x00001000u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_PWDN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_PWDN_ALWAYS_ACTIVE   (0x0u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_HSDIVIDER_CLKOUT2_PWDN_AUTO_PWDN   (0x1u)

#define CM_WKUP_CM_DIV_M5_DPLL_CORE_ST_HSDIVIDER_CLKOUT2   (0x00000200u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_ST_HSDIVIDER_CLKOUT2_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_ST_HSDIVIDER_CLKOUT2_CLK_ENABLED   (0x0u)
#define CM_WKUP_CM_DIV_M5_DPLL_CORE_ST_HSDIVIDER_CLKOUT2_CLK_GATED   (0x1u)


/* CM_CLKMODE_DPLL_MPU */
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_DRIFTGUARD_EN   (0x00000100u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_DRIFTGUARD_EN_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_DRIFTGUARD_EN_DIASBLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_DRIFTGUARD_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN   (0x00000007u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_SHIFT   (0x00000000u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_DPLL_FR_BYP_MODE   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_DPLL_LOCK_MODE   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_DPLL_LP_BYP_MODE   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_DPLL_MN_BYP_MODE   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_RESERVED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_RESERVED1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_RESERVED2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_EN_RESERVED3   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_LPMODE_EN   (0x00000400u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_LPMODE_EN_SHIFT   (0x0000000Au)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_LPMODE_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_LPMODE_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_LEVEL   (0x00000018u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_LEVEL_SHIFT   (0x00000003u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_LEVEL_RAMP_ALGO1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_LEVEL_RAMP_ALGO2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_LEVEL_RAMP_DISABLE   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_LEVEL_RESERVED   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE   (0x000000E0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_SHIFT   (0x00000005u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX128   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX16   (0x3u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX2   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX32   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX4   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX512   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX64   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RAMP_RATE_REFCLKX8   (0x2u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_REGM4XEN   (0x00000800u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_REGM4XEN_SHIFT   (0x0000000Bu)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_REGM4XEN_DISABLED   (0x0u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RELOCK_RAMP_EN   (0x00000200u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_RELOCK_RAMP_EN_SHIFT   (0x00000009u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_ACK   (0x00002000u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_ACK_SHIFT   (0x0000000Du)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_ACK_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_ACK_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_DOWNSPREAD   (0x00004000u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_DOWNSPREAD_SHIFT   (0x0000000Eu)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_DOWNSPREAD_FULL_SPREAD   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_DOWNSPREAD_LOW_SPREAD   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_EN   (0x00001000u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_EN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_TYPE   (0x00008000u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_TYPE_SHIFT   (0x0000000Fu)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_TYPE_SQUARE   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_MPU_DPLL_SSC_TYPE_TRIANGULAR   (0x0u)


/* CM_CLKMODE_DPLL_PER */
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN   (0x00000007u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_SHIFT   (0x00000000u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_DPLL_LOCK_MODE   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_DPLL_LP_BYP_MODE   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_DPLL_LP_STP_MODE   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_DPLL_MN_BYP_MODE   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_RESERVED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_RESERVED2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_RESERVED3   (0x3u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_EN_RESERVED6   (0x6u)

#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_ACK   (0x00002000u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_ACK_SHIFT   (0x0000000Du)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_ACK_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_ACK_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_DOWNSPREAD   (0x00004000u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_DOWNSPREAD_SHIFT   (0x0000000Eu)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_DOWNSPREAD_FULL_SPREAD   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_DOWNSPREAD_LOW_SPREAD   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_EN   (0x00001000u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_EN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_TYPE   (0x00008000u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_TYPE_SHIFT   (0x0000000Fu)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_TYPE_SQUARE   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_PER_DPLL_SSC_TYPE_TRIANGULAR   (0x0u)


/* CM_CLKMODE_DPLL_CORE */
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_DRIFTGUARD_EN   (0x00000100u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_DRIFTGUARD_EN_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_DRIFTGUARD_EN_DIASBLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_DRIFTGUARD_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN   (0x00000007u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_SHIFT   (0x00000000u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_DPLL_FR_BYP_MODE   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_DPLL_LOCK_MODE   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_DPLL_LP_BYP_MODE   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_DPLL_MN_BYP_MODE   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_RESERVED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_RESERVED1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_RESERVED2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_EN_RESERVED3   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_LPMODE_EN   (0x00000400u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_LPMODE_EN_SHIFT   (0x0000000Au)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_LPMODE_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_LPMODE_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_LEVEL   (0x00000018u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_LEVEL_SHIFT   (0x00000003u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_LEVEL_RAMP_ALGO1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_LEVEL_RAMP_ALGO2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_LEVEL_RAMP_DISABLE   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_LEVEL_RESERVED   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE   (0x000000E0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_SHIFT   (0x00000005u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX128   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX16   (0x3u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX2   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX32   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX4   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX512   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX64   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RAMP_RATE_REFCLKX8   (0x2u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_REGM4XEN   (0x00000800u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_REGM4XEN_SHIFT   (0x0000000Bu)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_REGM4XEN_DISABLED   (0x0u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RELOCK_RAMP_EN   (0x00000200u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_RELOCK_RAMP_EN_SHIFT   (0x00000009u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_ACK   (0x00002000u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_ACK_SHIFT   (0x0000000Du)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_ACK_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_ACK_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_DOWNSPREAD   (0x00004000u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_DOWNSPREAD_SHIFT   (0x0000000Eu)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_DOWNSPREAD_FULL_SPREAD   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_DOWNSPREAD_LOW_SPREAD   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_EN   (0x00001000u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_EN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_TYPE   (0x00008000u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_TYPE_SHIFT   (0x0000000Fu)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_TYPE_SQUARE   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_CORE_DPLL_SSC_TYPE_TRIANGULAR   (0x0u)


/* CM_CLKMODE_DPLL_DDR */
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_DRIFTGUARD_EN   (0x00000100u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_DRIFTGUARD_EN_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_DRIFTGUARD_EN_DIASBLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_DRIFTGUARD_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN   (0x00000007u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_SHIFT   (0x00000000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_DPLL_FR_BYP_MODE   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_DPLL_LOCK_MODE   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_DPLL_LP_BYP_MODE   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_DPLL_MN_BYP_MODE   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_RESERVED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_RESERVED1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_RESERVED2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_EN_RESERVED3   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_LPMODE_EN   (0x00000400u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_LPMODE_EN_SHIFT   (0x0000000Au)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_LPMODE_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_LPMODE_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_LEVEL   (0x00000018u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_LEVEL_SHIFT   (0x00000003u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_LEVEL_RAMP_ALGO1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_LEVEL_RAMP_ALGO2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_LEVEL_RAMP_DISABLE   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_LEVEL_RESERVED   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE   (0x000000E0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_SHIFT   (0x00000005u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX128   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX16   (0x3u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX2   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX32   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX4   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX512   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX64   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RAMP_RATE_REFCLKX8   (0x2u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_REGM4XEN   (0x00000800u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_REGM4XEN_SHIFT   (0x0000000Bu)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_REGM4XEN_DISABLED   (0x0u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RELOCK_RAMP_EN   (0x00000200u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_RELOCK_RAMP_EN_SHIFT   (0x00000009u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_ACK   (0x00002000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_ACK_SHIFT   (0x0000000Du)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_ACK_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_ACK_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_DOWNSPREAD   (0x00004000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_DOWNSPREAD_SHIFT   (0x0000000Eu)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_DOWNSPREAD_FULL_SPREAD   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_DOWNSPREAD_LOW_SPREAD   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_EN   (0x00001000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_EN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_TYPE   (0x00008000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_TYPE_SHIFT   (0x0000000Fu)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_TYPE_SQUARE   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DDR_DPLL_SSC_TYPE_TRIANGULAR   (0x0u)


/* CM_CLKMODE_DPLL_DISP */
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_DRIFTGUARD_EN   (0x00000100u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_DRIFTGUARD_EN_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_DRIFTGUARD_EN_DIASBLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_DRIFTGUARD_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN   (0x00000007u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_SHIFT   (0x00000000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_DPLL_FR_BYP_MODE   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_DPLL_LOCK_MODE   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_DPLL_LP_BYP_MODE   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_DPLL_MN_BYP_MODE   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_RESERVED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_RESERVED1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_RESERVED2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_EN_RESERVED3   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_LPMODE_EN   (0x00000400u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_LPMODE_EN_SHIFT   (0x0000000Au)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_LPMODE_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_LPMODE_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_LEVEL   (0x00000018u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_LEVEL_SHIFT   (0x00000003u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_LEVEL_RAMP_ALGO1   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_LEVEL_RAMP_ALGO2   (0x2u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_LEVEL_RAMP_DISABLE   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_LEVEL_RESERVED   (0x3u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE   (0x000000E0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_SHIFT   (0x00000005u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX128   (0x6u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX16   (0x3u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX2   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX32   (0x4u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX4   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX512   (0x7u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX64   (0x5u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RAMP_RATE_REFCLKX8   (0x2u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_REGM4XEN   (0x00000800u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_REGM4XEN_SHIFT   (0x0000000Bu)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_REGM4XEN_DISABLED   (0x0u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RELOCK_RAMP_EN   (0x00000200u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_RELOCK_RAMP_EN_SHIFT   (0x00000009u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_ACK   (0x00002000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_ACK_SHIFT   (0x0000000Du)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_ACK_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_ACK_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_DOWNSPREAD   (0x00004000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_DOWNSPREAD_SHIFT   (0x0000000Eu)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_DOWNSPREAD_FULL_SPREAD   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_DOWNSPREAD_LOW_SPREAD   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_EN   (0x00001000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_EN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_EN_DISABLED   (0x0u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_EN_ENABLED   (0x1u)

#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_TYPE   (0x00008000u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_TYPE_SHIFT   (0x0000000Fu)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_TYPE_SQUARE   (0x1u)
#define CM_WKUP_CM_CLKMODE_DPLL_DISP_DPLL_SSC_TYPE_TRIANGULAR   (0x0u)


/* CM_CLKSEL_DPLL_PERIPH */
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_DIV   (0x000000FFu)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_DIV_SHIFT   (0x00000000u)

#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_MULT   (0x000FFF00u)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_MULT_SHIFT   (0x00000008u)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_MULT_0   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_MULT_1   (0x1u)

#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_SD_DIV   (0xFF000000u)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_SD_DIV_SHIFT   (0x00000018u)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_SD_DIV_RESERVED   (0x0u)
#define CM_WKUP_CM_CLKSEL_DPLL_PERIPH_DPLL_SD_DIV_RESERVED1   (0x1u)


/* CM_DIV_M2_DPLL_DDR */
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_DIV   (0x0000001Fu)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_DIVCHACK   (0x00000020u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_DIVCHACK_SHIFT   (0x00000005u)

#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_DPLL_CLKOUT_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M2_DPLL_DDR_ST_DPLL_CLKOUT   (0x00000200u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_ST_DPLL_CLKOUT_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_ST_DPLL_CLKOUT_CLK_ENABLED   (0x1u)
#define CM_WKUP_CM_DIV_M2_DPLL_DDR_ST_DPLL_CLKOUT_CLK_GATED   (0x0u)


/* CM_DIV_M2_DPLL_DISP */
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_DIV   (0x0000001Fu)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_DIVCHACK   (0x00000020u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_DIVCHACK_SHIFT   (0x00000005u)

#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_DPLL_CLKOUT_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M2_DPLL_DISP_ST_DPLL_CLKOUT   (0x00000200u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_ST_DPLL_CLKOUT_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_ST_DPLL_CLKOUT_CLK_ENABLED   (0x1u)
#define CM_WKUP_CM_DIV_M2_DPLL_DISP_ST_DPLL_CLKOUT_CLK_GATED   (0x0u)


/* CM_DIV_M2_DPLL_MPU */
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_DIV   (0x0000001Fu)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_DIVCHACK   (0x00000020u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_DIVCHACK_SHIFT   (0x00000005u)

#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_DPLL_CLKOUT_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M2_DPLL_MPU_ST_DPLL_CLKOUT   (0x00000200u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_ST_DPLL_CLKOUT_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_ST_DPLL_CLKOUT_CLK_ENABLED   (0x1u)
#define CM_WKUP_CM_DIV_M2_DPLL_MPU_ST_DPLL_CLKOUT_CLK_GATED   (0x0u)


/* CM_DIV_M2_DPLL_PER */
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_DIV   (0x0000007Fu)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_DIVCHACK   (0x00000080u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_DIVCHACK_SHIFT   (0x00000007u)

#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_DPLL_CLKOUT_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M2_DPLL_PER_ST_DPLL_CLKOUT   (0x00000200u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_ST_DPLL_CLKOUT_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_ST_DPLL_CLKOUT_CLK_ENABLED   (0x1u)
#define CM_WKUP_CM_DIV_M2_DPLL_PER_ST_DPLL_CLKOUT_CLK_GATED   (0x0u)


/* WKUP_M3_CLKCTRL */
#define CM_WKUP_WKUP_M3_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_WKUP_M3_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_WKUP_M3_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_WKUP_M3_CLKCTRL_MODULEMODE_DISABLE  (0x0u)

#define CM_WKUP_WKUP_M3_CLKCTRL_STBYST   (0x00040000u)
#define CM_WKUP_WKUP_M3_CLKCTRL_STBYST_SHIFT   (0x00000012u)
#define CM_WKUP_WKUP_M3_CLKCTRL_STBYST_FUNC   (0x0u)
#define CM_WKUP_WKUP_M3_CLKCTRL_STBYST_STANDBY   (0x1u)


/* UART0_CLKCTRL */
#define CM_WKUP_UART0_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_UART0_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_UART0_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_UART0_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_UART0_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_UART0_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_UART0_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_UART0_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_UART0_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_UART0_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_UART0_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_UART0_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* I2C0_CLKCTRL */
#define CM_WKUP_I2C0_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_I2C0_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_I2C0_CLKCTRL_IDLEST_DISABLED   (0x3u)
#define CM_WKUP_I2C0_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_I2C0_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_I2C0_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_I2C0_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_I2C0_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_I2C0_CLKCTRL_MODULEMODE_DISABLE   (0x0u)
#define CM_WKUP_I2C0_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_I2C0_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_I2C0_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* ADC_TSC_CLKCTRL */
#define CM_WKUP_ADC_TSC_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_ADC_TSC_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_ADC_TSC_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_ADC_TSC_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_ADC_TSC_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_ADC_TSC_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_ADC_TSC_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_ADC_TSC_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_ADC_TSC_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_ADC_TSC_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_ADC_TSC_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_ADC_TSC_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* SMARTREFLEX0_CLKCTRL */
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_SMARTREFLEX0_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_SMARTREFLEX0_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* TIMER1_CLKCTRL */
#define CM_WKUP_TIMER1_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_TIMER1_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_TIMER1_CLKCTRL_IDLEST_DISABLED   (0x3u)
#define CM_WKUP_TIMER1_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_TIMER1_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_TIMER1_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_TIMER1_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_TIMER1_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_TIMER1_CLKCTRL_MODULEMODE_DISABLE   (0x0u)
#define CM_WKUP_TIMER1_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_TIMER1_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_TIMER1_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* SMARTREFLEX1_CLKCTRL */
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_SMARTREFLEX1_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_SMARTREFLEX1_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* CM_L4_WKUP_AON_CLKSTCTRL */
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKACTIVITY_L4_WKUP_AON_GCLK   (0x00000004u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKACTIVITY_L4_WKUP_AON_GCLK_SHIFT   (0x00000002u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKACTIVITY_L4_WKUP_AON_GCLK_ACT   (0x1u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKACTIVITY_L4_WKUP_AON_GCLK_INACT   (0x0u)

#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKTRCTRL   (0x00000003u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKTRCTRL_SHIFT   (0x00000000u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKTRCTRL_NO_SLEEP   (0x0u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKTRCTRL_SW_SLEEP   (0x1u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKTRCTRL_SW_WKUP    (0x2u)
#define CM_WKUP_CM_L4_WKUP_AON_CLKSTCTRL_CLKTRCTRL_HW_AUTO    (0x3u)

/* WDT0_CLKCTRL */
#define CM_WKUP_WDT0_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_WDT0_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_WDT0_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_WDT0_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_WDT0_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_WDT0_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_WDT0_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_WDT0_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_WDT0_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_WDT0_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_WDT0_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_WDT0_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* WDT1_CLKCTRL */
#define CM_WKUP_WDT1_CLKCTRL_IDLEST   (0x00030000u)
#define CM_WKUP_WDT1_CLKCTRL_IDLEST_SHIFT   (0x00000010u)
#define CM_WKUP_WDT1_CLKCTRL_IDLEST_DISABLE   (0x3u)
#define CM_WKUP_WDT1_CLKCTRL_IDLEST_FUNC   (0x0u)
#define CM_WKUP_WDT1_CLKCTRL_IDLEST_IDLE   (0x2u)
#define CM_WKUP_WDT1_CLKCTRL_IDLEST_TRANS   (0x1u)

#define CM_WKUP_WDT1_CLKCTRL_MODULEMODE   (0x00000003u)
#define CM_WKUP_WDT1_CLKCTRL_MODULEMODE_SHIFT   (0x00000000u)
#define CM_WKUP_WDT1_CLKCTRL_MODULEMODE_DISABLED   (0x0u)
#define CM_WKUP_WDT1_CLKCTRL_MODULEMODE_ENABLE   (0x2u)
#define CM_WKUP_WDT1_CLKCTRL_MODULEMODE_RESERVED   (0x3u)
#define CM_WKUP_WDT1_CLKCTRL_MODULEMODE_RESERVED_1   (0x1u)


/* CM_DIV_M6_DPLL_CORE */
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_DIV   (0x0000001Fu)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_DIV_SHIFT   (0x00000000u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_DIV_RESERVED   (0x0u)

#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_DIVCHACK   (0x00000020u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_DIVCHACK_SHIFT   (0x00000005u)

#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_GATE_CTRL   (0x00000100u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_GATE_CTRL_SHIFT   (0x00000008u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_GATE_CTRL_CLK_AUTOGATE   (0x0u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_GATE_CTRL_CLK_ENABLE   (0x1u)

#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_PWDN   (0x00001000u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_PWDN_SHIFT   (0x0000000Cu)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_PWDN_ALWAYS_ACTIVE   (0x0u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_HSDIVIDER_CLKOUT3_PWDN_AUTO_PWDN   (0x1u)

#define CM_WKUP_CM_DIV_M6_DPLL_CORE_ST_HSDIVIDER_CLKOUT3   (0x00000200u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_ST_HSDIVIDER_CLKOUT3_SHIFT   (0x00000009u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_ST_HSDIVIDER_CLKOUT3_CLK_ENABLED   (0x0u)
#define CM_WKUP_CM_DIV_M6_DPLL_CORE_ST_HSDIVIDER_CLKOUT3_CLK_GATED   (0x1u)







// CM_WKUP (Clock Module Wake-up Registers)
#define CM_WKUP_START_ADDR              (0x44e00400)
#define CM_WKUP_SIZE                    (0x100)     // 256

#define OFFSET_CM_CLK_MODE_DPLL_DDR             (0x94)



//********************************************************************
//EMIF4DC module definitions
//********************************************************************
#define EMIF_REG_SIZE                     (0x1000000)         // 16 MB
#define EMIF_BASE_ADDR                    (0x4C000000)
#define EMIF_STATUS_REG                   (EMIF_BASE_ADDR + 0x004)
#define EMIF_SDRAM_CONFIG_REG             (EMIF_BASE_ADDR + 0x008)
#define EMIF_SDRAM_CONFIG_2_REG           (EMIF_BASE_ADDR + 0x00C)
#define EMIF_SDRAM_REF_CTRL_REG           (EMIF_BASE_ADDR + 0x010)
#define EMIF_SDRAM_REF_CTRL_SHDW_REG      (EMIF_BASE_ADDR + 0x014)
#define EMIF_SDRAM_TIM_1_REG              (EMIF_BASE_ADDR + 0x018)
#define EMIF_SDRAM_TIM_1_SHDW_REG         (EMIF_BASE_ADDR + 0x01C)
#define EMIF_SDRAM_TIM_2_REG              (EMIF_BASE_ADDR + 0x020)
#define EMIF_SDRAM_TIM_2_SHDW_REG         (EMIF_BASE_ADDR + 0x024)
#define EMIF_SDRAM_TIM_3_REG              (EMIF_BASE_ADDR + 0x028)
#define EMIF_SDRAM_TIM_3_SHDW_REG         (EMIF_BASE_ADDR + 0x02C)
#define EMIF_LPDDR2_NVM_TIM_REG           (EMIF_BASE_ADDR + 0x030)
#define EMIF_LPDDR2_NVM_TIM_SHDW_REG      (EMIF_BASE_ADDR + 0x034)
#define EMIF_PWR_MGMT_CTRL_REG            (EMIF_BASE_ADDR + 0x038)
#define EMIF_PWR_MGMT_CTRL_SHDW_REG       (EMIF_BASE_ADDR + 0x03C)
#define EMIF_LPDDR2_MODE_REG_DATA_REG     (EMIF_BASE_ADDR + 0x040)
#define EMIF_LPDDR2_MODE_REG_CFG_REG      (EMIF_BASE_ADDR + 0x050)
#define EMIF_OCP_CONFIG_REG               (EMIF_BASE_ADDR + 0x054)
#define EMIF_OCP_CFG_VAL_1_REG            (EMIF_BASE_ADDR + 0x058)
#define EMIF_OCP_CFG_VAL_2_REG            (EMIF_BASE_ADDR + 0x05C)
#define EMIF_IODFT_TLGC_REG               (EMIF_BASE_ADDR + 0x060)
#define EMIF_IODFT_CTRL_MISR_RSLT_REG     (EMIF_BASE_ADDR + 0x064)
#define EMIF_IODFT_ADDR_MISR_RSLT_REG     (EMIF_BASE_ADDR + 0x068)
#define EMIF_IODFT_DATA_MISR_RSLT_1_REG   (EMIF_BASE_ADDR + 0x06C)
#define EMIF_IODFT_DATA_MISR_RSLT_2_REG   (EMIF_BASE_ADDR + 0x070)
#define EMIF_IODFT_DATA_MISR_RSLT_3_REG   (EMIF_BASE_ADDR + 0x074)
#define EMIF_PERF_CNT_1_REG               (EMIF_BASE_ADDR + 0x080)
#define EMIF_PERF_CNT_2_REG               (EMIF_BASE_ADDR + 0x084)
#define EMIF_PERF_CNT_CFG_REG             (EMIF_BASE_ADDR + 0x088)
#define EMIF_PERF_CNT_SEL_REG             (EMIF_BASE_ADDR + 0x08C)
#define EMIF_PERF_CNT_TIM_REG             (EMIF_BASE_ADDR + 0x090)
#define EMIF_READ_IDLE_CTRL_REG           (EMIF_BASE_ADDR + 0x098)
#define EMIF_READ_IDLE_CTRL_SHDW_REG      (EMIF_BASE_ADDR + 0x09C)
#define EMIF_IRQ_EOI_REG                  (EMIF_BASE_ADDR + 0x0A0)
#define EMIF_IRQSTATUS_RAW_SYS_REG        (EMIF_BASE_ADDR + 0x0A4)
#define EMIF_IRQSTATUS_SYS_REG            (EMIF_BASE_ADDR + 0x0AC)
#define EMIF_IRQENABLE_SET_SYS_REG        (EMIF_BASE_ADDR + 0x0B4)
#define EMIF_IRQENABLE_CLR_SYS_REG        (EMIF_BASE_ADDR + 0x0BC)
#define EMIF_ZQ_CONFIG_REG                (EMIF_BASE_ADDR + 0x0C8)
#define EMIF_TEMP_ALERT_CONFIG_REG        (EMIF_BASE_ADDR + 0x0CC)
#define EMIF_OCP_ERR_LOG_REG              (EMIF_BASE_ADDR + 0x0D0)
#define EMIF_RDWR_LVL_RMP_WIN_REG         (EMIF_BASE_ADDR + 0x0D4)
#define EMIF_RDWR_LVL_RMP_CTRL_REG        (EMIF_BASE_ADDR + 0x0D8)
#define EMIF_RDWR_LVL_CTRL_REG            (EMIF_BASE_ADDR + 0x0DC)
#define EMIF_DDR_PHY_CTRL_1_REG           (EMIF_BASE_ADDR + 0x0E4)
#define EMIF_DDR_PHY_CTRL_1_SHDW_REG      (EMIF_BASE_ADDR + 0x0E8)
#define EMIF_DDR_PHY_CTRL_2_REG           (EMIF_BASE_ADDR + 0x0EC)
#define EMIF_PRI_COS_MAP_REG              (EMIF_BASE_ADDR + 0x100)
#define EMIF_CONNID_COS_1_MAP_REG         (EMIF_BASE_ADDR + 0x104)
#define EMIF_CONNID_COS_2_MAP_REG         (EMIF_BASE_ADDR + 0x108)
#define EMIF_RD_WR_EXEC_THRSH_REG         (EMIF_BASE_ADDR + 0x120)


//*******************************************************************
//DDR PHY registers
//*******************************************************************
#define    DDR_PHY_REG_SIZE                                    (0x400)
#define    DDR_PHY_BASE_ADDR                                   (0x44E12000)  
//CMD0
#define    CMD0_REG_PHY_CTRL_SLAVE_RATIO_0                     (0x01C + DDR_PHY_BASE_ADDR)
#define    CMD0_REG_PHY_CTRL_SLAVE_FORCE_0                     (0x020 + DDR_PHY_BASE_ADDR)
#define    CMD0_REG_PHY_CTRL_SLAVE_DELAY_0                     (0x024 + DDR_PHY_BASE_ADDR)
#define    CMD0_REG_PHY_DLL_LOCK_DIFF_0                        (0x028 + DDR_PHY_BASE_ADDR)
#define    CMD0_REG_PHY_INVERT_CLKOUT_0                        (0x02C + DDR_PHY_BASE_ADDR)
#define    CMD0_PHY_REG_STATUS_PHY_CTRL_DLL_LOCK_0             (0x030 + DDR_PHY_BASE_ADDR)
#define    CMD0_PHY_REG_STATUS_PHY_CTRL_OF_IN_LOCK_STATE_0     (0x034 + DDR_PHY_BASE_ADDR)
#define    CMD0_PHY_REG_STATUS_PHY_CTRL_OF_IN_DELAY_VALUE_0    (0x038 + DDR_PHY_BASE_ADDR)
#define    CMD0_PHY_REG_STATUS_PHY_CTRL_OF_OUT_DELAY_VALUE_0   (0x03C + DDR_PHY_BASE_ADDR)

//CMD1
#define    CMD1_REG_PHY_CTRL_SLAVE_RATIO_0                     (0x050 + DDR_PHY_BASE_ADDR)
#define    CMD1_REG_PHY_CTRL_SLAVE_FORCE_0                     (0x054 + DDR_PHY_BASE_ADDR)
#define    CMD1_REG_PHY_CTRL_SLAVE_DELAY_0                     (0x058 + DDR_PHY_BASE_ADDR)
#define    CMD1_REG_PHY_DLL_LOCK_DIFF_0                        (0x05C + DDR_PHY_BASE_ADDR)
#define    CMD1_REG_PHY_INVERT_CLKOUT_0                        (0x060 + DDR_PHY_BASE_ADDR)
#define    CMD1_PHY_REG_STATUS_PHY_CTRL_DLL_LOCK_0             (0x064 + DDR_PHY_BASE_ADDR)
#define    CMD1_PHY_REG_STATUS_PHY_CTRL_OF_IN_LOCK_STATE_0     (0x068 + DDR_PHY_BASE_ADDR)
#define    CMD1_PHY_REG_STATUS_PHY_CTRL_OF_IN_DELAY_VALUE_0    (0x06C + DDR_PHY_BASE_ADDR)
#define    CMD1_PHY_REG_STATUS_PHY_CTRL_OF_OUT_DELAY_VALUE_0   (0x070 + DDR_PHY_BASE_ADDR)

//CMD2
#define    CMD2_REG_PHY_CTRL_SLAVE_RATIO_0                     (0x084 + DDR_PHY_BASE_ADDR)
#define    CMD2_REG_PHY_CTRL_SLAVE_FORCE_0                     (0x088 + DDR_PHY_BASE_ADDR)
#define    CMD2_REG_PHY_CTRL_SLAVE_DELAY_0                     (0x08C + DDR_PHY_BASE_ADDR)
#define    CMD2_REG_PHY_DLL_LOCK_DIFF_0                        (0x090 + DDR_PHY_BASE_ADDR)
#define    CMD2_REG_PHY_INVERT_CLKOUT_0                        (0x094 + DDR_PHY_BASE_ADDR)
#define    CMD2_PHY_REG_STATUS_PHY_CTRL_DLL_LOCK_0             (0x098 + DDR_PHY_BASE_ADDR)
#define    CMD2_PHY_REG_STATUS_PHY_CTRL_OF_IN_LOCK_STATE_0     (0x09C + DDR_PHY_BASE_ADDR)
#define    CMD2_PHY_REG_STATUS_PHY_CTRL_OF_IN_DELAY_VALUE_0    (0x0A0 + DDR_PHY_BASE_ADDR)
#define    CMD2_PHY_REG_STATUS_PHY_CTRL_OF_OUT_DELAY_VALUE_0   (0x0A4 + DDR_PHY_BASE_ADDR)

//DATA0
#define    DATA0_REG_PHY_DATA_SLICE_IN_USE_0                   (0x0B8 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_DIS_CALIB_RST_0                       (0x0BC + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_RDC_FIFO_RST_ERR_CNT_CLR_0            (0x0C0 + DDR_PHY_BASE_ADDR)
#define    DATA0_PHY_RDC_FIFO_RST_ERR_CNT_0                    (0x0C4 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_RD_DQS_SLAVE_RATIO_0                  (0x0C8 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_RD_DQS_SLAVE_RATIO_1                  (0x0CC + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_RD_DQS_SLAVE_FORCE_0                  (0x0D0 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_RD_DQS_SLAVE_DELAY_0                  (0x0D4 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_RD_DQS_SLAVE_DELAY_1                  (0x0D8 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DQS_SLAVE_RATIO_0                  (0x0DC + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DQS_SLAVE_RATIO_1                  (0x0E0 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DQS_SLAVE_FORCE_0                  (0x0E4 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DQS_SLAVE_DELAY_0                  (0x0E8 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DQS_SLAVE_DELAY_1                  (0x0EC + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WRLVL_INIT_RATIO_0                    (0x0F0 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WRLVL_INIT_RATIO_1                    (0x0F4 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WRLVL_INIT_MODE_0                     (0x0F8 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_GATELVL_INIT_RATIO_0                  (0x0FC + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_GATELVL_INIT_RATIO_1                  (0x100 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_GATELVL_INIT_MODE_0                   (0x104 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_FIFO_WE_SLAVE_RATIO_0                 (0x108 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_FIFO_WE_SLAVE_RATIO_1                 (0x10C + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_FIFO_WE_IN_FORCE_0                    (0x110 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_FIFO_WE_IN_DELAY_0                    (0x114 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_FIFO_WE_IN_DELAY_1                    (0x118 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_DQ_OFFSET_0                           (0x11C + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DATA_SLAVE_RATIO_0                 (0x120 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DATA_SLAVE_RATIO_1                 (0x124 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DATA_SLAVE_FORCE_0                 (0x128 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DATA_SLAVE_DELAY_0                 (0x12C + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_WR_DATA_SLAVE_DELAY_1                 (0x130 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_USE_RANK0_DELAYS_0                    (0x134 + DDR_PHY_BASE_ADDR)
#define    DATA0_REG_PHY_DLL_LOCK_DIFF_0                       (0x138 + DDR_PHY_BASE_ADDR)
#define    DATA0_PHY_REG_STATUS_DLL_LOCK_0                     (0x13C + DDR_PHY_BASE_ADDR)
#define    DATA0_PHY_REG_STATUS_OF_IN_LOCK_STATE_0             (0x140 + DDR_PHY_BASE_ADDR)
#define    DATA0_PHY_REG_STATUS_OF_IN_DELAY_VALUE_0            (0x144 + DDR_PHY_BASE_ADDR)
#define    DATA0_PHY_REG_STATUS_OF_OUT_DELAY_VALUE_0           (0x148 + DDR_PHY_BASE_ADDR)

//DATA1
#define    DATA1_REG_PHY_DATA_SLICE_IN_USE_0                   (0x15C + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_DIS_CALIB_RST_0                       (0x160 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_RDC_FIFO_RST_ERR_CNT_CLR_0            (0x164 + DDR_PHY_BASE_ADDR)
#define    DATA1_PHY_RDC_FIFO_RST_ERR_CNT_0                    (0x168 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_RD_DQS_SLAVE_RATIO_0                  (0x16C + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_RD_DQS_SLAVE_RATIO_1                  (0x170 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_RD_DQS_SLAVE_FORCE_0                  (0x174 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_RD_DQS_SLAVE_DELAY_0                  (0x178 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_RD_DQS_SLAVE_DELAY_1                  (0x17C + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DQS_SLAVE_RATIO_0                  (0x180 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DQS_SLAVE_RATIO_1                  (0x184 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DQS_SLAVE_FORCE_0                  (0x188 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DQS_SLAVE_DELAY_0                  (0x18C + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DQS_SLAVE_DELAY_1                  (0x190 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WRLVL_INIT_RATIO_0                    (0x194 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WRLVL_INIT_RATIO_1                    (0x198 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WRLVL_INIT_MODE_0                     (0x19C + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_GATELVL_INIT_RATIO_0                  (0x1A0 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_GATELVL_INIT_RATIO_1                  (0x1A4 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_GATELVL_INIT_MODE_0                   (0x1A8 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_FIFO_WE_SLAVE_RATIO_0                 (0x1AC + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_FIFO_WE_SLAVE_RATIO_1                 (0x1B0 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_FIFO_WE_IN_FORCE_0                    (0x1B4 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_FIFO_WE_IN_DELAY_0                    (0x1B8 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_FIFO_WE_IN_DELAY_1                    (0x1BC + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_DQ_OFFSET_0                           (0x1C0 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DATA_SLAVE_RATIO_0                 (0x1C4 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DATA_SLAVE_RATIO_1                 (0x1C8 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DATA_SLAVE_FORCE_0                 (0x1CC + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DATA_SLAVE_DELAY_0                 (0x1D0 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_WR_DATA_SLAVE_DELAY_1                 (0x1D4 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_USE_RANK0_DELAYS_0                    (0x1D8 + DDR_PHY_BASE_ADDR)
#define    DATA1_REG_PHY_DLL_LOCK_DIFF_0                       (0x1DC + DDR_PHY_BASE_ADDR)
#define    DATA1_PHY_REG_STATUS_DLL_LOCK_0                     (0x1E0 + DDR_PHY_BASE_ADDR)
#define    DATA1_PHY_REG_STATUS_OF_IN_LOCK_STATE_0             (0x1E4 + DDR_PHY_BASE_ADDR)
#define    DATA1_PHY_REG_STATUS_OF_IN_DELAY_VALUE_0            (0x1E8 + DDR_PHY_BASE_ADDR)
#define    DATA1_PHY_REG_STATUS_OF_OUT_DELAY_VALUE_0           (0x1EC + DDR_PHY_BASE_ADDR)

//FIFO
#define FIFO_WE_OUT0_IO_CONFIG_I_0                             (0x338 + DDR_PHY_BASE_ADDR)
#define FIFO_WE_OUT0_IO_CONFIG_SR_0                            (0x33C + DDR_PHY_BASE_ADDR)
#define FIFO_WE_OUT1_IO_CONFIG_I_0                             (0x340 + DDR_PHY_BASE_ADDR)
#define FIFO_WE_OUT1_IO_CONFIG_SR_0                            (0x344 + DDR_PHY_BASE_ADDR)
#define FIFO_WE_IN2_IO_CONFIG_I_0                              (0x348 + DDR_PHY_BASE_ADDR)
#define FIFO_WE_IN2_IO_CONFIG_SR_0                             (0x34C + DDR_PHY_BASE_ADDR)
#define FIFO_WE_IN3_IO_CONFIG_I_0                              (0x350 + DDR_PHY_BASE_ADDR)
#define FIFO_WE_IN3_IO_CONFIG_SR_0                             (0x354 + DDR_PHY_BASE_ADDR)

//Leveling
#define DATA0_REG_PHY_WRLVL_NUM_OF_DQ0                         (0x35C + DDR_PHY_BASE_ADDR)
#define DATA0_REG_PHY_GATELVL_NUM_OF_DQ0                       (0x360 + DDR_PHY_BASE_ADDR)
#define DATA1_REG_PHY_WRLVL_NUM_OF_DQ0                         (0x364 + DDR_PHY_BASE_ADDR)
#define DATA1_REG_PHY_GATELVL_NUM_OF_DQ0                       (0x368 + DDR_PHY_BASE_ADDR)






// GPIO Bank
#define GPIO0_START_ADDR (0x44E07000)
#define GPIO1_START_ADDR (0x4804C000)
#define GPIO2_START_ADDR (0x481AC000)
#define GPIO3_START_ADDR (0x481AE000)
#define GPIO_BANK_SIZE (0x1000)         // 4 KB


// GPIO memory-mapped register addresses.
#define GPIO_IRQSTATUS_0        0x2C
#define GPIO_IRQSTATUS_1        0x30


#define GPIO_REVISION   (0x0)
#define GPIO_SYSCONFIG   (0x10)
#define GPIO_IRQSTATUS_RAW(n)   (0x24 + (n * 4))
#define GPIO_IRQSTATUS(n)   (0x2C + (n * 4))
#define GPIO_IRQSTATUS_SET(n)   (0x34 + (n * 4))
#define GPIO_IRQSTATUS_CLR(n)   (0x3C + (n * 4))
#define GPIO_IRQWAKEN(n)   (0x44 + (n * 4))
#define GPIO_SYSSTATUS   (0x114)
#define GPIO_CTRL   (0x130)
#define GPIO_OE   (0x134)
#define GPIO_DATAIN   (0x138)
#define GPIO_DATAOUT   (0x13C)
#define GPIO_LEVELDETECT(n)   (0x140 + (n * 4))
#define GPIO_RISINGDETECT   (0x148)
#define GPIO_FALLINGDETECT   (0x14C)
#define GPIO_DEBOUNCENABLE   (0x150)
#define GPIO_DEBOUNCINGTIME   (0x154)
#define GPIO_CLEARDATAOUT   (0x190)
#define GPIO_SETDATAOUT   (0x194)



/* REVISION */
#define GPIO_REVISION_CUSTOM   (0x000000C0u)
#define GPIO_REVISION_CUSTOM_SHIFT   (0x00000006u)

#define GPIO_REVISION_FUNC   (0x0FFF0000u)
#define GPIO_REVISION_FUNC_SHIFT   (0x00000010u)

#define GPIO_REVISION_MAJOR   (0x00000700u)
#define GPIO_REVISION_MAJOR_SHIFT   (0x00000008u)

#define GPIO_REVISION_MINOR   (0x0000003Fu)
#define GPIO_REVISION_MINOR_SHIFT   (0x00000000u)

#define GPIO_REVISION_RTL   (0x0000F800u)
#define GPIO_REVISION_RTL_SHIFT   (0x0000000Bu)

#define GPIO_REVISION_SCHEME   (0xC0000000u)
#define GPIO_REVISION_SCHEME_SHIFT   (0x0000001Eu)


/* SYSCONFIG */
#define GPIO_SYSCONFIG_AUTOIDLE   (0x00000001u)
#define GPIO_SYSCONFIG_AUTOIDLE_SHIFT   (0x00000000u)
#define GPIO_SYSCONFIG_AUTOIDLE_AUTOMATIC   (0x1u)
#define GPIO_SYSCONFIG_AUTOIDLE_FREERUN   (0x0u)

#define GPIO_SYSCONFIG_ENAWAKEUP   (0x00000004u)
#define GPIO_SYSCONFIG_ENAWAKEUP_SHIFT   (0x00000002u)
#define GPIO_SYSCONFIG_ENAWAKEUP_DISABLE   (0x0u)
#define GPIO_SYSCONFIG_ENAWAKEUP_ENABLE   (0x1u)

#define GPIO_SYSCONFIG_IDLEMODE   (0x00000018u)
#define GPIO_SYSCONFIG_IDLEMODE_SHIFT   (0x00000003u)
#define GPIO_SYSCONFIG_IDLEMODE_FORCEIDLE   (0x0u)
#define GPIO_SYSCONFIG_IDLEMODE_NOIDLE   (0x1u)
#define GPIO_SYSCONFIG_IDLEMODE_SMARTIDLE   (0x2u)
#define GPIO_SYSCONFIG_IDLEMODE_SMARTIDLEWAKEUP   (0x3u)

#define GPIO_SYSCONFIG_SOFTRESET   (0x00000002u)
#define GPIO_SYSCONFIG_SOFTRESET_SHIFT   (0x00000001u)
#define GPIO_SYSCONFIG_SOFTRESET_NORMAL   (0x0u)
#define GPIO_SYSCONFIG_SOFTRESET_RESET   (0x1u)


/* IRQSTATUS_RAW_0 */
#define GPIO_IRQSTATUS_RAW_0_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_RAW_0_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_RAW_1 */
#define GPIO_IRQSTATUS_RAW_1_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_RAW_1_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_0 */
#define GPIO_IRQSTATUS_0_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_0_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_1 */
#define GPIO_IRQSTATUS_1_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_1_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_SET_0 */
#define GPIO_IRQSTATUS_SET_0_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_SET_0_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_SET_1 */
#define GPIO_IRQSTATUS_SET_1_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_SET_1_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_CLR_0 */
#define GPIO_IRQSTATUS_CLR_0_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_CLR_0_INTLINE_SHIFT   (0x00000000u)


/* IRQSTATUS_CLR_1 */
#define GPIO_IRQSTATUS_CLR_1_INTLINE   (0xFFFFFFFFu)
#define GPIO_IRQSTATUS_CLR_1_INTLINE_SHIFT   (0x00000000u)


/* SYSSTATUS */
#define GPIO_SYSSTATUS_RESETDONE   (0x00000001u)
#define GPIO_SYSSTATUS_RESETDONE_SHIFT   (0x00000000u)
#define GPIO_SYSSTATUS_RESETDONE_COMPLETE   (0x1u)
#define GPIO_SYSSTATUS_RESETDONE_ONGOING   (0x0u)


/* CTRL */
#define GPIO_CTRL_DISABLEMODULE   (0x00000001u)
#define GPIO_CTRL_DISABLEMODULE_SHIFT   (0x00000000u)
#define GPIO_CTRL_DISABLEMODULE_DISABLED   (0x1u)
#define GPIO_CTRL_DISABLEMODULE_ENABLED   (0x0u)

#define GPIO_CTRL_GATINGRATIO   (0x00000006u)
#define GPIO_CTRL_GATINGRATIO_SHIFT   (0x00000001u)
#define GPIO_CTRL_GATINGRATIO_N_1   (0x0u)
#define GPIO_CTRL_GATINGRATIO_N_2   (0x1u)
#define GPIO_CTRL_GATINGRATIO_N_4   (0x2u)
#define GPIO_CTRL_GATINGRATIO_N_8   (0x3u)


/* OE */
#define GPIO_OE_OUTPUTEN   (0xFFFFFFFFu)
#define GPIO_OE_OUTPUTEN_SHIFT   (0x00000000u)
#define GPIO_OE_OUTPUTEN_DISABLED   (0x1u)
#define GPIO_OE_OUTPUTEN_ENABLED   (0x0u)


/* DATAIN */
#define GPIO_DATAIN_DATAIN   (0xFFFFFFFFu)
#define GPIO_DATAIN_DATAIN_SHIFT   (0x00000000u)


/* DATAOUT */
#define GPIO_DATAOUT_DATAOUT   (0xFFFFFFFFu)
#define GPIO_DATAOUT_DATAOUT_SHIFT   (0x00000000u)


/* LEVELDETECT0 */
#define GPIO_LEVELDETECT0_LEVELDETECT0   (0xFFFFFFFFu)
#define GPIO_LEVELDETECT0_LEVELDETECT0_SHIFT   (0x00000000u)
#define GPIO_LEVELDETECT0_LEVELDETECT0_DISABLED   (0x0u)
#define GPIO_LEVELDETECT0_LEVELDETECT0_ENABLED   (0x1u)


/* LEVELDETECT1 */
#define GPIO_LEVELDETECT1_LEVELDETECT1   (0xFFFFFFFFu)
#define GPIO_LEVELDETECT1_LEVELDETECT1_SHIFT   (0x00000000u)
#define GPIO_LEVELDETECT1_LEVELDETECT1_DISABLED   (0x0u)
#define GPIO_LEVELDETECT1_LEVELDETECT1_ENABLED   (0x1u)


/* RISINGDETECT */
#define GPIO_RISINGDETECT_RISINGDETECT   (0xFFFFFFFFu)
#define GPIO_RISINGDETECT_RISINGDETECT_SHIFT   (0x00000000u)
#define GPIO_RISINGDETECT_RISINGDETECT_DISABLED   (0x0u)
#define GPIO_RISINGDETECT_RISINGDETECT_ENABLED   (0x1u)


/* FALLINGDETECT */
#define GPIO_FALLINGDETECT_FALLINGDETECT   (0xFFFFFFFFu)
#define GPIO_FALLINGDETECT_FALLINGDETECT_SHIFT   (0x00000000u)
#define GPIO_FALLINGDETECT_FALLINGDETECT_DISABLED   (0x0u)
#define GPIO_FALLINGDETECT_FALLINGDETECT_ENABLED   (0x1u)


/* DEBOUNCENABLE */
#define GPIO_DEBOUNCENABLE_DEBOUNCEENABLE   (0xFFFFFFFFu)
#define GPIO_DEBOUNCENABLE_DEBOUNCEENABLE_SHIFT   (0x00000000u)
#define GPIO_DEBOUNCENABLE_DEBOUNCEENABLE_DEBOUNCE   (0x1u)
#define GPIO_DEBOUNCENABLE_DEBOUNCEENABLE_NODEBOUNCE   (0x0u)


/* DEBOUNCINGTIME */
#define GPIO_DEBOUNCINGTIME_DEBOUNCETIME   (0x000000FFu)
#define GPIO_DEBOUNCINGTIME_DEBOUNCETIME_SHIFT   (0x00000000u)


/* CLEARDATAOUT */
#define GPIO_CLEARDATAOUT_INTLINE   (0xFFFFFFFFu)
#define GPIO_CLEARDATAOUT_INTLINE_SHIFT   (0x00000000u)


/* SETDATAOUT */
#define GPIO_SETDATAOUT_INTLINE   (0xFFFFFFFFu)
#define GPIO_SETDATAOUT_INTLINE_SHIFT   (0x00000000u)







#define PRU_ICSS_START_ADDR         (0x4a300000)
//#define PRU_ICSS_CMD_OFFSET             (0x11700)

#define PRU_PER_SIZE                (0x80000)       // 512KB

#define OFFSET_PRU_ICSS_PRU0_DATA_RAM_1             (0x2000)
#define OFFSET_PRU_ICSS_SHARED_DATA_RAM             (0x10000)

#define PRU_DATA_RAM_SIZE                           (0x2000)        // 8KB

#define OFFSET_PRU_ICSS_INTC                        (0x20000)
#define OFFSET_PRU_ICSS_PRU0_CONTROL                (0x22000)
#define OFFSET_PRU_ICSS_PRU1_CONTROL                (0x24000)

#define OFFSET_PRU_ICSS_PRU_CFG                (0x26000)

#define OFFSET_PRU0_IRAM_PHYS_BASE                  (0x34000)

#define PRUSSDRV_PRU_RESET              (0x00000000)
#define PRUSSDRV_PRU_DISABLE            (0x00000001)
#define PRUSSDRV_PRU_ENABLE             (0x00000002)







//
//USB subsystem base address
//
#define USBSS_BASE					0x47400000
//
//USB0 base address
//
#define USB_0_OTGBASE				0x47401000
//
//USB1 base address
//
#define USB_1_OTGBASE				0x47401800

//
//USB subsystem register offsets
//
#define USBSS_IRQ_EOI				0x20
#define USBSS_IRQ_STATUS_RAW		0x24
#define USBSS_IRQ_STATUS			0x28
#define USBSS_IRQ_ENABLE_SET		0x2C
#define USBSS_IRQ_ENABLE_CLR		0x30

//
//USB0 offset register offsets
//
#define USB_0_REVISION				0x00
#define USB_0_CTRL	            	0x14
#define USB_0_STAT	            	0x18
#define USB_0_IRQ_MERGED_STATUS		0x20
#define USB_0_IRQ_EOI				0x24
#define USB_0_IRQ_STATUS_RAW_0 		0x28
#define USB_0_IRQ_STATUS_RAW_1 		0x2C
#define USB_0_IRQ_STATUS_0     		0x30
#define USB_0_IRQ_STATUS_1     		0x34
#define USB_0_IRQ_ENABLE_SET_0 		0x38
#define USB_0_IRQ_ENABLE_SET_1 		0x3C
#define USB_0_IRQ_ENABLE_CLR_0 		0x40
#define USB_0_IRQ_ENABLE_CLR_1 		0x44

#define USB_0_TX_MODE				0x70
#define USB_0_RX_MODE				0x74

#define USB_0_GEN_RNDIS_SIZE_EP1	0x80
#define USB_0_GEN_RNDIS_SIZE_EP2	0x84
#define USB_0_GEN_RNDIS_SIZE_EP3	0x88
#define USB_0_GEN_RNDIS_SIZE_EP4	0x8C
#define USB_0_GEN_RNDIS_SIZE_EP5	0x90
#define USB_0_GEN_RNDIS_SIZE_EP6	0x94
#define USB_0_GEN_RNDIS_SIZE_EP7	0x98
#define USB_0_GEN_RNDIS_SIZE_EP8	0x9C
#define USB_0_GEN_RNDIS_SIZE_EP9	0xA0
#define USB_0_GEN_RNDIS_SIZE_EP10	0xA4
#define USB_0_GEN_RNDIS_SIZE_EP11	0xA8
#define USB_0_GEN_RNDIS_SIZE_EP12	0xAC
#define USB_0_GEN_RNDIS_SIZE_EP13	0xB0
#define USB_0_GEN_RNDIS_SIZE_EP14	0xB4
#define USB_0_GEN_RNDIS_SIZE_EP15	0xB8

#define USB_1_GEN_RNDIS_SIZE_EP1	0x880
#define USB_1_GEN_RNDIS_SIZE_EP2	0x884
#define USB_1_GEN_RNDIS_SIZE_EP3	0x888
#define USB_1_GEN_RNDIS_SIZE_EP4	0x88C
#define USB_1_GEN_RNDIS_SIZE_EP5	0x890
#define USB_1_GEN_RNDIS_SIZE_EP6	0x894
#define USB_1_GEN_RNDIS_SIZE_EP7	0x898
#define USB_1_GEN_RNDIS_SIZE_EP8	0x89C
#define USB_1_GEN_RNDIS_SIZE_EP9	0x8A0
#define USB_1_GEN_RNDIS_SIZE_EP10	0x8A4
#define USB_1_GEN_RNDIS_SIZE_EP11	0x8A8
#define USB_1_GEN_RNDIS_SIZE_EP12	0x8AC
#define USB_1_GEN_RNDIS_SIZE_EP13	0x8B0
#define USB_1_GEN_RNDIS_SIZE_EP14	0x8B4
#define USB_1_GEN_RNDIS_SIZE_EP15	0x8B8

#define USB_0_AUTO_REQ				0xD0 						
#define USB_0_SRP_FIX_TIME          0xD4
#define USB_0_TEARDOWN              0xD8
#define USB_0_THRESHOLD_XDMA_IDLE   0xDC
#define USB_0_PHY_UTMI              0xE0
#define USB_0_MGC_UTMI_LOOPBACK     0xE4
#define USB_0_MODE                  0xE8















/**
@def        am3356 gpio pin number definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

// am335x-bone-common.dtsi (&mmc1), omap_hsmmc.c
// cd-gpios = <&gpio0 6 GPIO_ACTIVE_HIGH>;

#define GPIO_USER_LED_1         ((32*1)+29)     // GPIO1_29, Front Led Left
#define GPIO_USER_LED_2         ((32*1)+30)     // GPIO1_30, Front Led Right (Start / Stop)
#define GPIO_USER_LED_3         ((32*2)+19)     // GPIO2_19, Reject Full

#define GPIO_PIN_NUM_AM3356_STATUS_LED_MLO             ((32*1)+28)      // For Booting Stage U-Boot MLO (Low=On, High=Off)
#define GPIO_PIN_NUM_AM3356_STATUS_LED_UBOOT       ((32*3)+10)          // For Booting Stage U-Boot U-boot.img (Low=On, High=Off)
#define GPIO_PIN_NUM_AM3356_STATUS_LED_KERNEL       ((32*3)+9)          // For Kernel HeartBeat

#define GPIO_PIN_NUM_AM3356_PRU_STATUS_LED             ((32*2)+5)     // PRU Status



#define GPIO_INTR_DSP      ((32*3)+10)     // GPIO3_10 (VIN1A_D6,AG6)
#define GPIO_INTR_SC       ((32*3)+11)     // GPIO3_11 (VIN1A_D7,AH4)
#define MAX_NUM_OF_GPIO_INTR		(2)


#define GPIO_KEY_1         ((32*1)+0)     // GPIO1_0
#define GPIO_KEY_2         ((32*1)+1)     // GPIO1_1
#define GPIO_KEY_3         ((32*1)+2)     // GPIO1_2
#define GPIO_KEY_4         ((32*1)+3)     // GPIO1_3
#define GPIO_KEY_5         ((32*1)+4)     // GPIO1_4
#define GPIO_KEY_6         ((32*1)+5)     // GPIO1_5
#define GPIO_KEY_7         ((32*1)+6)     // GPIO1_6
#define GPIO_KEY_8         ((32*1)+7)     // GPIO1_7

#define GPIO_KEY_9_INTR         ((32*0)+26)    // GPIO0_26


#define GPIO_BEEPER         ((32*1)+18)     // GPIO1_18


#define GPIO_PIN_NUM_VIDEO_PORT_ON              ((32*2)+1)
#define GPIO_PIN_NUM_TOUCH_INTR                 ((32*0)+7)

#define GPIO_PIN_NUM_RESET_FPGA                 ((32*0)+17)
#define GPIO_PIN_NUM_RESET_DSP                  ((32*2)+2)

#define GPIO_PIN_NUM_PRU_STATUS_LED             ((32*2)+5)
#define GPIO_PIN_NUM_LAN8710_RESET              ((32*2)+18)

#define GPIO_PIN_NUM_MACHINE_ID_0            ((32*0)+18)
#define GPIO_PIN_NUM_MACHINE_ID_1            ((32*3)+13)






/** @brief Base addresses of PWMSS memory mapped registers.                   */

#define SOC_PWMSS0_REGS                     (0x48300000)
#define SOC_PWMSS1_REGS                     (0x48302000)
#define SOC_PWMSS2_REGS                     (0x48304000)

#define SOC_ECAP_REGS                       (0x00000100)
#define SOC_EQEP_REGS                       (0x00000180)
#define SOC_EPWM_REGS                       (0x00000200)

#define SOC_ECAP_0_REGS                     (SOC_PWMSS0_REGS + SOC_ECAP_REGS)
#define SOC_ECAP_1_REGS                     (SOC_PWMSS1_REGS + SOC_ECAP_REGS)
#define SOC_ECAP_2_REGS                     (SOC_PWMSS2_REGS + SOC_ECAP_REGS)

#define SOC_EQEP_0_REGS                     (SOC_PWMSS0_REGS + SOC_EQEP_REGS)
#define SOC_EQEP_1_REGS                     (SOC_PWMSS1_REGS + SOC_EQEP_REGS)
#define SOC_EQEP_2_REGS                     (SOC_PWMSS2_REGS + SOC_EQEP_REGS) 

#define SOC_EPWM_0_REGS                     (SOC_PWMSS0_REGS + SOC_EPWM_REGS)
#define SOC_EPWM_1_REGS                     (SOC_PWMSS1_REGS + SOC_EPWM_REGS)
#define SOC_EPWM_2_REGS                     (SOC_PWMSS2_REGS + SOC_EPWM_REGS)



#define EHRPWM_TBCTL		(0x0)
#define EHRPWM_TBSTS		(0x2)
#define EHRPWM_TBPHSHR		(0x4)
#define EHRPWM_TBPHS		(0x6)
#define EHRPWM_TBCTR		(0x8)
#define EHRPWM_TBPRD		(0xA)
#define EHRPWM_CMPCTL		(0xE)
#define EHRPWM_CMPAHR		(0x10)
#define EHRPWM_CMPA		(0x12)
#define EHRPWM_CMPB		(0x14)
#define EHRPWM_AQCTLA		(0x16)
#define EHRPWM_AQCTLB		(0x18)
#define EHRPWM_AQSFRC		(0x1A)
#define EHRPWM_AQCSFRC		(0x1C)
#define EHRPWM_DBCTL		(0x1E)
#define EHRPWM_DBRED		(0x20)
#define EHRPWM_DBFED		(0x22)
#define EHRPWM_TZSEL		(0x24)
#define EHRPWM_TZCTL		(0x28)
#define EHRPWM_TZEINT		(0x2A)
#define EHRPWM_TZFLG		(0x2C)
#define EHRPWM_TZCLR		(0x2E)
#define EHRPWM_TZFRC		(0x30)
#define EHRPWM_ETSEL		(0x32)
#define EHRPWM_ETPS		(0x34)
#define EHRPWM_ETFLG		(0x36)
#define EHRPWM_ETCLR		(0x38)
#define EHRPWM_ETFRC		(0x3A)
#define EHRPWM_PCCTL		(0x3C)




#define PWMSS_CLOCK_CONFIG               0x08
#define PWMSS_CLOCK_STATUS               0x0C
#define PWMSS_ECAP_CLK_EN_ACK_SHIFT      0x00
#define PWMSS_ECAP_CLK_STOP_ACK_SHIFT    0x01
#define PWMSS_EHRPWM_CLK_EN_ACK_SHIFT    0x08
#define PWMSS_EHRPWM_CLK_STOP_ACK_SHIFT  0x09  
#define PWMSS_ECAP_CLK_EN_ACK            0x01
#define PWMSS_ECAP_CLK_STOP_ACK          0x02
#define PWMSS_EHRPWM_CLK_EN_ACK          0x100
#define PWMSS_EHRPWM_CLK_STOP_ACK        0x200









/**
@def        am3356 with DSP(6748) Data definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

typedef enum {
    REQUEST_DSP_DATA_TYPE_FULL_IMG_0 = 0,
    REQUEST_DSP_DATA_TYPE_FULL_IMG_1,
    REQUEST_DSP_DATA_TYPE_FULL_IMG_2,
    REQUEST_DSP_DATA_TYPE_PROC_RESULT,
    REQUEST_DSP_DATA_TYPE_COMMON_50K,
    REQUEST_DSP_DATA_TYPE_COMMON_100K,
    REQUEST_DSP_DATA_TYPE_COMMON_500K,
    REQUEST_DSP_DATA_TYPE_COMMON_1M,
    REQUEST_DSP_DATA_TYPE_COMMON_2M,
    REQUEST_DSP_DATA_TYPE_PROTOCOL_PACKET,
    MAX_NUM_OF_REQUEST_DSP_DATA_TYPE
} eRequestDspDataType;


#define ADDRESS_DSP_DATA_TYPE_FULL_IMG_0                    (0xC0000000)        // 4315 KB (1584 * 279 * 10)
#define ADDRESS_DSP_DATA_TYPE_FULL_IMG_1                    (0xC0436F20)        // 4315 KB (1584 * 279 * 10)
#define ADDRESS_DSP_DATA_TYPE_FULL_IMG_2                    (0xC086DE40)        // 4315 KB (1584 * 279 * 10)
#define ADDRESS_DSP_DATA_TYPE_PROC_RESULT                   (0xCF98F820)        // 15 KB
#define ADDRESS_DSP_DATA_TYPE_COMMON_50K                    (0xCF99C020)
#define ADDRESS_DSP_DATA_TYPE_COMMON_100K                   (0xCF99C020)
#define ADDRESS_DSP_DATA_TYPE_COMMON_500K                   (0xCF99C020)
#define ADDRESS_DSP_DATA_TYPE_COMMON_1M                     (0xCF99C020)
#define ADDRESS_DSP_DATA_TYPE_COMMON_2M                     (0xCF99C020)
#define ADDRESS_DSP_DATA_TYPE_PROTOCOL_PACKET                       (0xCFE9E820)    // 3 KB






/**
@def        am3356 Shared Memory(DDR) UDP Protocol definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/
#define KISAN_APL_NAME_PREFIX          "B3_"
//#define KISAN_APL_NAME_PREFIX          "kisan_comm"

#define DEFAULT_UDP_PORT                        (7890)


#define UDP_CMD_KISAN_APL_NOTI                  (0x01)

#define UDP_CMD_KISAN_WIFI_ATTACHED             (0x02)
#define UDP_CMD_KISAN_WIFI_DETACHED             (0x03)

#define UDP_CMD_KISAN_LTE_ATTACHED              (0x04)
#define UDP_CMD_KISAN_LTE_DETACHED              (0x05)


/**
@def        am3356 Shared Memory(DDR) Structure definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

//#define ADDR_DDR_VIDEO_BUF_START                    (0x99000000)
#define ADDR_DDR_VIDEO_BUF_START                    (0x9BA00000)
#define ADDR_DDR_VIDEO_BUF_LENGTH                   (0x200000)   // 2MB (0x9BA0_0000 ~ 0x9BBF_FFFF)


//#define ADDR_UPP_DATA_BUF_READ_ADDRESS                 (0x99300000)
#define ADDR_UPP_DATA_BUF_READ_ADDRESS                 (0x9C400000)

//#define ADDR_DDR_SHARED_DATA_BUF                       (0x9f701000)
#define ADDR_DDR_SHARED_DATA_BUF                       (0x9FB01000)
#define LENGTH_OF_DDR_SHM_DATA_KEY                     (3)    // 3Bytes



/**
@def        am3356 Global variables external declarations
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

//extern unsigned char        g_aucDbgPrint[2048];


#define S1_OS_VER_MAJOR        (0)
#define S1_OS_VER_MINOR        (0)
#define S1_OS_VER_INNER        (0)


typedef struct {
    unsigned char ucMajor;
    unsigned char ucMinor;
    unsigned char ucInner;
    unsigned char ucHwRev;
} structKernelVersion;



#endif	/* _LINUX_KISAN_H */

