/**
@file       kisan_common.h
@brief      am3356 device driver  
@details    am3356 device driver  
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

#ifndef _LINUX_KISAN_H
#define _LINUX_KISAN_H

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>
#include <signal.h>


#if !defined(TRUE)
#define TRUE 	(1)
#endif	// #if !defined(TRUE)
#if !defined(FALSE)
#define FALSE 	(0)
#endif	// #if !defined(FALSE)


#define __ON__      (1)
#define __OFF__     (0)

#define __YES__      (1)
#define __NO__     (0)


#define __HI__      (1)
#define __LO__     (0)


#define __IN__     (1)
#define __OUT__      (0)


#define __FILENAME__ (strrchr(__FILE__, '/') ? strrchr(__FILE__, '/') + 1 : __FILE__)



/**
@def        Macros
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

/*  Ʈ Ŭ */
#define BIT_CLR(data, loc)    ((data) &= ~(0x1 << (loc)))
/* ӵ  Ʈ Ŭ */
#define BITS_CLR(data, area, loc)     ((data) &= ~((area) << (loc)))
  
/*  Ʈ  */
#define BIT_SET(data, loc)      ((data) |= (0x1 << (loc)))
/* ӵ  Ʈ  */
#define BITS_SET(data, area, loc)  ((data) |= ((area) << (loc)))
  
/*  Ʈ  */
#define BIT_INVERT(data, loc)   ((data) ^= (0x1 << (loc)))
/* ӵ  Ʈ  */
#define BITS_INVERT(data, area, loc)    ((data) ^= ((area) << (loc)))
  
/* Ʈ ˻ */
#define BIT_CHECK(data, loc)    ((data) & (0x1 << (loc)))

/* Ʈ  */
#define BITS_EXTRACT(data, area, loc)   (((data) >> (loc)) & (area))



#define GPIO_TO_BANK(gpio)	((gpio) / 32)
#define GPIO_TO_PINS(gpio)	((gpio) % 32)




/**
@def        am3356 registers definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

// Interrupt Controller Registers
#define INTC_START_ADDR                 (0x48200000)
#define INTC_SIZE                       (0x1000)
#define OFFSET_INTC_SYSCONFIG           (0x10)
#define OFFSET_INTC_CONTROL             (0x48)


// Power Reset Module Interrupt Registers
#define PRM_IRQ_START_ADDR          (0x44e00b00)
#define PRM_IRQ_SIZE                (0x100)

// Power Reset Module Peripheral Registers
#define PRM_PER_START_ADDR          (0x44e00c00)
#define PRM_PER_SIZE                (0x100)

// CM_PER (Clock Module Peripheral Registers)
#define CM_PER_START_ADDR           (0x44e00000)
#define CM_PER_SIZE                 (0x400)



#define CM_PER_GPIO1_CLKCTRL (0xac)
#define CM_PER_GPIO2_CLKCTRL (0xb0)
#define CM_PER_GPIO3_CLKCTRL (0xb4)
#define OFFSET_CMPER_EMIF_CLKCTRL                     (0x28)
#define OFFSET_CMPER_PRU_ICSS_CLKCTRL                 (0xe8)
#define OFFSET_CMPER_PRU_ICSS_CLKSTCTRL               (0x140)




// GPIO Bank
#define GPIO0_START_ADDR (0x44E07000)
#define GPIO1_START_ADDR (0x4804C000)
#define GPIO2_START_ADDR (0x481AC000)
#define GPIO3_START_ADDR (0x481AE000)
#define GPIO_BANK_SIZE (0x1000)         // 4 KB


// GPIO memory-mapped register addresses.
#define GPIO_IRQSTATUS_0        0x2C
#define GPIO_IRQSTATUS_1        0x30
#define GPIO_OE           (0x134)
#define GPIO_DATAOUT      (0x13C)
#define GPIO_RISINGDETECT       0x148
#define GPIO_FALLINGDETECT 0x14C
#define GPIO_CLEARDATAOUT          0x190
#define GPIO_SETDATAOUT            0x194



#define PRU_ICSS_START_ADDR         (0x4a300000)
//#define PRU_ICSS_CMD_OFFSET             (0x11700)

#define PRU_PER_SIZE                (0x80000)       // 512KB

#define OFFSET_PRU_ICSS_INTC                        (0x20000)
#define OFFSET_PRU_ICSS_PRU0_CONTROL                (0x22000)
#define OFFSET_PRU_ICSS_PRU1_CONTROL                (0x24000)

#define OFFSET_PRU_ICSS_PRU_CFG                (0x26000)

#define OFFSET_PRU0_IRAM_PHYS_BASE                  (0x34000)

#define PRUSSDRV_PRU_RESET              (0x00000000)
#define PRUSSDRV_PRU_DISABLE            (0x00000001)
#define PRUSSDRV_PRU_ENABLE             (0x00000002)






/**
@def        am3356 gpio pin number definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/


// am335x-bone-common.dtsi (&mmc1), omap_hsmmc.c
// cd-gpios = <&gpio0 6 GPIO_ACTIVE_HIGH>;


#define GPIO_USER_LED_1         0 //    ((32*1)+30)     // GPIO, LEFT
#define GPIO_USER_LED_2         ((32*1)+30)     // GPIO1_30, RIGHT           // Start / Stop
#define GPIO_USER_LED_3         ((32*2)+19)     // GPIO2_19, Reject Full


//#define GPIO_STATUS_LED_1       ((32*1)+28)     // For U-Boot
#define GPIO_STATUS_LED_2       ((32*3)+10)
#define GPIO_STATUS_LED_3       ((32*3)+ 9)




#define GPIO_KEY_1         ((32*1)+0)     // GPIO1_0
#define GPIO_KEY_2         ((32*1)+1)     // GPIO1_1
#define GPIO_KEY_3         ((32*1)+2)     // GPIO1_2
#define GPIO_KEY_4         ((32*1)+3)     // GPIO1_3
//#define GPIO_KEY_5         ((32*0)+27)    // GPIO0_27
#define GPIO_KEY_5         ((32*1)+29)    // GPIO0_27

#define GPIO_KEY_6         ((32*1)+5)     // GPIO1_5
#define GPIO_KEY_7         ((32*1)+6)     // GPIO1_6
#define GPIO_KEY_8         ((32*1)+7)     // GPIO1_7
#define GPIO_KEY_9         ((32*0)+26)    // GPIO0_26
#define GPIO_KEY_10        ((32*1)+4)     // GPIO1_4








#define GPIO_PIN_NUM_VIDEO_PORT_ON ((32*2)+1)
#define GPIO_PIN_NUM_TOUCH_INTR         ((32*0)+7)

#define GPIO_PIN_NUM_AM3356_STATUS_LED_1             ((32*1)+28)

#define GPIO_PIN_NUM_PRU_STATUS_LED             ((32*2)+5)
#define GPIO_PIN_NUM_LAN8710_RESET              ((32*2)+18)













/**
@def        am3356 with DSP(6748) Data definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

typedef enum {
    REQUEST_DSP_DATA_TYPE_FULL_IMG_0 = 0,
    REQUEST_DSP_DATA_TYPE_FULL_IMG_1,
    REQUEST_DSP_DATA_TYPE_FULL_IMG_2,
    REQUEST_DSP_DATA_TYPE_PROC_RESULT,
    REQUEST_DSP_DATA_TYPE_COMMON_50K,
    REQUEST_DSP_DATA_TYPE_COMMON_100K,
    REQUEST_DSP_DATA_TYPE_COMMON_500K,
    REQUEST_DSP_DATA_TYPE_COMMON_1M,
    REQUEST_DSP_DATA_TYPE_COMMON_2M,
    REQUEST_DSP_DATA_TYPE_PROTOCOL_PACKET,
    MAX_NUM_OF_REQUEST_DSP_DATA_TYPE
} eRequestDspDataType;







/**
@def        am3356 Shared Memory(DDR) Structure definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

//#define ADDR_UPP_DATA_BUF_READ_ADDRESS                 (0x99300000)
#define ADDR_UPP_DATA_BUF_READ_ADDRESS                 (0x9C400000)

//#define ADDR_DDR_SHARED_DATA_BUF                       (0x9f701000)
#define ADDR_DDR_SHARED_DATA_BUF                       (0x9FB01000)
#define LENGTH_OF_DDR_SHM_DATA_KEY                     (3)    // 3Bytes




/**
@def        am3356 Shared Memory(DDR) UDP Protocol definitions
@date       2016-10-19
@author     hong.yongje@kisane.com
*/


#define DEFAULT_UDP_PORT                (7890)
#define CMD_UDP_MSG_USB_NOTI            (0x02)

#define LENGTH_OF_SHM_DATA_KEY                  (2)    // 2Bytes
#define LENGTH_OF_SHM_DATA_USB_NOTI             (2)    // 2Bytes





/**
@def        am3356 Global variables external declarations
@date       2016-10-19
@author     hong.yongje@kisane.com
*/

//extern unsigned char        g_aucDbgPrint[2048];

typedef struct {
    unsigned char ucMajor;
    unsigned char ucMinor;
    unsigned char ucInner;
    unsigned char ucHwRev;
} structKernelVersion;




typedef enum {
    CMD_TYPE_PRU_INIT = 0,
    CMD_TYPE_PRU_ENABLE,
    CMD_TYPE_PRU_DISABLE,
    CMD_TYPE_PRU_UPLOAD,
    CMD_TYPE_PRU_REQUEST_DATA,
    CMD_TYPE_PRU_COPY_RECEIVED_DATA_TO_SHARED_MEM,
    CMD_TYPE_PRU_SW_RESET,
    MAX_NUM_OF_PRU_CMD_TYPE
} eCommandTypePRUSS;


typedef struct {
    int nPRUNum;    // (pru#0, pru#1)
    int nCmdType;

    int nDspDataType;
    unsigned int *punDspDataAddr;
    unsigned int unDspDataLength;
} structUserPRU;








#endif	/* _LINUX_KISAN_H */
