/**
@file       test_gpio_handler.c
@brief      am3356 device driver ׽Ʈ User-space Application
@details     device driver : kisan_gpio_handler (character)
@date       2016-10-24
@author     hong.yongje@kisane.com
*/

#include "../include/kisan_common.h"


struct structGpioHandler {
    int nCmdType;   // 0=SetDirection, 1=GetDirection, 2=SetValue, 3=GetValue
    int nGpioBank;
    int nGpioNum;
    int nCmdData;
    int nDbgMsgFlag;
};


typedef enum {
    CMD_TYPE_GPIO_HANDLER_SET_DIRECTION = 0,
    CMD_TYPE_GPIO_HANDLER_GET_DIRECTION,
    CMD_TYPE_GPIO_HANDLER_SET_VALUE,
    CMD_TYPE_GPIO_HANDLER_GET_VALUE,
    CMD_TYPE_GPIO_HANDLER_TOGGLE_PIN,   // during 1~5 msec
    MAX_NUM_OF_CMD_TYPE_GPIO_HANDLER
} eCommandTypeGpioHandler;


static const char *g_strDevice = "/dev/kisan_gpio_handler";


int main(int argc, char *argv[])
{
    int fdDev = 0;
    int nStatus = 0;

    struct structGpioHandler stGpioHandler;

    if(argc < 5) {
        printf("Usage  : %s CmdType(0~3) GpioBank(2~8) GpioNum(0~31) CmdData(*) DbgMsg(0~1)\n", 
            __FILENAME__);
        printf("[%s] CmdType: 0=SetDirection, 1=GetDirection, 2=SetValue, 3=GetValue, 4=TogglePin\n", 
            __FILENAME__);

        return 0;
    }

    stGpioHandler.nCmdType     = atoi(argv[1]);
    stGpioHandler.nGpioBank    = atoi(argv[2]);
    stGpioHandler.nGpioNum     = atoi(argv[3]);
    stGpioHandler.nCmdData     = atoi(argv[4]);

    if(argc == 6)
        stGpioHandler.nDbgMsgFlag  = atoi(argv[5]);
    else
        stGpioHandler.nDbgMsgFlag  = __OFF__;

//    printf("\n====================================== Start Test Program ====================================== \n\n");

    if((fdDev = open(g_strDevice, O_RDWR | O_NDELAY)) < 0) {
        printf("[%s] Failed to open %s \n", __FILENAME__, g_strDevice);
        return 0;
    }

    if( ioctl (fdDev, 0, &stGpioHandler ) < 0 ) {
        printf("[%s] Failed to ioctl. \n", __FILENAME__);
    }
    else {
        switch(stGpioHandler.nCmdType)
        {
            case CMD_TYPE_GPIO_HANDLER_SET_DIRECTION:
                printf("[%s] Set GPIO%d_%d direction: %s \n",
                    __FILENAME__, stGpioHandler.nGpioBank, stGpioHandler.nGpioNum, 
                    stGpioHandler.nCmdData == __OUT__ ? "Out(0)" : "In(1)");
                break;

            case CMD_TYPE_GPIO_HANDLER_GET_DIRECTION:
                printf("[%s] Get GPIO%d_%d direction: %s \n",
                    __FILENAME__, stGpioHandler.nGpioBank, stGpioHandler.nGpioNum,
                    stGpioHandler.nCmdData == __OUT__ ? "Out(0)" : "In(1)");
                break;

            case CMD_TYPE_GPIO_HANDLER_SET_VALUE:
                printf("[%s] Set GPIO%d_%d Value: %s \n",
                    __FILENAME__, stGpioHandler.nGpioBank, stGpioHandler.nGpioNum,
                    stGpioHandler.nCmdData== __LO__ ? "Low(0)" : "Hi(1)");
                break;

            case CMD_TYPE_GPIO_HANDLER_GET_VALUE:
                printf("[%s] Get GPIO%d_%d Value: %s \n",
                    __FILENAME__, stGpioHandler.nGpioBank, stGpioHandler.nGpioNum,
                    stGpioHandler.nCmdData== __LO__ ? "Low(0)" : "Hi(1)");
                break;

            case CMD_TYPE_GPIO_HANDLER_TOGGLE_PIN:
                printf("[%s] Toggle GPIO%d_%d during %d usec. \n",
                    __FILENAME__, stGpioHandler.nGpioBank, stGpioHandler.nGpioNum,
                    stGpioHandler.nCmdData);
                break;
        }
    }

//    printf("======================================= End Test Program ======================================= \n\n");

    close(fdDev);

    return 0;
}

