/******************************************************************************
 *
 * SOC.h - SOC memory map header file
 *
 * Copyright (C) 2015-2018 Texas Instruments Incorporated.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
******************************************************************************
*/

// 20200709   ġ
// ~/SDK_RTOS_ROOT/pdk_am57xx_1_0_17/packages/ti/csl/soc/am572x/src

#ifndef CSLR_SOC_MPU_BASEADDRESS_H
#define CSLR_SOC_MPU_BASEADDRESS_H

#ifdef __cplusplus
extern "C"
{
#endif

#define CSL_MPU_GPMC_REGS                                                       (0x0U)
#define CSL_MPU_GPMC_SIZE                                                       (0x20000000U)
#define CSL_MPU_PCIE_SS1_REGS                                                   (0x20000000U)
#define CSL_MPU_PCIE_SS1_SIZE                                                   (0x10000000U)
#define CSL_MPU_PCIE_SS2_REGS                                                   (0x30000000U)
#define CSL_MPU_PCIE_SS2_SIZE                                                   (0x10000000U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_REGS                                           (0x40000000U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_SIZE                                           (0x37000U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_REST_REGS                                      (0x40037000U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_REST_SIZE                                      (0x1000U)
#define CSL_MPU_MPU_ROM_BOOT_PUBLIC_REGS                                        (0x40038000U)
#define CSL_MPU_MPU_ROM_BOOT_PUBLIC_SIZE                                        (0xc000U)
#define CSL_MPU_MPU_RAM_REGS                                                    (0x402f0000U)
#define CSL_MPU_MPU_RAM_SIZE                                                    (0x10000U)
#define CSL_MPU_OCMC_RAM1_REGS                                                  (0x40300000U)
#define CSL_MPU_OCMC_RAM2_REGS                                                  (0x40400000U)
#define CSL_MPU_OCMC_RAM3_REGS                                                  (0x40500000U)

#ifdef  CSL_MODIFICATION
#define CSL_MPU_OCMC_RAM1_SIZE                                                  (0x240U)
#define CSL_MPU_OCMC_RAM2_SIZE                                                  (0x240U)
#define CSL_MPU_OCMC_RAM3_SIZE                                                  (0x240U)
#else
/* OCMC RAM1 size is 512KBytes */
#define CSL_MPU_OCMC_RAM1_SIZE                                                  (0x80000U)
/* OCMC RAM2 & RAM3 size is 1MB */
#define CSL_MPU_OCMC_RAM2_SIZE                                                  (0x100000U)
#define CSL_MPU_OCMC_RAM3_SIZE                                                  (0x100000U)
#endif

#define CSL_MPU_DSP1_L2_SRAM_REGS                                               (0x40800000U)
#define CSL_MPU_DSP1_L2_SRAM_SIZE                                               (0x48000U)
#define CSL_MPU_DSP1_SYSTEM_REGS                                                (0x40d00000U)
#define CSL_MPU_DSP1_SYSTEM_SIZE                                                (0x100U)
#define CSL_MPU_DSP1_MMU0CFG_REGS                                               (0x40d01000U)
#define CSL_MPU_DSP1_MMU0CFG_SIZE                                               (0xb0U)
#define CSL_MPU_DSP1_MMU1CFG_REGS                                               (0x40d02000U)
#define CSL_MPU_DSP1_MMU1CFG_SIZE                                               (0xb0U)
#define CSL_MPU_DSP1_FW0CFG_REGS                                                (0x40d03000U)
#define CSL_MPU_DSP1_FW0CFG_SIZE                                                (0x1000U)
#define CSL_MPU_DSP1_FW1CFG_REGS                                                (0x40d04000U)
#define CSL_MPU_DSP1_FW1CFG_SIZE                                                (0x1000U)
#define CSL_MPU_DSP1_EDMA_TC0_REGS                                              (0x40d05000U)
#define CSL_MPU_DSP1_EDMA_TC0_SIZE                                              (0x80U)
#define CSL_MPU_DSP1_EDMA_TC1_REGS                                              (0x40d06000U)
#define CSL_MPU_DSP1_EDMA_TC1_SIZE                                              (0x80U)
#define CSL_MPU_DSP1_NOC_REGS                                                   (0x40d07000U)
#define CSL_MPU_DSP1_NOC_SIZE                                                   (0x1000U)
#define CSL_MPU_DSP1_DFT_REGS                                                   (0x40d0f000U)
#define CSL_MPU_DSP1_DFT_SIZE                                                   (0x1000U)
#define CSL_MPU_DSP1_EDMA_CC_REGS                                               (0x40d10000U)
#define CSL_MPU_DSP1_EDMA_CC_SIZE                                               (0xa98U)
#define CSL_MPU_DSP1_L1P_SRAM_REGS                                              (0x40e00000U)
#define CSL_MPU_DSP1_L1P_SRAM_SIZE                                              (0x8000U)
#define CSL_MPU_DSP1_L1D_SRAM_REGS                                              (0x40f00000U)
#define CSL_MPU_DSP1_L1D_SRAM_SIZE                                              (0x8000U)
#define CSL_MPU_DSP2_L2_SRAM_REGS                                               (0x41000000U)
#define CSL_MPU_DSP2_L2_SRAM_SIZE                                               (0x48000U)
#define CSL_MPU_DSP2_SYSTEM_REGS                                                (0x41500000U)
#define CSL_MPU_DSP2_SYSTEM_SIZE                                                (0x100U)
#define CSL_MPU_DSP2_MMU0CFG_REGS                                               (0x41501000U)
#define CSL_MPU_DSP2_MMU0CFG_SIZE                                               (0xb0U)
#define CSL_MPU_DSP2_MMU1CFG_REGS                                               (0x41502000U)
#define CSL_MPU_DSP2_MMU1CFG_SIZE                                               (0xb0U)
#define CSL_MPU_DSP2_FW0CFG_REGS                                                (0x41503000U)
#define CSL_MPU_DSP2_FW0CFG_SIZE                                                (0x1000U)
#define CSL_MPU_DSP2_FW1CFG_REGS                                                (0x41504000U)
#define CSL_MPU_DSP2_FW1CFG_SIZE                                                (0x1000U)
#define CSL_MPU_DSP2_EDMA_TC0_REGS                                              (0x41505000U)
#define CSL_MPU_DSP2_EDMA_TC0_SIZE                                              (0x80U)
#define CSL_MPU_DSP2_EDMA_TC1_REGS                                              (0x41506000U)
#define CSL_MPU_DSP2_EDMA_TC1_SIZE                                              (0x80U)
#define CSL_MPU_DSP2_NOC_REGS                                                   (0x41507000U)
#define CSL_MPU_DSP2_NOC_SIZE                                                   (0x1000U)
#define CSL_MPU_DSP2_DFT_REGS                                                   (0x4150f000U)
#define CSL_MPU_DSP2_DFT_SIZE                                                   (0x1000U)
#define CSL_MPU_DSP2_EDMA_CC_REGS                                               (0x41510000U)
#define CSL_MPU_DSP2_EDMA_CC_SIZE                                               (0xa98U)
#define CSL_MPU_DSP2_L1P_SRAM_REGS                                              (0x41600000U)
#define CSL_MPU_DSP2_L1P_SRAM_SIZE                                              (0x8000U)
#define CSL_MPU_DSP2_L1D_SRAM_REGS                                              (0x41700000U)
#define CSL_MPU_DSP2_L1D_SRAM_SIZE                                              (0x8000U)
#define CSL_MPU_OCMC_RAM1_CBUF_REGS                                             (0x41800000U)
#define CSL_MPU_OCMC_RAM1_CBUF_SIZE                                             (0x800000U)
#define CSL_MPU_EVE1_DMEM_REGS                                                  (0x42020000U)
#define CSL_MPU_EVE1_DMEM_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE1_WBUF_REGS                                                  (0x42040000U)
#define CSL_MPU_EVE1_WBUF_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE1_IBUFLA_REGS                                                (0x42050000U)
#define CSL_MPU_EVE1_IBUFLA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE1_IBUFHA_REGS                                                (0x42054000U)
#define CSL_MPU_EVE1_IBUFHA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE1_IBUFLB_REGS                                                (0x42070000U)
#define CSL_MPU_EVE1_IBUFLB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE1_IBUFHB_REGS                                                (0x42074000U)
#define CSL_MPU_EVE1_IBUFHB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE1_EVE_CONTROL_REGS                                           (0x42080000U)
#define CSL_MPU_EVE1_EVE_CONTROL_SIZE                                           (0x1000U)
#define CSL_MPU_EVE1_MMU0_REGS                                                  (0x42081000U)
#define CSL_MPU_EVE1_MMU0_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE1_MMU1_REGS                                                  (0x42082000U)
#define CSL_MPU_EVE1_MMU1_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE1_T16_REGS                                                   (0x42083000U)
#define CSL_MPU_EVE1_T16_SIZE                                                   (0x4U)
#define CSL_MPU_EVE1_VCOP_REGS                                                  (0x42084000U)
#define CSL_MPU_EVE1_VCOP_SIZE                                                  (0x80U)
#define CSL_MPU_EVE1_CTM_REGS                                                   (0x42085000U)
#define CSL_MPU_EVE1_CTM_SIZE                                                   (0x1a0U)
#define CSL_MPU_EVE1_TPTC0_REGS                                                 (0x42086000U)
#define CSL_MPU_EVE1_TPTC0_SIZE                                                 (0x44U)
#define CSL_MPU_EVE1_TPTC1_REGS                                                 (0x42087000U)
#define CSL_MPU_EVE1_TPTC1_SIZE                                                 (0x44U)
#define CSL_MPU_EVE1_SMSET_CONF_REGS                                            (0x42088000U)
#define CSL_MPU_EVE1_SMSET_CONF_SIZE                                            (0x50U)
#define CSL_MPU_EVE1_SMSET_SW_REGS                                              (0x42089000U)
#define CSL_MPU_EVE1_SMSET_SW_SIZE                                              (0x800U)
#define CSL_MPU_EVE1_L2_FNOC_EVE_REGS                                           (0x4208a000U)
#define CSL_MPU_EVE1_L2_FNOC_EVE_SIZE                                           (0x400U)
#define CSL_MPU_EVE1_MLB0_REGS                                                  (0x4208b000U)
#define CSL_MPU_EVE1_MLB0_SIZE                                                  (0x80U)
#define CSL_MPU_EVE1_MLB1_REGS                                                  (0x4208c000U)
#define CSL_MPU_EVE1_MLB1_SIZE                                                  (0x80U)
#define CSL_MPU_EVE1_MLB2_REGS                                                  (0x4208d000U)
#define CSL_MPU_EVE1_MLB2_SIZE                                                  (0x80U)
#define CSL_MPU_EVE1_MLB3_REGS                                                  (0x4208e000U)
#define CSL_MPU_EVE1_MLB3_SIZE                                                  (0x80U)
#define CSL_MPU_EVE1_MLB4_REGS                                                  (0x4208f000U)
#define CSL_MPU_EVE1_MLB4_SIZE                                                  (0x80U)
#define CSL_MPU_EVE1_PCACHE_RAW_REGS                                            (0x42090000U)
#define CSL_MPU_EVE1_PCACHE_RAW_SIZE                                            (0x4U)
#define CSL_MPU_EVE1_PCACHE_TAGS_REGS                                           (0x42098000U)
#define CSL_MPU_EVE1_PCACHE_TAGS_SIZE                                           (0x4U)
#define CSL_MPU_EVE1_TPCC0_REGS                                                 (0x420a0000U)
#define CSL_MPU_EVE1_TPCC0_SIZE                                                 (0xa98U)
#define CSL_MPU_EVE2_DMEM_REGS                                                  (0x42120000U)
#define CSL_MPU_EVE2_DMEM_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE2_WBUF_REGS                                                  (0x42140000U)
#define CSL_MPU_EVE2_WBUF_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE2_IBUFLA_REGS                                                (0x42150000U)
#define CSL_MPU_EVE2_IBUFLA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE2_IBUFHA_REGS                                                (0x42154000U)
#define CSL_MPU_EVE2_IBUFHA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE2_IBUFLB_REGS                                                (0x42170000U)
#define CSL_MPU_EVE2_IBUFLB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE2_IBUFHB_REGS                                                (0x42174000U)
#define CSL_MPU_EVE2_IBUFHB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE2_EVE_CONTROL_REGS                                           (0x42180000U)
#define CSL_MPU_EVE2_EVE_CONTROL_SIZE                                           (0x1000U)
#define CSL_MPU_EVE2_MMU0_REGS                                                  (0x42181000U)
#define CSL_MPU_EVE2_MMU0_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE2_MMU1_REGS                                                  (0x42182000U)
#define CSL_MPU_EVE2_MMU1_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE2_T16_REGS                                                   (0x42183000U)
#define CSL_MPU_EVE2_T16_SIZE                                                   (0x4U)
#define CSL_MPU_EVE2_VCOP_REGS                                                  (0x42184000U)
#define CSL_MPU_EVE2_VCOP_SIZE                                                  (0x80U)
#define CSL_MPU_EVE2_CTM_REGS                                                   (0x42185000U)
#define CSL_MPU_EVE2_CTM_SIZE                                                   (0x1a0U)
#define CSL_MPU_EVE2_TPTC0_REGS                                                 (0x42186000U)
#define CSL_MPU_EVE2_TPTC0_SIZE                                                 (0x44U)
#define CSL_MPU_EVE2_TPTC1_REGS                                                 (0x42187000U)
#define CSL_MPU_EVE2_TPTC1_SIZE                                                 (0x44U)
#define CSL_MPU_EVE2_SMSET_CONF_REGS                                            (0x42188000U)
#define CSL_MPU_EVE2_SMSET_CONF_SIZE                                            (0x50U)
#define CSL_MPU_EVE2_SMSET_SW_REGS                                              (0x42189000U)
#define CSL_MPU_EVE2_SMSET_SW_SIZE                                              (0x800U)
#define CSL_MPU_EVE2_L2_FNOC_EVE_REGS                                           (0x4218a000U)
#define CSL_MPU_EVE2_L2_FNOC_EVE_SIZE                                           (0x400U)
#define CSL_MPU_EVE2_MLB0_REGS                                                  (0x4218b000U)
#define CSL_MPU_EVE2_MLB0_SIZE                                                  (0x80U)
#define CSL_MPU_EVE2_MLB1_REGS                                                  (0x4218c000U)
#define CSL_MPU_EVE2_MLB1_SIZE                                                  (0x80U)
#define CSL_MPU_EVE2_MLB2_REGS                                                  (0x4218d000U)
#define CSL_MPU_EVE2_MLB2_SIZE                                                  (0x80U)
#define CSL_MPU_EVE2_MLB3_REGS                                                  (0x4218e000U)
#define CSL_MPU_EVE2_MLB3_SIZE                                                  (0x80U)
#define CSL_MPU_EVE2_MLB4_REGS                                                  (0x4218f000U)
#define CSL_MPU_EVE2_MLB4_SIZE                                                  (0x80U)
#define CSL_MPU_EVE2_PCACHE_RAW_REGS                                            (0x42190000U)
#define CSL_MPU_EVE2_PCACHE_RAW_SIZE                                            (0x4U)
#define CSL_MPU_EVE2_PCACHE_TAGS_REGS                                           (0x42198000U)
#define CSL_MPU_EVE2_PCACHE_TAGS_SIZE                                           (0x4U)
#define CSL_MPU_EVE2_TPCC0_REGS                                                 (0x421a0000U)
#define CSL_MPU_EVE2_TPCC0_SIZE                                                 (0xa98U)
#define CSL_MPU_EVE3_DMEM_REGS                                                  (0x42220000U)
#define CSL_MPU_EVE3_DMEM_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE3_WBUF_REGS                                                  (0x42240000U)
#define CSL_MPU_EVE3_WBUF_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE3_IBUFLA_REGS                                                (0x42250000U)
#define CSL_MPU_EVE3_IBUFLA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE3_IBUFHA_REGS                                                (0x42254000U)
#define CSL_MPU_EVE3_IBUFHA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE3_IBUFLB_REGS                                                (0x42270000U)
#define CSL_MPU_EVE3_IBUFLB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE3_IBUFHB_REGS                                                (0x42274000U)
#define CSL_MPU_EVE3_IBUFHB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE3_EVE_CONTROL_REGS                                           (0x42280000U)
#define CSL_MPU_EVE3_EVE_CONTROL_SIZE                                           (0x1000U)
#define CSL_MPU_EVE3_MMU0_REGS                                                  (0x42281000U)
#define CSL_MPU_EVE3_MMU0_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE3_MMU1_REGS                                                  (0x42282000U)
#define CSL_MPU_EVE3_MMU1_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE3_T16_REGS                                                   (0x42283000U)
#define CSL_MPU_EVE3_T16_SIZE                                                   (0x4U)
#define CSL_MPU_EVE3_VCOP_REGS                                                  (0x42284000U)
#define CSL_MPU_EVE3_VCOP_SIZE                                                  (0x80U)
#define CSL_MPU_EVE3_CTM_REGS                                                   (0x42285000U)
#define CSL_MPU_EVE3_CTM_SIZE                                                   (0x1a0U)
#define CSL_MPU_EVE3_TPTC0_REGS                                                 (0x42286000U)
#define CSL_MPU_EVE3_TPTC0_SIZE                                                 (0x44U)
#define CSL_MPU_EVE3_TPTC1_REGS                                                 (0x42287000U)
#define CSL_MPU_EVE3_TPTC1_SIZE                                                 (0x44U)
#define CSL_MPU_EVE3_SMSET_CONF_REGS                                            (0x42288000U)
#define CSL_MPU_EVE3_SMSET_CONF_SIZE                                            (0x50U)
#define CSL_MPU_EVE3_SMSET_SW_REGS                                              (0x42289000U)
#define CSL_MPU_EVE3_SMSET_SW_SIZE                                              (0x800U)
#define CSL_MPU_EVE3_L2_FNOC_EVE_REGS                                           (0x4228a000U)
#define CSL_MPU_EVE3_L2_FNOC_EVE_SIZE                                           (0x400U)
#define CSL_MPU_EVE3_MLB0_REGS                                                  (0x4228b000U)
#define CSL_MPU_EVE3_MLB0_SIZE                                                  (0x80U)
#define CSL_MPU_EVE3_MLB1_REGS                                                  (0x4228c000U)
#define CSL_MPU_EVE3_MLB1_SIZE                                                  (0x80U)
#define CSL_MPU_EVE3_MLB2_REGS                                                  (0x4228d000U)
#define CSL_MPU_EVE3_MLB2_SIZE                                                  (0x80U)
#define CSL_MPU_EVE3_MLB3_REGS                                                  (0x4228e000U)
#define CSL_MPU_EVE3_MLB3_SIZE                                                  (0x80U)
#define CSL_MPU_EVE3_MLB4_REGS                                                  (0x4228f000U)
#define CSL_MPU_EVE3_MLB4_SIZE                                                  (0x80U)
#define CSL_MPU_EVE3_PCACHE_RAW_REGS                                            (0x42290000U)
#define CSL_MPU_EVE3_PCACHE_RAW_SIZE                                            (0x4U)
#define CSL_MPU_EVE3_PCACHE_TAGS_REGS                                           (0x42298000U)
#define CSL_MPU_EVE3_PCACHE_TAGS_SIZE                                           (0x4U)
#define CSL_MPU_EVE3_TPCC0_REGS                                                 (0x422a0000U)
#define CSL_MPU_EVE3_TPCC0_SIZE                                                 (0xa98U)
#define CSL_MPU_EVE4_DMEM_REGS                                                  (0x42320000U)
#define CSL_MPU_EVE4_DMEM_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE4_WBUF_REGS                                                  (0x42340000U)
#define CSL_MPU_EVE4_WBUF_SIZE                                                  (0x8000U)
#define CSL_MPU_EVE4_IBUFLA_REGS                                                (0x42350000U)
#define CSL_MPU_EVE4_IBUFLA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE4_IBUFHA_REGS                                                (0x42354000U)
#define CSL_MPU_EVE4_IBUFHA_SIZE                                                (0x4000U)
#define CSL_MPU_EVE4_IBUFLB_REGS                                                (0x42370000U)
#define CSL_MPU_EVE4_IBUFLB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE4_IBUFHB_REGS                                                (0x42374000U)
#define CSL_MPU_EVE4_IBUFHB_SIZE                                                (0x4000U)
#define CSL_MPU_EVE4_EVE_CONTROL_REGS                                           (0x42380000U)
#define CSL_MPU_EVE4_EVE_CONTROL_SIZE                                           (0x1000U)
#define CSL_MPU_EVE4_MMU0_REGS                                                  (0x42381000U)
#define CSL_MPU_EVE4_MMU0_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE4_MMU1_REGS                                                  (0x42382000U)
#define CSL_MPU_EVE4_MMU1_SIZE                                                  (0xb0U)
#define CSL_MPU_EVE4_T16_REGS                                                   (0x42383000U)
#define CSL_MPU_EVE4_T16_SIZE                                                   (0x4U)
#define CSL_MPU_EVE4_VCOP_REGS                                                  (0x42384000U)
#define CSL_MPU_EVE4_VCOP_SIZE                                                  (0x80U)
#define CSL_MPU_EVE4_CTM_REGS                                                   (0x42385000U)
#define CSL_MPU_EVE4_CTM_SIZE                                                   (0x1a0U)
#define CSL_MPU_EVE4_TPTC0_REGS                                                 (0x42386000U)
#define CSL_MPU_EVE4_TPTC0_SIZE                                                 (0x44U)
#define CSL_MPU_EVE4_TPTC1_REGS                                                 (0x42387000U)
#define CSL_MPU_EVE4_TPTC1_SIZE                                                 (0x44U)
#define CSL_MPU_EVE4_SMSET_CONF_REGS                                            (0x42388000U)
#define CSL_MPU_EVE4_SMSET_CONF_SIZE                                            (0x50U)
#define CSL_MPU_EVE4_SMSET_SW_REGS                                              (0x42389000U)
#define CSL_MPU_EVE4_SMSET_SW_SIZE                                              (0x800U)
#define CSL_MPU_EVE4_L2_FNOC_EVE_REGS                                           (0x4238a000U)
#define CSL_MPU_EVE4_L2_FNOC_EVE_SIZE                                           (0x400U)
#define CSL_MPU_EVE4_MLB0_REGS                                                  (0x4238b000U)
#define CSL_MPU_EVE4_MLB0_SIZE                                                  (0x80U)
#define CSL_MPU_EVE4_MLB1_REGS                                                  (0x4238c000U)
#define CSL_MPU_EVE4_MLB1_SIZE                                                  (0x80U)
#define CSL_MPU_EVE4_MLB2_REGS                                                  (0x4238d000U)
#define CSL_MPU_EVE4_MLB2_SIZE                                                  (0x80U)
#define CSL_MPU_EVE4_MLB3_REGS                                                  (0x4238e000U)
#define CSL_MPU_EVE4_MLB3_SIZE                                                  (0x80U)
#define CSL_MPU_EVE4_MLB4_REGS                                                  (0x4238f000U)
#define CSL_MPU_EVE4_MLB4_SIZE                                                  (0x80U)
#define CSL_MPU_EVE4_PCACHE_RAW_REGS                                            (0x42390000U)
#define CSL_MPU_EVE4_PCACHE_RAW_SIZE                                            (0x4U)
#define CSL_MPU_EVE4_PCACHE_TAGS_REGS                                           (0x42398000U)
#define CSL_MPU_EVE4_PCACHE_TAGS_SIZE                                           (0x4U)
#define CSL_MPU_EVE4_TPCC0_REGS                                                 (0x423a0000U)
#define CSL_MPU_EVE4_TPCC0_SIZE                                                 (0xa98U)
#define CSL_MPU_SHA2MD5_2_ADDRSP0_REGS                                          (0x42600000U)
#define CSL_MPU_SHA2MD5_2_ADDRSP0_SIZE                                          (0x10028cU)
#define CSL_MPU_SHA2MD5_2_ADDRSP1_REGS                                          (0x42700000U)
#define CSL_MPU_SHA2MD5_2_ADDRSP1_SIZE                                          (0x100000U)
#define CSL_MPU_SPARE_TSC_ADC_REGS                                              (0x42c00000U)
#define CSL_MPU_SPARE_TSC_ADC_SIZE                                              (0x400000U)
#define CSL_MPU_EDMA_TPCC_REGS                                                  (0x43300000U)
#define CSL_MPU_EDMA_TPCC_SIZE                                                  (0xa98U)
#define CSL_MPU_EDMA_TC0_REGS                                                   (0x43400000U)
#define CSL_MPU_EDMA_TC0_SIZE                                                   (0x80U)
#define CSL_MPU_EDMA_TC1_REGS                                                   (0x43500000U)
#define CSL_MPU_EDMA_TC1_SIZE                                                   (0x80U)
#define CSL_MPU_OCMC_ROM_REGS                                                   (0x43a00000U)
#define CSL_MPU_OCMC_ROM_SIZE                                                   (0x40000U)
#define CSL_MPU_L3_MAIN_REGS                                                    (0x44000000U)
#define CSL_MPU_L3_MAIN_SIZE                                                    (0x1000U)
#define CSL_MPU_MCASP1_REGS                                                     (0x45800000U)
#define CSL_MPU_MCASP1_SIZE                                                     (0x2c0U)
#define CSL_MPU_MCASP2_REGS                                                     (0x45c00000U)
#define CSL_MPU_MCASP2_SIZE                                                     (0x2c0U)
#define CSL_MPU_MCASP3_REGS                                                     (0x46000000U)
#define CSL_MPU_MCASP3_SIZE                                                     (0x2c0U)
#define CSL_MPU_VCP1_REGS                                                       (0x46400000U)
#define CSL_MPU_VCP1_SIZE                                                       (0x10000U)
#define CSL_MPU_VCP2_REGS                                                       (0x46800000U)
#define CSL_MPU_VCP2_SIZE                                                       (0x10000U)
#define CSL_MPU_MPU_CS_STM_REGS                                                 (0x47000000U)
#define CSL_MPU_MPU_CS_STM_SIZE                                                 (0x1000000U)
#define CSL_MPU_UART3_REGS                                                      (0x48020000U)
#define CSL_MPU_UART3_SIZE                                                      (0x88U)
#define CSL_MPU_TIMER2_REGS                                                     (0x48032000U)
#define CSL_MPU_TIMER2_SIZE                                                     (0x70U)
#define CSL_MPU_TIMER3_REGS                                                     (0x48034000U)
#define CSL_MPU_TIMER3_SIZE                                                     (0x5cU)
#define CSL_MPU_TIMER4_REGS                                                     (0x48036000U)
#define CSL_MPU_TIMER4_SIZE                                                     (0x5cU)
#define CSL_MPU_TIMER9_REGS                                                     (0x4803e000U)
#define CSL_MPU_TIMER9_SIZE                                                     (0x5cU)
#define CSL_MPU_GPIO7_REGS                                                      (0x48051000U)
#define CSL_MPU_GPIO7_SIZE                                                      (0x198U)
#define CSL_MPU_GPIO8_REGS                                                      (0x48053000U)
#define CSL_MPU_GPIO8_SIZE                                                      (0x198U)
#define CSL_MPU_GPIO2_REGS                                                      (0x48055000U)
#define CSL_MPU_GPIO2_SIZE                                                      (0x198U)
#define CSL_MPU_GPIO3_REGS                                                      (0x48057000U)
#define CSL_MPU_GPIO3_SIZE                                                      (0x198U)
#define CSL_MPU_GPIO4_REGS                                                      (0x48059000U)
#define CSL_MPU_GPIO4_SIZE                                                      (0x198U)
#define CSL_MPU_GPIO5_REGS                                                      (0x4805b000U)
#define CSL_MPU_GPIO5_SIZE                                                      (0x198U)
#define CSL_MPU_GPIO6_REGS                                                      (0x4805d000U)
#define CSL_MPU_GPIO6_SIZE                                                      (0x198U)
#define CSL_MPU_I2C3_REGS                                                       (0x48060000U)
#define CSL_MPU_I2C3_SIZE                                                       (0xd6U)
#define CSL_MPU_UART5_REGS                                                      (0x48066000U)
#define CSL_MPU_UART5_SIZE                                                      (0x88U)
#define CSL_MPU_UART6_REGS                                                      (0x48068000U)
#define CSL_MPU_UART6_SIZE                                                      (0x88U)
#define CSL_MPU_UART1_REGS                                                      (0x4806a000U)
#define CSL_MPU_UART1_SIZE                                                      (0x88U)
#define CSL_MPU_UART2_REGS                                                      (0x4806c000U)
#define CSL_MPU_UART2_SIZE                                                      (0x88U)
#define CSL_MPU_UART4_REGS                                                      (0x4806e000U)
#define CSL_MPU_UART4_SIZE                                                      (0x88U)
#define CSL_MPU_I2C1_REGS                                                       (0x48070000U)
#define CSL_MPU_I2C1_SIZE                                                       (0xd6U)
#define CSL_MPU_I2C2_REGS                                                       (0x48072000U)
#define CSL_MPU_I2C2_SIZE                                                       (0xd6U)
#define CSL_MPU_ELM_REGS                                                        (0x48078000U)
#define CSL_MPU_ELM_SIZE                                                        (0x100U)
#define CSL_MPU_I2C4_REGS                                                       (0x4807a000U)
#define CSL_MPU_I2C4_SIZE                                                       (0xd6U)
#define CSL_MPU_I2C5_REGS                                                       (0x4807c000U)
#define CSL_MPU_I2C5_SIZE                                                       (0xd6U)
#define CSL_MPU_TIMER10_REGS                                                    (0x48086000U)
#define CSL_MPU_TIMER10_SIZE                                                    (0x70U)
#define CSL_MPU_TIMER11_REGS                                                    (0x48088000U)
#define CSL_MPU_TIMER11_SIZE                                                    (0x5cU)
#define CSL_MPU_RNG_REGS                                                        (0x48090000U)
#define CSL_MPU_RNG_SIZE                                                        (0x1ffcU)
#define CSL_MPU_MCSPI1_REGS                                                     (0x48098000U)
#define CSL_MPU_MCSPI1_SIZE                                                     (0x1a4U)
#define CSL_MPU_MCSPI2_REGS                                                     (0x4809a000U)
#define CSL_MPU_MCSPI2_SIZE                                                     (0x1a4U)
#define CSL_MPU_MMC1_REGS                                                       (0x4809c000U)
#define CSL_MPU_MMC1_SIZE                                                       (0x300U)
#define CSL_MPU_DMA_CRYPTO_REGS                                                 (0x480a2000U)
#define CSL_MPU_DMA_CRYPTO_SIZE                                                 (0x7cU)
#define CSL_MPU_DES3DES_ADDRSP0_REGS                                            (0x480a4000U)
#define CSL_MPU_DES3DES_ADDRSP0_SIZE                                            (0x1044U)
#define CSL_MPU_DES3DES_ADDRSP1_REGS                                            (0x480a5000U)
#define CSL_MPU_DES3DES_ADDRSP1_SIZE                                            (0x1000U)
#define CSL_MPU_FPKA_REGS                                                       (0x480a8080U)
#define CSL_MPU_FPKA_SIZE                                                       (0x2f80U)
#define CSL_MPU_MMC3_REGS                                                       (0x480ad000U)
#define CSL_MPU_MMC3_SIZE                                                       (0x300U)
#define CSL_MPU_HDQ1W_REGS                                                      (0x480b2000U)
#define CSL_MPU_HDQ1W_SIZE                                                      (0x1cU)
#define CSL_MPU_MMC2_REGS                                                       (0x480b4000U)
#define CSL_MPU_MMC2_SIZE                                                       (0x300U)
#define CSL_MPU_MCSPI3_REGS                                                     (0x480b8000U)
#define CSL_MPU_MCSPI3_SIZE                                                     (0x1a4U)
#define CSL_MPU_MCSPI4_REGS                                                     (0x480ba000U)
#define CSL_MPU_MCSPI4_SIZE                                                     (0x1a4U)
#define CSL_MPU_MMC4_REGS                                                       (0x480d1000U)
#define CSL_MPU_MMC4_SIZE                                                       (0x300U)
#define CSL_MPU_INTC_MPU_DISTRIBUTOR_REGS                                       (0x48211000U)
#define CSL_MPU_INTC_MPU_DISTRIBUTOR_SIZE                                       (0x1000U)
#define CSL_MPU_INTC_MPU_PHYS_CPU_IF_REGS                                       (0x48212000U)
#define CSL_MPU_INTC_MPU_PHYS_CPU_IF_SIZE                                       (0x1004U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_HYP_REGS                                   (0x48214000U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_HYP_SIZE                                   (0x110U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_VM_REGS                                    (0x48216000U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_VM_SIZE                                    (0x1004U)
#define CSL_MPU_MPU_PRCM_REGS                                                   (0x48243000U)
#define CSL_MPU_MPU_PRCM_SIZE                                                   (0x80U)
#define CSL_MPU_PRCM_MPU_OCP_SOCKET_REGS                                        (0x48243000U)
#define CSL_MPU_PRCM_MPU_OCP_SOCKET_SIZE                                        (0x4U)
#define CSL_MPU_PRCM_MPU_DEVICE_REGS                                            (0x48243200U)
#define CSL_MPU_PRCM_MPU_DEVICE_SIZE                                            (0x18U)
#define CSL_MPU_PRCM_MPU_PRM_C0_REGS                                            (0x48243400U)
#define CSL_MPU_PRCM_MPU_PRM_C0_SIZE                                            (0x28U)
#define CSL_MPU_PRCM_MPU_CM_C0_REGS                                             (0x48243600U)
#define CSL_MPU_PRCM_MPU_CM_C0_SIZE                                             (0x24U)
#define CSL_MPU_PRCM_MPU_PRM_C1_REGS                                            (0x48243800U)
#define CSL_MPU_PRCM_MPU_PRM_C1_SIZE                                            (0x28U)
#define CSL_MPU_PRCM_MPU_CM_C1_REGS                                             (0x48243a00U)
#define CSL_MPU_PRCM_MPU_CM_C1_SIZE                                             (0x24U)
#define CSL_MPU_MPU_SCM_REGS                                                    (0x48280004U)
#define CSL_MPU_MPU_SCM_SIZE                                                    (0x34U)
#define CSL_MPU_MPU_WUGEN_REGS                                                  (0x48281000U)
#define CSL_MPU_MPU_WUGEN_SIZE                                                  (0xc10U)
#define CSL_MPU_MPU_CMU_REGS                                                    (0x48290000U)
#define CSL_MPU_MPU_CMU_SIZE                                                    (0x20U)
#define CSL_MPU_WATCHDOGTIMER_REGS                                              (0x482a0000U)
#define CSL_MPU_WATCHDOGTIMER_SIZE                                              (0x20U)
#define CSL_MPU_AXI2OCP_RPT_REGS                                                (0x482a1000U)
#define CSL_MPU_AXI2OCP_RPT_SIZE                                                (0x54U)
#define CSL_MPU_AXI2OCP_MISC_REGS                                               (0x482a2000U)
#define CSL_MPU_AXI2OCP_MISC_SIZE                                               (0x4U)
#define CSL_MPU_MA_MPU_LSM_REGS                                                 (0x482af010U)
#define CSL_MPU_MA_MPU_LSM_SIZE                                                 (0x40U)
#define CSL_MPU_MA_MPU_WP_REGS                                                  (0x482af200U)
#define CSL_MPU_MA_MPU_WP_SIZE                                                  (0x44U)
#define CSL_MPU_UART7_REGS                                                      (0x48420000U)
#define CSL_MPU_UART7_SIZE                                                      (0x88U)
#define CSL_MPU_UART8_REGS                                                      (0x48422000U)
#define CSL_MPU_UART8_SIZE                                                      (0x88U)
#define CSL_MPU_UART9_REGS                                                      (0x48424000U)
#define CSL_MPU_UART9_SIZE                                                      (0x88U)
#define CSL_MPU_MLB_REGS                                                        (0x4842c000U)
#define CSL_MPU_MLB_SIZE                                                        (0x1000U)
#define CSL_MPU_MCASP4_DAT_REGS                                                 (0x48436000U)
#define CSL_MPU_MCASP4_DAT_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP5_DAT_REGS                                                 (0x4843a000U)
#define CSL_MPU_MCASP5_DAT_SIZE                                                 (0x2c0U)
#define CSL_MPU_ATL_REGS                                                        (0x4843c000U)
#define CSL_MPU_ATL_SIZE                                                        (0x1000U)
#define CSL_MPU_PWMSS1_IPWMSS_REGS                                              (0x4843e000U)
#define CSL_MPU_PWMSS1_IPWMSS_SIZE                                              (0x30U)
#define CSL_MPU_PWMSS1_IECAP_REGS                                               (0x4843e100U)
#define CSL_MPU_PWMSS1_IECAP_SIZE                                               (0x190U)
#define CSL_MPU_PWMSS1_IEQEP_REGS                                               (0x4843e180U)
#define CSL_MPU_PWMSS1_IEQEP_SIZE                                               (0x74U)
#define CSL_MPU_PWMSS1_IEPWM_REGS                                               (0x4843e200U)
#define CSL_MPU_PWMSS1_IEPWM_SIZE                                               (0x88U)
#define CSL_MPU_PWMSS2_IPWMSS_REGS                                              (0x48440000U)
#define CSL_MPU_PWMSS2_IPWMSS_SIZE                                              (0x30U)
#define CSL_MPU_PWMSS2_IECAP_REGS                                               (0x48440100U)
#define CSL_MPU_PWMSS2_IECAP_SIZE                                               (0x190U)
#define CSL_MPU_PWMSS2_IEQEP_REGS                                               (0x48440180U)
#define CSL_MPU_PWMSS2_IEQEP_SIZE                                               (0x74U)
#define CSL_MPU_PWMSS2_IEPWM_REGS                                               (0x48440200U)
#define CSL_MPU_PWMSS2_IEPWM_SIZE                                               (0x88U)
#define CSL_MPU_PWMSS3_IPWMSS_REGS                                              (0x48442000U)
#define CSL_MPU_PWMSS3_IPWMSS_SIZE                                              (0x30U)
#define CSL_MPU_PWMSS3_IECAP_REGS                                               (0x48442100U)
#define CSL_MPU_PWMSS3_IECAP_SIZE                                               (0x190U)
#define CSL_MPU_PWMSS3_IEQEP_REGS                                               (0x48442180U)
#define CSL_MPU_PWMSS3_IEQEP_SIZE                                               (0x74U)
#define CSL_MPU_PWMSS3_IEPWM_REGS                                               (0x48442200U)
#define CSL_MPU_PWMSS3_IEPWM_SIZE                                               (0x88U)
#define CSL_MPU_VCP1_CFG_REGS                                                   (0x48446000U)
#define CSL_MPU_VCP1_CFG_SIZE                                                   (0x10000U)
#define CSL_MPU_VCP2_CFG_REGS                                                   (0x48448000U)
#define CSL_MPU_VCP2_CFG_SIZE                                                   (0x10000U)
#define CSL_MPU_DELAYLINE_REGS                                                  (0x4844a000U)
#define CSL_MPU_DELAYLINE_SIZE                                                  (0xd20U)
#define CSL_MPU_MCASP6_DAT_REGS                                                 (0x4844c000U)
#define CSL_MPU_MCASP6_DAT_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP7_DAT_REGS                                                 (0x48450000U)
#define CSL_MPU_MCASP7_DAT_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP8_DAT_REGS                                                 (0x48454000U)
#define CSL_MPU_MCASP8_DAT_SIZE                                                 (0x2c0U)
#define CSL_MPU_SPARE_UNKNOWN4_REGS                                             (0x48458000U)
#define CSL_MPU_SPARE_UNKNOWN4_SIZE                                             (0x2000U)
#define CSL_MPU_SPARE_UNKNOWN5_REGS                                             (0x4845b000U)
#define CSL_MPU_SPARE_UNKNOWN5_SIZE                                             (0x2000U)
#define CSL_MPU_SPARE_UNKNOWN6_REGS                                             (0x4845d000U)
#define CSL_MPU_SPARE_UNKNOWN6_SIZE                                             (0x2000U)
#define CSL_MPU_MCASP1_CFG_REGS                                                 (0x48460000U)
#define CSL_MPU_MCASP1_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP2_CFG_REGS                                                 (0x48464000U)
#define CSL_MPU_MCASP2_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP3_CFG_REGS                                                 (0x48468000U)
#define CSL_MPU_MCASP3_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP4_CFG_REGS                                                 (0x4846c000U)
#define CSL_MPU_MCASP4_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP5_CFG_REGS                                                 (0x48470000U)
#define CSL_MPU_MCASP5_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP6_CFG_REGS                                                 (0x48474000U)
#define CSL_MPU_MCASP6_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP7_CFG_REGS                                                 (0x48478000U)
#define CSL_MPU_MCASP7_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_MCASP8_CFG_REGS                                                 (0x4847c000U)
#define CSL_MPU_MCASP8_CFG_SIZE                                                 (0x2c0U)
#define CSL_MPU_DCAN2_REGS                                                      (0x48480000U)
#define CSL_MPU_DCAN2_SIZE                                                      (0x220U)
#define CSL_MPU_ISS_REGS                                                        (0x48484000U)
#define CSL_MPU_ISS_SIZE                                                        (0x50U)
#define CSL_MPU_IPORT_REGS                                                      (0x48484100U)
#define CSL_MPU_IPORT_SIZE                                                      (0x940U)
#define CSL_MPU_ICPDMA_REGS                                                     (0x48484800U)
#define CSL_MPU_ICPDMA_SIZE                                                     (0x2e0U)
#define CSL_MPU_ISTATERAM_REGS                                                  (0x48484a00U)
#define CSL_MPU_ISTATERAM_SIZE                                                  (0x120U)
#define CSL_MPU_ICPTS_REGS                                                      (0x48484c00U)
#define CSL_MPU_ICPTS_SIZE                                                      (0xf0U)
#define CSL_MPU_IALE_REGS                                                       (0x48484d00U)
#define CSL_MPU_IALE_SIZE                                                       (0x170U)
#define CSL_MPU_ISL1_REGS                                                       (0x48484d80U)
#define CSL_MPU_ISL1_SIZE                                                       (0x80U)
#define CSL_MPU_ISL2_REGS                                                       (0x48484dc0U)
#define CSL_MPU_ISL2_SIZE                                                       (0x80U)
#define CSL_MPU_IMDIO_REGS                                                      (0x48485000U)
#define CSL_MPU_IMDIO_SIZE                                                      (0xc0U)
#define CSL_MPU_IWR_REGS                                                        (0x48485200U)
#define CSL_MPU_IWR_SIZE                                                        (0x160U)
#define CSL_MPU_MAILBOX13_REGS                                                  (0x48802000U)
#define CSL_MPU_MAILBOX13_SIZE                                                  (0x14U)
#define CSL_MPU_OCMC_RAM1_CFG_REGS                                              (0x48804000U)
#define CSL_MPU_OCMC_RAM1_CFG_SIZE                                              (0x1000U)
#define CSL_MPU_OCMC_RAM2_CFG_REGS                                              (0x4880a000U)
#define CSL_MPU_OCMC_RAM2_CFG_SIZE                                              (0x1000U)
#define CSL_MPU_OCMC_RAM3_CFG_REGS                                              (0x48810000U)
#define CSL_MPU_OCMC_RAM3_CFG_SIZE                                              (0x1000U)
#define CSL_MPU_SPARE_SATA2_REGS                                                (0x48816000U)
#define CSL_MPU_SPARE_SATA2_SIZE                                                (0x1000U)
#define CSL_MPU_L4_PER3_MMU1_REGS                                               (0x4881c000U)
#define CSL_MPU_L4_PER3_MMU1_SIZE                                               (0xb0U)
#define CSL_MPU_MMU2_REGS                                                       (0x4881e000U)
#define CSL_MPU_MMU2_SIZE                                                       (0xb0U)
#define CSL_MPU_TIMER5_REGS                                                     (0x48820000U)
#define CSL_MPU_TIMER5_SIZE                                                     (0x5cU)
#define CSL_MPU_TIMER6_REGS                                                     (0x48822000U)
#define CSL_MPU_TIMER6_SIZE                                                     (0x5cU)
#define CSL_MPU_TIMER7_REGS                                                     (0x48824000U)
#define CSL_MPU_TIMER7_SIZE                                                     (0x5cU)
#define CSL_MPU_TIMER8_REGS                                                     (0x48826000U)
#define CSL_MPU_TIMER8_SIZE                                                     (0x5cU)
#define CSL_MPU_TIMER13_REGS                                                    (0x48828000U)
#define CSL_MPU_TIMER13_SIZE                                                    (0x5cU)
#define CSL_MPU_TIMER14_REGS                                                    (0x4882a000U)
#define CSL_MPU_TIMER14_SIZE                                                    (0x5cU)
#define CSL_MPU_TIMER15_REGS                                                    (0x4882c000U)
#define CSL_MPU_TIMER15_SIZE                                                    (0x5cU)
#define CSL_MPU_TIMER16_REGS                                                    (0x4882e000U)
#define CSL_MPU_TIMER16_SIZE                                                    (0x5cU)
#define CSL_MPU_RTC_SS_REGS                                                     (0x48838000U)
#define CSL_MPU_RTC_SS_SIZE                                                     (0xa0U)
#define CSL_MPU_MAILBOX2_REGS                                                   (0x4883a000U)
#define CSL_MPU_MAILBOX2_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX3_REGS                                                   (0x4883c000U)
#define CSL_MPU_MAILBOX3_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX4_REGS                                                   (0x4883e000U)
#define CSL_MPU_MAILBOX4_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX5_REGS                                                   (0x48840000U)
#define CSL_MPU_MAILBOX5_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX6_REGS                                                   (0x48842000U)
#define CSL_MPU_MAILBOX6_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX7_REGS                                                   (0x48844000U)
#define CSL_MPU_MAILBOX7_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX8_REGS                                                   (0x48846000U)
#define CSL_MPU_MAILBOX8_SIZE                                                   (0x14U)
#define CSL_MPU_SPARE_ICM_REGS                                                  (0x48848000U)
#define CSL_MPU_SPARE_ICM_SIZE                                                  (0x2000U)
#define CSL_MPU_SPARE_HDMI_RX_REGS                                              (0x4884a000U)
#define CSL_MPU_SPARE_HDMI_RX_SIZE                                              (0x2000U)
#define CSL_MPU_SPARE_LVDS_TX1_REGS                                             (0x4884c000U)
#define CSL_MPU_SPARE_LVDS_TX1_SIZE                                             (0x2000U)
#define CSL_MPU_CSI2_2_REGS                                                     (0x4884e000U)
#define CSL_MPU_CSI2_2_SIZE                                                     (0x2000U)
#define CSL_MPU_SPARE_VENC_REGS                                                 (0x48850000U)
#define CSL_MPU_SPARE_VENC_SIZE                                                 (0x2000U)
#define CSL_MPU_LVDS_RX_REGS                                                    (0x48852000U)
#define CSL_MPU_LVDS_RX_SIZE                                                    (0x2000U)
#define CSL_MPU_CSI2_1_REGS                                                     (0x48854000U)
#define CSL_MPU_CSI2_1_SIZE                                                     (0x2000U)
#define CSL_MPU_SPARE_VIDEOPLL1_REGS                                            (0x48856000U)
#define CSL_MPU_SPARE_VIDEOPLL1_SIZE                                            (0x2000U)
#define CSL_MPU_SPARE_VIDEOPLL2_REGS                                            (0x48858000U)
#define CSL_MPU_SPARE_VIDEOPLL2_SIZE                                            (0x2000U)
#define CSL_MPU_SPARE_VIDEOPLL3_REGS                                            (0x4885a000U)
#define CSL_MPU_SPARE_VIDEOPLL3_SIZE                                            (0x2000U)
#define CSL_MPU_SPARE_CME_REGS                                                  (0x4885c000U)
#define CSL_MPU_SPARE_CME_SIZE                                                  (0x2000U)
#define CSL_MPU_MAILBOX9_REGS                                                   (0x4885e000U)
#define CSL_MPU_MAILBOX9_SIZE                                                   (0x14U)
#define CSL_MPU_MAILBOX10_REGS                                                  (0x48860000U)
#define CSL_MPU_MAILBOX10_SIZE                                                  (0x14U)
#define CSL_MPU_MAILBOX11_REGS                                                  (0x48862000U)
#define CSL_MPU_MAILBOX11_SIZE                                                  (0x14U)
#define CSL_MPU_MAILBOX12_REGS                                                  (0x48864000U)
#define CSL_MPU_MAILBOX12_SIZE                                                  (0x14U)
#define CSL_MPU_USB1_CFG_USBOTGSS_WRAPPER_REGS                                  (0x48880000U)
#define CSL_MPU_USB1_CFG_USBOTGSS_WRAPPER_SIZE                                  (0x24U)
#define CSL_MPU_USB1_CFG_DWC_USB3_REGS                                          (0x48890000U)
#define CSL_MPU_USB1_CFG_DWC_USB3_SIZE                                          (0x400U)
#define CSL_MPU_USB2_CFG_USBOTGSS_WRAPPER_REGS                                  (0x488c0000U)
#define CSL_MPU_USB2_CFG_USBOTGSS_WRAPPER_SIZE                                  (0x24U)
#define CSL_MPU_USB2_CFG_DWC_USB3_REGS                                          (0x488d0000U)
#define CSL_MPU_USB2_CFG_DWC_USB3_SIZE                                          (0x400U)
#define CSL_MPU_USB3_CFG_USBOTGSS_WRAPPER_REGS                                  (0x48900000U)
#define CSL_MPU_USB3_CFG_USBOTGSS_WRAPPER_SIZE                                  (0x24U)
#define CSL_MPU_USB3_CFG_DWC_USB3_REGS                                          (0x48910000U)
#define CSL_MPU_USB3_CFG_DWC_USB3_SIZE                                          (0x400U)
#define CSL_MPU_USB4_CFG_USBOTGSS_WRAPPER_REGS                                  (0x48940000U)
#define CSL_MPU_USB4_CFG_USBOTGSS_WRAPPER_SIZE                                  (0x24U)
#define CSL_MPU_USB4_CFG_DWC_USB3_REGS                                          (0x48950000U)
#define CSL_MPU_USB4_CFG_DWC_USB3_SIZE                                          (0x400U)
#define CSL_MPU_VIP1_VIP_REGS_REGS                                              (0x48970000U)
#define CSL_MPU_VIP1_VIP_REGS_SIZE                                              (0x114U)
#define CSL_MPU_VIP1_VIP_PARSER_SLICE0_REGS_REGS                                (0x48975500U)
#define CSL_MPU_VIP1_VIP_PARSER_SLICE0_REGS_SIZE                                (0xe8U)
#define CSL_MPU_VIP1_VIP_CSC_SLICE0_REGS_REGS                                   (0x48975700U)
#define CSL_MPU_VIP1_VIP_CSC_SLICE0_REGS_SIZE                                   (0x18U)
#define CSL_MPU_VIP1_VIP_SC_SLICE0_REGS_REGS                                    (0x48975800U)
#define CSL_MPU_VIP1_VIP_SC_SLICE0_REGS_SIZE                                    (0x80U)
#define CSL_MPU_VIP1_VIP_PARSER_SLICE1_REGS_REGS                                (0x48975a00U)
#define CSL_MPU_VIP1_VIP_PARSER_SLICE1_REGS_SIZE                                (0xe8U)
#define CSL_MPU_VIP1_VIP_CSC_SLICE1_REGS_REGS                                   (0x48975c00U)
#define CSL_MPU_VIP1_VIP_CSC_SLICE1_REGS_SIZE                                   (0x18U)
#define CSL_MPU_VIP1_VIP_SC_SLICE1_REGS_REGS                                    (0x48975d00U)
#define CSL_MPU_VIP1_VIP_SC_SLICE1_REGS_SIZE                                    (0x80U)
#define CSL_MPU_VIP1_VIP_VPDMA_REGS_REGS                                        (0x4897d000U)
#define CSL_MPU_VIP1_VIP_VPDMA_REGS_SIZE                                        (0x3f8U)
#define CSL_MPU_VIP2_VIP_REGS_REGS                                              (0x48990000U)
#define CSL_MPU_VIP2_VIP_REGS_SIZE                                              (0x114U)
#define CSL_MPU_VIP2_VIP_PARSER_SLICE0_REGS_REGS                                (0x48995500U)
#define CSL_MPU_VIP2_VIP_PARSER_SLICE0_REGS_SIZE                                (0xe8U)
#define CSL_MPU_VIP2_VIP_CSC_SLICE0_REGS_REGS                                   (0x48995700U)
#define CSL_MPU_VIP2_VIP_CSC_SLICE0_REGS_SIZE                                   (0x18U)
#define CSL_MPU_VIP2_VIP_SC_SLICE0_REGS_REGS                                    (0x48995800U)
#define CSL_MPU_VIP2_VIP_SC_SLICE0_REGS_SIZE                                    (0x80U)
#define CSL_MPU_VIP2_VIP_PARSER_SLICE1_REGS_REGS                                (0x48995a00U)
#define CSL_MPU_VIP2_VIP_PARSER_SLICE1_REGS_SIZE                                (0xe8U)
#define CSL_MPU_VIP2_VIP_CSC_SLICE1_REGS_REGS                                   (0x48995c00U)
#define CSL_MPU_VIP2_VIP_CSC_SLICE1_REGS_SIZE                                   (0x18U)
#define CSL_MPU_VIP2_VIP_SC_SLICE1_REGS_REGS                                    (0x48995d00U)
#define CSL_MPU_VIP2_VIP_SC_SLICE1_REGS_SIZE                                    (0x80U)
#define CSL_MPU_VIP2_VIP_VPDMA_REGS_REGS                                        (0x4899d000U)
#define CSL_MPU_VIP2_VIP_VPDMA_REGS_SIZE                                        (0x3f8U)
#define CSL_MPU_VIP3_VIP_REGS_REGS                                              (0x489b0000U)
#define CSL_MPU_VIP3_VIP_REGS_SIZE                                              (0x114U)
#define CSL_MPU_VIP3_VIP_PARSER_SLICE0_REGS_REGS                                (0x489b5500U)
#define CSL_MPU_VIP3_VIP_PARSER_SLICE0_REGS_SIZE                                (0xe8U)
#define CSL_MPU_VIP3_VIP_CSC_SLICE0_REGS_REGS                                   (0x489b5700U)
#define CSL_MPU_VIP3_VIP_CSC_SLICE0_REGS_SIZE                                   (0x18U)
#define CSL_MPU_VIP3_VIP_SC_SLICE0_REGS_REGS                                    (0x489b5800U)
#define CSL_MPU_VIP3_VIP_SC_SLICE0_REGS_SIZE                                    (0x80U)
#define CSL_MPU_VIP3_VIP_PARSER_SLICE1_REGS_REGS                                (0x489b5a00U)
#define CSL_MPU_VIP3_VIP_PARSER_SLICE1_REGS_SIZE                                (0xe8U)
#define CSL_MPU_VIP3_VIP_CSC_SLICE1_REGS_REGS                                   (0x489b5c00U)
#define CSL_MPU_VIP3_VIP_CSC_SLICE1_REGS_SIZE                                   (0x18U)
#define CSL_MPU_VIP3_VIP_SC_SLICE1_REGS_REGS                                    (0x489b5d00U)
#define CSL_MPU_VIP3_VIP_SC_SLICE1_REGS_SIZE                                    (0x80U)
#define CSL_MPU_VIP3_VIP_VPDMA_REGS_REGS                                        (0x489bd000U)
#define CSL_MPU_VIP3_VIP_VPDMA_REGS_SIZE                                        (0x3f8U)
#define CSL_MPU_VPE_REGS_REGS                                                   (0x489d0000U)
#define CSL_MPU_VPE_REGS_SIZE                                                   (0x120U)
#define CSL_MPU_CHR_US_INST0_REGS_REGS                                          (0x489d0300U)
#define CSL_MPU_CHR_US_INST0_REGS_SIZE                                          (0x24U)
#define CSL_MPU_CHR_US_INST1_REGS_REGS                                          (0x489d0400U)
#define CSL_MPU_CHR_US_INST1_REGS_SIZE                                          (0x24U)
#define CSL_MPU_CHR_US_INST2_REGS_REGS                                          (0x489d0500U)
#define CSL_MPU_CHR_US_INST2_REGS_SIZE                                          (0x24U)
#define CSL_MPU_DEI_REGS_REGS                                                   (0x489d0600U)
#define CSL_MPU_DEI_REGS_SIZE                                                   (0x3cU)
#define CSL_MPU_SC_REGS_REGS                                                    (0x489d0700U)
#define CSL_MPU_SC_REGS_SIZE                                                    (0x80U)
#define CSL_MPU_CSC_REGS_REGS                                                   (0x489d5700U)
#define CSL_MPU_CSC_REGS_SIZE                                                   (0x18U)
#define CSL_MPU_VPDMA_REGS_REGS                                                 (0x489dd000U)
#define CSL_MPU_VPDMA_REGS_SIZE                                                 (0x3f8U)
#define CSL_MPU_OCMC_RAM2_CBUF_REGS                                             (0x49000000U)
#define CSL_MPU_OCMC_RAM2_CBUF_SIZE                                             (0x800000U)
#define CSL_MPU_OCMC_RAM3_CBUF_REGS                                             (0x49800000U)
#define CSL_MPU_OCMC_RAM3_CBUF_SIZE                                             (0x800000U)
#define CSL_MPU_IA_IP0_REGS                                                     (0x4a001000U)
#define CSL_MPU_IA_IP0_SIZE                                                     (0x1000U)
#define CSL_MPU_CTRL_MODULE_CORE_REGS                                           (0x4a002000U)
#define CSL_MPU_CTRL_MODULE_CORE_SIZE                                           (0x80U)
#define CSL_MPU_CTRL_MODULE_CORE_CORE_REGISTERS_REGS                            (0x4a002100U)
#define CSL_MPU_CTRL_MODULE_CORE_CORE_REGISTERS_SIZE                            (0xfccU)
#define CSL_MPU_IRQ_DMARQ_CROSSBAR_REGISTERS_REGS                               (0x4a0027a0U)
#define CSL_MPU_IRQ_DMARQ_CROSSBAR_REGISTERS_SIZE                               (0x5b4U)
#define CSL_MPU_CTRL_MODULE_CORE_CORE_PAD_REGISTERS_REGS                        (0x4a002da0U)
#define CSL_MPU_CTRL_MODULE_CORE_CORE_PAD_REGISTERS_SIZE                        (0xecU)
#define CSL_MPU_CORE_PAD_IO_REGISTERS_REGS                                      (0x4a003400U)
#define CSL_MPU_CORE_PAD_IO_REGISTERS_SIZE                                      (0x48cU)
#define CSL_MPU_SEC_EFUSE_REGISTERS_REGS                                        (0x4a003a00U)
#define CSL_MPU_SEC_EFUSE_REGISTERS_SIZE                                        (0x248U)
#define CSL_MPU_TA_CTRL_MODULE_CORE_TARG_REGS                                   (0x4a004000U)
#define CSL_MPU_TA_CTRL_MODULE_CORE_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_AON_REGS                                     (0x4a005000U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_AON_SIZE                                     (0x100U)
#define CSL_MPU_CKGEN_CM_CORE_AON_REGS                                          (0x4a005100U)
#define CSL_MPU_CKGEN_CM_CORE_AON_SIZE                                          (0x1f8U)
#define CSL_MPU_MPU_CM_CORE_AON_REGS                                            (0x4a005300U)
#define CSL_MPU_MPU_CM_CORE_AON_SIZE                                            (0x2cU)
#define CSL_MPU_DSP1_CM_CORE_AON_REGS                                           (0x4a005400U)
#define CSL_MPU_DSP1_CM_CORE_AON_SIZE                                           (0x24U)
#define CSL_MPU_IPU_CM_CORE_AON_REGS                                            (0x4a005500U)
#define CSL_MPU_IPU_CM_CORE_AON_SIZE                                            (0x84U)
#define CSL_MPU_DSP2_CM_CORE_AON_REGS                                           (0x4a005600U)
#define CSL_MPU_DSP2_CM_CORE_AON_SIZE                                           (0x24U)
#define CSL_MPU_EVE1_CM_CORE_AON_REGS                                           (0x4a005640U)
#define CSL_MPU_EVE1_CM_CORE_AON_SIZE                                           (0x24U)
#define CSL_MPU_EVE2_CM_CORE_AON_REGS                                           (0x4a005680U)
#define CSL_MPU_EVE2_CM_CORE_AON_SIZE                                           (0x24U)
#define CSL_MPU_EVE3_CM_CORE_AON_REGS                                           (0x4a0056c0U)
#define CSL_MPU_EVE3_CM_CORE_AON_SIZE                                           (0x24U)
#define CSL_MPU_EVE4_CM_CORE_AON_REGS                                           (0x4a005700U)
#define CSL_MPU_EVE4_CM_CORE_AON_SIZE                                           (0x24U)
#define CSL_MPU_RTC_CM_CORE_AON_REGS                                            (0x4a005740U)
#define CSL_MPU_RTC_CM_CORE_AON_SIZE                                            (0x8U)
#define CSL_MPU_VPE_CM_CORE_AON_REGS                                            (0x4a005760U)
#define CSL_MPU_VPE_CM_CORE_AON_SIZE                                            (0xcU)
#define CSL_MPU_RESTORE_CM_CORE_AON_REGS                                        (0x4a005e00U)
#define CSL_MPU_RESTORE_CM_CORE_AON_SIZE                                        (0x54U)
#define CSL_MPU_INSTR_CM_CORE_AON_REGS                                          (0x4a005f00U)
#define CSL_MPU_INSTR_CM_CORE_AON_SIZE                                          (0x34U)
#define CSL_MPU_TA_CM_CORE_AON_TARG_REGS                                        (0x4a006000U)
#define CSL_MPU_TA_CM_CORE_AON_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_REGS                                         (0x4a008000U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_SIZE                                         (0xf4U)
#define CSL_MPU_CKGEN_CM_CORE_REGS                                              (0x4a008100U)
#define CSL_MPU_CKGEN_CM_CORE_SIZE                                              (0x128U)
#define CSL_MPU_COREAON_CM_CORE_REGS                                            (0x4a008600U)
#define CSL_MPU_COREAON_CM_CORE_SIZE                                            (0xd4U)
#define CSL_MPU_CORE_CM_CORE_REGS                                               (0x4a008700U)
#define CSL_MPU_CORE_CM_CORE_SIZE                                               (0x754U)
#define CSL_MPU_IVA_CM_CORE_REGS                                                (0x4a008f00U)
#define CSL_MPU_IVA_CM_CORE_SIZE                                                (0x2cU)
#define CSL_MPU_CAM_CM_CORE_REGS                                                (0x4a009000U)
#define CSL_MPU_CAM_CM_CORE_SIZE                                                (0x4cU)
#define CSL_MPU_DSS_CM_CORE_REGS                                                (0x4a009100U)
#define CSL_MPU_DSS_CM_CORE_SIZE                                                (0x40U)
#define CSL_MPU_GPU_CM_CORE_REGS                                                (0x4a009200U)
#define CSL_MPU_GPU_CM_CORE_SIZE                                                (0x24U)
#define CSL_MPU_L3INIT_CM_CORE_REGS                                             (0x4a009300U)
#define CSL_MPU_L3INIT_CM_CORE_SIZE                                             (0xf4U)
#define CSL_MPU_CUSTEFUSE_CM_CORE_REGS                                          (0x4a009600U)
#define CSL_MPU_CUSTEFUSE_CM_CORE_SIZE                                          (0x24U)
#define CSL_MPU_L4PER_CM_CORE_REGS                                              (0x4a009700U)
#define CSL_MPU_L4PER_CM_CORE_SIZE                                              (0x218U)
#define CSL_MPU_RESTORE_CM_CORE_REGS                                            (0x4a009e00U)
#define CSL_MPU_RESTORE_CM_CORE_SIZE                                            (0x58U)
#define CSL_MPU_TA_CM_CORE_TARG_REGS                                            (0x4a00a000U)
#define CSL_MPU_TA_CM_CORE_TARG_SIZE                                            (0x1000U)
#define CSL_MPU_DMA_SYSTEM_REGS                                                 (0x4a056000U)
#define CSL_MPU_DMA_SYSTEM_SIZE                                                 (0x7cU)
#define CSL_MPU_TA_DMA_SYSTEM_TARG_REGS                                         (0x4a057000U)
#define CSL_MPU_TA_DMA_SYSTEM_TARG_SIZE                                         (0x1000U)
#define CSL_MPU_SAR_ROM_REGS                                                    (0x4a05e000U)
#define CSL_MPU_SAR_ROM_SIZE                                                    (0x2000U)
#define CSL_MPU_TA_SAR_ROM_TARG_REGS                                            (0x4a060000U)
#define CSL_MPU_TA_SAR_ROM_TARG_SIZE                                            (0x1000U)
#define CSL_MPU_OCP2SCP1_REGS                                                   (0x4a080000U)
#define CSL_MPU_OCP2SCP1_SIZE                                                   (0x1cU)
#define CSL_MPU_OCP2SCP1_USB_PHY1_CORE_REGS                                     (0x4a084000U)
#define CSL_MPU_OCP2SCP1_USB_PHY1_CORE_SIZE                                     (0x7cU)
#define CSL_MPU_OCP2SCP1_USB3RX_PHY_USB_REGS                                    (0x4a084400U)
#define CSL_MPU_OCP2SCP1_USB3RX_PHY_USB_SIZE                                    (0x68U)
#define CSL_MPU_OCP2SCP1_USB3TX_PHY_USB_REGS                                    (0x4a084800U)
#define CSL_MPU_OCP2SCP1_USB3TX_PHY_USB_SIZE                                    (0x38U)
#define CSL_MPU_OCP2SCP1_DPLLCTRL_USB_OTG_SS_REGS                               (0x4a084c00U)
#define CSL_MPU_OCP2SCP1_DPLLCTRL_USB_OTG_SS_SIZE                               (0x400U)
#define CSL_MPU_OCP2SCP1_USB_PHY2_CORE_REGS                                     (0x4a085000U)
#define CSL_MPU_OCP2SCP1_USB_PHY2_CORE_SIZE                                     (0x7cU)
#define CSL_MPU_TA_OCP2SCP1_TARG_REGS                                           (0x4a088000U)
#define CSL_MPU_TA_OCP2SCP1_TARG_SIZE                                           (0x1000U)
#define CSL_MPU_OCP2SCP3_REGS                                                   (0x4a090000U)
#define CSL_MPU_OCP2SCP3_SIZE                                                   (0x1cU)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_PCIE1_REGS                                  (0x4a094000U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_PCIE1_SIZE                                  (0x68U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_PCIE1_REGS                                  (0x4a094400U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_PCIE1_SIZE                                  (0x38U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_PCIE1_REGS                                    (0x4a094800U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_PCIE1_SIZE                                    (0x400U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_PCIE2_REGS                                  (0x4a095000U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_PCIE2_SIZE                                  (0x68U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_PCIE2_REGS                                  (0x4a095400U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_PCIE2_SIZE                                  (0x38U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_SATA_REGS                                   (0x4a096000U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_SATA_SIZE                                   (0x68U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_SATA_REGS                                   (0x4a096400U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_SATA_SIZE                                   (0x38U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_SATA_REGS                                     (0x4a096800U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_SATA_SIZE                                     (0x400U)
#define CSL_MPU_TA_OCP2SCP3_TARG_REGS                                           (0x4a098000U)
#define CSL_MPU_TA_OCP2SCP3_TARG_SIZE                                           (0x1000U)
#define CSL_MPU_OCP2SCP2_REGS                                                   (0x4a0a0000U)
#define CSL_MPU_OCP2SCP2_SIZE                                                   (0x1cU)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO1_REGS                                   (0x4a0a4000U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO1_SIZE                                   (0x400U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO2_REGS                                   (0x4a0a5000U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO2_SIZE                                   (0x400U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_HDMI_REGS                                     (0x4a0a6000U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_HDMI_SIZE                                     (0x400U)
#define CSL_MPU_TA_OCP2SCP2_TARG_REGS                                           (0x4a0a8000U)
#define CSL_MPU_TA_OCP2SCP2_TARG_SIZE                                           (0x1000U)
#define CSL_MPU_SMARTREFLEX_MPU_REGS                                            (0x4a0d9000U)
#define CSL_MPU_SMARTREFLEX_MPU_SIZE                                            (0x50U)
#define CSL_MPU_TA_SMARTREFLEX_MPU_TARG_REGS                                    (0x4a0da000U)
#define CSL_MPU_TA_SMARTREFLEX_MPU_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SMARTREFLEX_CORE_REGS                                           (0x4a0dd000U)
#define CSL_MPU_SMARTREFLEX_CORE_SIZE                                           (0x50U)
#define CSL_MPU_TA_SMARTREFLEX_CORE_TARG_REGS                                   (0x4a0de000U)
#define CSL_MPU_TA_SMARTREFLEX_CORE_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_EFUSE_CTRL_CUST_REGS                                            (0x4a0e0000U)
#define CSL_MPU_EFUSE_CTRL_CUST_SIZE                                            (0x400U)
#define CSL_MPU_TA_EFUSE_CTRL_CUST_TARG_REGS                                    (0x4a0e1000U)
#define CSL_MPU_TA_EFUSE_CTRL_CUST_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_MAILBOX1_REGS                                                   (0x4a0f4000U)
#define CSL_MPU_MAILBOX1_SIZE                                                   (0x14U)
#define CSL_MPU_TA_MAILBOX1_TARG_REGS                                           (0x4a0f5000U)
#define CSL_MPU_TA_MAILBOX1_TARG_SIZE                                           (0x1000U)
#define CSL_MPU_SPINLOCK_REGS                                                   (0x4a0f6000U)
#define CSL_MPU_SPINLOCK_SIZE                                                   (0x880U)
#define CSL_MPU_TA_SPINLOCK_TARG_REGS                                           (0x4a0f7000U)
#define CSL_MPU_TA_SPINLOCK_TARG_SIZE                                           (0x1000U)
#define CSL_MPU_OCP_WP_NOC_REGS                                                 (0x4a102000U)
#define CSL_MPU_OCP_WP_NOC_SIZE                                                 (0x6cU)
#define CSL_MPU_TA_OCP_WP_NOC_TARG_REGS                                         (0x4a103000U)
#define CSL_MPU_TA_OCP_WP_NOC_TARG_SIZE                                         (0x1000U)
#define CSL_MPU_IEEE1500_2_OCP_REGS                                             (0x4a108000U)
#define CSL_MPU_IEEE1500_2_OCP_SIZE                                             (0x1000U)
#define CSL_MPU_TA_IEEE1500_2_OCP_TARG_REGS                                     (0x4a109000U)
#define CSL_MPU_TA_IEEE1500_2_OCP_TARG_SIZE                                     (0x1000U)
#define CSL_MPU_DWC_AHSATA_REGS                                                 (0x4a140000U)
#define CSL_MPU_DWC_AHSATA_SIZE                                                 (0x100U)
#define CSL_MPU_SATAMAC_WRAPPER_REGS                                            (0x4a141100U)
#define CSL_MPU_SATAMAC_WRAPPER_SIZE                                            (0x8U)
#define CSL_MPU_TA_SATA_TARG_REGS                                               (0x4a150000U)
#define CSL_MPU_TA_SATA_TARG_SIZE                                               (0x1000U)
#define CSL_MPU_SECURITYCORE_EVE1_REGS                                          (0x4a151000U)
#define CSL_MPU_SECURITYCORE_EVE1_SIZE                                          (0x90U)
#define CSL_MPU_TA_EVE1_FW_CFG_TARG_REGS                                        (0x4a152000U)
#define CSL_MPU_TA_EVE1_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_EVE2_REGS                                          (0x4a153000U)
#define CSL_MPU_SECURITYCORE_EVE2_SIZE                                          (0x90U)
#define CSL_MPU_TA_EVE2_FW_CFG_TARG_REGS                                        (0x4a154000U)
#define CSL_MPU_TA_EVE2_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_EVE3_REGS                                          (0x4a155000U)
#define CSL_MPU_SECURITYCORE_EVE3_SIZE                                          (0x90U)
#define CSL_MPU_TA_EVE3_FW_CFG_TARG_REGS                                        (0x4a156000U)
#define CSL_MPU_TA_EVE3_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_EVE4_REGS                                          (0x4a157000U)
#define CSL_MPU_SECURITYCORE_EVE4_SIZE                                          (0x90U)
#define CSL_MPU_TA_EVE4_FW_CFG_TARG_REGS                                        (0x4a158000U)
#define CSL_MPU_TA_EVE4_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_PCIE2_REGS                                         (0x4a159000U)
#define CSL_MPU_SECURITYCORE_PCIE2_SIZE                                         (0x100U)
#define CSL_MPU_TA_PCIE_SS2_FW_CFG_TARG_REGS                                    (0x4a15a000U)
#define CSL_MPU_TA_PCIE_SS2_FW_CFG_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SECURITYCORE_IPU1_REGS                                          (0x4a15b000U)
#define CSL_MPU_SECURITYCORE_IPU1_SIZE                                          (0xc0U)
#define CSL_MPU_TA_IPU1_FW_CFG_TARG_REGS                                        (0x4a15c000U)
#define CSL_MPU_TA_IPU1_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_VCP1_REGS                                          (0x4a15d000U)
#define CSL_MPU_SECURITYCORE_VCP1_SIZE                                          (0x90U)
#define CSL_MPU_TA_VCP1_FW_CFG_TARG_REGS                                        (0x4a15e000U)
#define CSL_MPU_TA_VCP1_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_VCP2_REGS                                          (0x4a15f000U)
#define CSL_MPU_SECURITYCORE_VCP2_SIZE                                          (0x90U)
#define CSL_MPU_TA_VCP2_FW_CFG_TARG_REGS                                        (0x4a160000U)
#define CSL_MPU_TA_VCP2_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_TPCC_REGS                                          (0x4a161000U)
#define CSL_MPU_SECURITYCORE_TPCC_SIZE                                          (0x90U)
#define CSL_MPU_TA_EDMA_TPCC_FW_CFG_TARG_REGS                                   (0x4a162000U)
#define CSL_MPU_TA_EDMA_TPCC_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_TPTC_REGS                                          (0x4a163000U)
#define CSL_MPU_SECURITYCORE_TPTC_SIZE                                          (0xa0U)
#define CSL_MPU_TA_EDMA_TC0_FW_CFG_TARG_REGS                                    (0x4a164000U)
#define CSL_MPU_TA_EDMA_TC0_FW_CFG_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SECURITYCORE_PCIE1_REGS                                         (0x4a165000U)
#define CSL_MPU_SECURITYCORE_PCIE1_SIZE                                         (0x100U)
#define CSL_MPU_TA_PCIE_SS1_FW_CFG_TARG_REGS                                    (0x4a166000U)
#define CSL_MPU_TA_PCIE_SS1_FW_CFG_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SECURITYCORE_MCASP1_REGS                                        (0x4a167000U)
#define CSL_MPU_SECURITYCORE_MCASP1_SIZE                                        (0x90U)
#define CSL_MPU_TA_MCASP1_FW_CFG_TARG_REGS                                      (0x4a168000U)
#define CSL_MPU_TA_MCASP1_FW_CFG_TARG_SIZE                                      (0x1000U)
#define CSL_MPU_SECURITYCORE_MCASP2_REGS                                        (0x4a169000U)
#define CSL_MPU_SECURITYCORE_MCASP2_SIZE                                        (0x90U)
#define CSL_MPU_TA_MCASP2_FW_CFG_TARG_REGS                                      (0x4a16a000U)
#define CSL_MPU_TA_MCASP2_FW_CFG_TARG_SIZE                                      (0x1000U)
#define CSL_MPU_SECURITYCORE_MCASP3_REGS                                        (0x4a16b000U)
#define CSL_MPU_SECURITYCORE_MCASP3_SIZE                                        (0x90U)
#define CSL_MPU_TA_MCASP3_FW_CFG_TARG_REGS                                      (0x4a16c000U)
#define CSL_MPU_TA_MCASP3_FW_CFG_TARG_SIZE                                      (0x1000U)
#define CSL_MPU_SECURITYCORE_TSC_ADC_REGS                                       (0x4a16d000U)
#define CSL_MPU_SECURITYCORE_TSC_ADC_SIZE                                       (0x90U)
#define CSL_MPU_TA_SPARE_TSC_ADC_FW_CFG_TARG_REGS                               (0x4a16e000U)
#define CSL_MPU_TA_SPARE_TSC_ADC_FW_CFG_TARG_SIZE                               (0x1000U)
#define CSL_MPU_SECURITYCORE_DSP1_SDMA_REGS                                     (0x4a171000U)
#define CSL_MPU_SECURITYCORE_DSP1_SDMA_SIZE                                     (0x90U)
#define CSL_MPU_TA_DSP1_FW_CFG_TARG_REGS                                        (0x4a172000U)
#define CSL_MPU_TA_DSP1_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_DSP2_SDMA_REGS                                     (0x4a173000U)
#define CSL_MPU_SECURITYCORE_DSP2_SDMA_SIZE                                     (0x90U)
#define CSL_MPU_TA_DSP2_FW_CFG_TARG_REGS                                        (0x4a174000U)
#define CSL_MPU_TA_DSP2_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_PRUSS1_REGS                                        (0x4a175000U)
#define CSL_MPU_SECURITYCORE_PRUSS1_SIZE                                        (0x90U)
#define CSL_MPU_TA_PRUSS1_FW_CFG_TARG_REGS                                      (0x4a176000U)
#define CSL_MPU_TA_PRUSS1_FW_CFG_TARG_SIZE                                      (0x1000U)
#define CSL_MPU_SECURITYCORE_PRUSS2_REGS                                        (0x4a177000U)
#define CSL_MPU_SECURITYCORE_PRUSS2_SIZE                                        (0x90U)
#define CSL_MPU_TA_PRUSS2_FW_CFG_TARG_REGS                                      (0x4a178000U)
#define CSL_MPU_TA_PRUSS2_FW_CFG_TARG_SIZE                                      (0x1000U)
#define CSL_MPU_SECURITYCORE_QSPI_REGS                                          (0x4a179000U)
#define CSL_MPU_SECURITYCORE_QSPI_SIZE                                          (0x90U)
#define CSL_MPU_TA_QSPI_FW_CFG_TARG_REGS                                        (0x4a17a000U)
#define CSL_MPU_TA_QSPI_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SPARE_SMARTREFLEX_RTC_REGS                                      (0x4a17b000U)
#define CSL_MPU_SPARE_SMARTREFLEX_RTC_SIZE                                      (0x1000U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_RTC_TARG_REGS                              (0x4a17c000U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_RTC_TARG_SIZE                              (0x1000U)
#define CSL_MPU_SPARE_SMARTREFLEX_WKUP_REGS                                     (0x4a17d000U)
#define CSL_MPU_SPARE_SMARTREFLEX_WKUP_SIZE                                     (0x1000U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_WKUP_TARG_REGS                             (0x4a17e000U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_WKUP_TARG_SIZE                             (0x1000U)
#define CSL_MPU_SPARE_SMARTREFLEX_SDRAM_REGS                                    (0x4a181000U)
#define CSL_MPU_SPARE_SMARTREFLEX_SDRAM_SIZE                                    (0x1000U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_SDRAM_TARG_REGS                            (0x4a182000U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_SDRAM_TARG_SIZE                            (0x1000U)
#define CSL_MPU_SMARTREFLEX_DSPEVE_REGS                                         (0x4a183000U)
#define CSL_MPU_SMARTREFLEX_DSPEVE_SIZE                                         (0x50U)
#define CSL_MPU_TA_SMARTREFLEX_DSPEVE_TARG_REGS                                 (0x4a184000U)
#define CSL_MPU_TA_SMARTREFLEX_DSPEVE_TARG_SIZE                                 (0x1000U)
#define CSL_MPU_SMARTREFLEX_GPU_REGS                                            (0x4a185000U)
#define CSL_MPU_SMARTREFLEX_GPU_SIZE                                            (0x50U)
#define CSL_MPU_TA_SMARTREFLEX_GPU_TARG_REGS                                    (0x4a186000U)
#define CSL_MPU_TA_SMARTREFLEX_GPU_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SMARTREFLEX_IVA_REGS                                            (0x4a187000U)
#define CSL_MPU_SMARTREFLEX_IVA_SIZE                                            (0x50U)
#define CSL_MPU_TA_SMARTREFLEX_IVA_TARG_REGS                                    (0x4a188000U)
#define CSL_MPU_TA_SMARTREFLEX_IVA_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SECURITYCORE_OCMC_ROM_REGS                                      (0x4a200000U)
#define CSL_MPU_SECURITYCORE_OCMC_ROM_SIZE                                      (0xc0U)
#define CSL_MPU_TA_OCMC_ROM_FW_CFG_TARG_REGS                                    (0x4a201000U)
#define CSL_MPU_TA_OCMC_ROM_FW_CFG_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_MA_MPU_NTTP_FW_CFG_REGS                                         (0x4a20a000U)
#define CSL_MPU_MA_MPU_NTTP_FW_CFG_SIZE                                         (0x1000U)
#define CSL_MPU_TA_MA_MPU_NTTP_FW_CFG_TARG_REGS                                 (0x4a20b000U)
#define CSL_MPU_TA_MA_MPU_NTTP_FW_CFG_TARG_SIZE                                 (0x1000U)
#define CSL_MPU_SECURITYCORE_OCP_FW_EMIF_5430_REGS                              (0x4a20c000U)
#define CSL_MPU_SECURITYCORE_OCP_FW_EMIF_5430_SIZE                              (0x100U)
#define CSL_MPU_TA_EMIF_OCP_FW_CFG_TARG_REGS                                    (0x4a20d000U)
#define CSL_MPU_TA_EMIF_OCP_FW_CFG_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM2_REGS                                     (0x4a20e000U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM2_SIZE                                     (0x180U)
#define CSL_MPU_TA_OCMC_RAM2_FW_CFG_TARG_REGS                                   (0x4a20f000U)
#define CSL_MPU_TA_OCMC_RAM2_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_GPMC_REGS                                          (0x4a210000U)
#define CSL_MPU_SECURITYCORE_GPMC_SIZE                                          (0x100U)
#define CSL_MPU_TA_GPMC_FW_CFG_TARG_REGS                                        (0x4a211000U)
#define CSL_MPU_TA_GPMC_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM1_REGS                                     (0x4a212000U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM1_SIZE                                     (0x180U)
#define CSL_MPU_TA_OCMC_RAM1_FW_CFG_TARG_REGS                                   (0x4a213000U)
#define CSL_MPU_TA_OCMC_RAM1_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_GPU_REGS                                           (0x4a214000U)
#define CSL_MPU_SECURITYCORE_GPU_SIZE                                           (0x90U)
#define CSL_MPU_TA_GPU_FW_CFG_TARG_REGS                                         (0x4a215000U)
#define CSL_MPU_TA_GPU_FW_CFG_TARG_SIZE                                         (0x1000U)
#define CSL_MPU_SECURITYCORE_IPU2_REGS                                          (0x4a218000U)
#define CSL_MPU_SECURITYCORE_IPU2_SIZE                                          (0xc0U)
#define CSL_MPU_TA_IPU2_FW_CFG_TARG_REGS                                        (0x4a219000U)
#define CSL_MPU_TA_IPU2_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_GRPX2D_REGS                                        (0x4a21a000U)
#define CSL_MPU_SECURITYCORE_GRPX2D_SIZE                                        (0x90U)
#define CSL_MPU_TA_BB2D_FW_CFG_TARG_REGS                                        (0x4a21b000U)
#define CSL_MPU_TA_BB2D_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_DSS_REGS                                           (0x4a21c000U)
#define CSL_MPU_SECURITYCORE_DSS_SIZE                                           (0x100U)
#define CSL_MPU_TA_DSS_FW_CFG_TARG_REGS                                         (0x4a21d000U)
#define CSL_MPU_TA_DSS_FW_CFG_TARG_SIZE                                         (0x1000U)
#define CSL_MPU_SECURITYCORE_IVA1_SL2IF_REGS                                    (0x4a21e000U)
#define CSL_MPU_SECURITYCORE_IVA1_SL2IF_SIZE                                    (0xc0U)
#define CSL_MPU_TA_IVA_SL2IF_FW_CFG_TARG_REGS                                   (0x4a21f000U)
#define CSL_MPU_TA_IVA_SL2IF_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_IVA1_CONFIG_REGS                                   (0x4a220000U)
#define CSL_MPU_SECURITYCORE_IVA1_CONFIG_SIZE                                   (0x90U)
#define CSL_MPU_TA_IVA_CONFIG_FW_CFG_TARG_REGS                                  (0x4a221000U)
#define CSL_MPU_TA_IVA_CONFIG_FW_CFG_TARG_SIZE                                  (0x1000U)
#define CSL_MPU_SECURITYCORE_DEBUGSS_CT_TBR_REGS                                (0x4a224000U)
#define CSL_MPU_SECURITYCORE_DEBUGSS_CT_TBR_SIZE                                (0xa0U)
#define CSL_MPU_TA_DEBUGSS_CT_TBR_FW_CFG_TARG_REGS                              (0x4a225000U)
#define CSL_MPU_TA_DEBUGSS_CT_TBR_FW_CFG_TARG_SIZE                              (0x1000U)
#define CSL_MPU_SECURITYCORE_L3_INSTR_REGS                                      (0x4a226000U)
#define CSL_MPU_SECURITYCORE_L3_INSTR_SIZE                                      (0x90U)
#define CSL_MPU_TA_L3_INSTR_FW_CFG_TARG_REGS                                    (0x4a227000U)
#define CSL_MPU_TA_L3_INSTR_FW_CFG_TARG_SIZE                                    (0x1000U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM3_REGS                                     (0x4a22a000U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM3_SIZE                                     (0x180U)
#define CSL_MPU_TA_OCMC_RAM3_FW_CFG_TARG_REGS                                   (0x4a22b000U)
#define CSL_MPU_TA_OCMC_RAM3_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_AES1_REGS                                          (0x4a22c000U)
#define CSL_MPU_SECURITYCORE_AES1_SIZE                                          (0xa0U)
#define CSL_MPU_TA_AES1_FW_CFG_TARG_REGS                                        (0x4a22d000U)
#define CSL_MPU_TA_AES1_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_AES2_REGS                                          (0x4a22e000U)
#define CSL_MPU_SECURITYCORE_AES2_SIZE                                          (0xa0U)
#define CSL_MPU_TA_AES2_FW_CFG_TARG_REGS                                        (0x4a22f000U)
#define CSL_MPU_TA_AES2_FW_CFG_TARG_SIZE                                        (0x1000U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P1_REGS                                    (0x4a230000U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P1_SIZE                                    (0xa0U)
#define CSL_MPU_TA_SHA2MD5_1_FW_CFG_TARG_REGS                                   (0x4a231000U)
#define CSL_MPU_TA_SHA2MD5_1_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P2_REGS                                    (0x4a232000U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P2_SIZE                                    (0xa0U)
#define CSL_MPU_TA_SHA2MD5_2_FW_CFG_TARG_REGS                                   (0x4a233000U)
#define CSL_MPU_TA_SHA2MD5_2_FW_CFG_TARG_SIZE                                   (0x1000U)
#define CSL_MPU_SECURITYCORE_IVA2_SL2IF_REGS                                    (0x4a234000U)
#define CSL_MPU_SECURITYCORE_IVA2_SL2IF_SIZE                                    (0xc0U)
#define CSL_MPU_TA_SPARE_IVA2_SL2IF_FW_CFG_TARG_REGS                            (0x4a235000U)
#define CSL_MPU_TA_SPARE_IVA2_SL2IF_FW_CFG_TARG_SIZE                            (0x1000U)
#define CSL_MPU_SECURITYCORE_IVA2_CONFIG_REGS                                   (0x4a236000U)
#define CSL_MPU_SECURITYCORE_IVA2_CONFIG_SIZE                                   (0x90U)
#define CSL_MPU_TA_SPARE_IVA2_CONFIG_FW_CFG_TARG_REGS                           (0x4a237000U)
#define CSL_MPU_TA_SPARE_IVA2_CONFIG_FW_CFG_TARG_SIZE                           (0x1000U)
#define CSL_MPU_COUNTER_32K_REGS                                                (0x4ae04000U)
#define CSL_MPU_COUNTER_32K_SIZE                                                (0x34U)
#define CSL_MPU_OCP_SOCKET_PRM_REGS                                             (0x4ae06000U)
#define CSL_MPU_OCP_SOCKET_PRM_SIZE                                             (0xf8U)
#define CSL_MPU_CKGEN_PRM_REGS                                                  (0x4ae06100U)
#define CSL_MPU_CKGEN_PRM_SIZE                                                  (0xe4U)
#define CSL_MPU_MPU_PRM_REGS                                                    (0x4ae06300U)
#define CSL_MPU_MPU_PRM_SIZE                                                    (0x28U)
#define CSL_MPU_DSP1_PRM_REGS                                                   (0x4ae06400U)
#define CSL_MPU_DSP1_PRM_SIZE                                                   (0x28U)
#define CSL_MPU_IPU_PRM_REGS                                                    (0x4ae06500U)
#define CSL_MPU_IPU_PRM_SIZE                                                    (0x88U)
#define CSL_MPU_COREAON_PRM_REGS                                                (0x4ae06600U)
#define CSL_MPU_COREAON_PRM_SIZE                                                (0xb8U)
#define CSL_MPU_CORE_PRM_REGS                                                   (0x4ae06700U)
#define CSL_MPU_CORE_PRM_SIZE                                                   (0x748U)
#define CSL_MPU_IVA_PRM_REGS                                                    (0x4ae06f00U)
#define CSL_MPU_IVA_PRM_SIZE                                                    (0x30U)
#define CSL_MPU_CAM_PRM_REGS                                                    (0x4ae07000U)
#define CSL_MPU_CAM_PRM_SIZE                                                    (0x50U)
#define CSL_MPU_DSS_PRM_REGS                                                    (0x4ae07100U)
#define CSL_MPU_DSS_PRM_SIZE                                                    (0x40U)
#define CSL_MPU_GPU_PRM_REGS                                                    (0x4ae07200U)
#define CSL_MPU_GPU_PRM_SIZE                                                    (0x28U)
#define CSL_MPU_L3INIT_PRM_REGS                                                 (0x4ae07300U)
#define CSL_MPU_L3INIT_PRM_SIZE                                                 (0xf8U)
#define CSL_MPU_L4PER_PRM_REGS                                                  (0x4ae07400U)
#define CSL_MPU_L4PER_PRM_SIZE                                                  (0x200U)
#define CSL_MPU_CUSTEFUSE_PRM_REGS                                              (0x4ae07600U)
#define CSL_MPU_CUSTEFUSE_PRM_SIZE                                              (0x28U)
#define CSL_MPU_WKUPAON_PRM_REGS                                                (0x4ae07700U)
#define CSL_MPU_WKUPAON_PRM_SIZE                                                (0xbcU)
#define CSL_MPU_WKUPAON_CM_REGS                                                 (0x4ae07800U)
#define CSL_MPU_WKUPAON_CM_SIZE                                                 (0xdcU)
#define CSL_MPU_EMU_PRM_REGS                                                    (0x4ae07900U)
#define CSL_MPU_EMU_PRM_SIZE                                                    (0x28U)
#define CSL_MPU_EMU_CM_REGS                                                     (0x4ae07a00U)
#define CSL_MPU_EMU_CM_SIZE                                                     (0x10U)
#define CSL_MPU_DSP2_PRM_REGS                                                   (0x4ae07b00U)
#define CSL_MPU_DSP2_PRM_SIZE                                                   (0x28U)
#define CSL_MPU_EVE1_PRM_REGS                                                   (0x4ae07b40U)
#define CSL_MPU_EVE1_PRM_SIZE                                                   (0x28U)
#define CSL_MPU_EVE2_PRM_REGS                                                   (0x4ae07b80U)
#define CSL_MPU_EVE2_PRM_SIZE                                                   (0x28U)
#define CSL_MPU_EVE3_PRM_REGS                                                   (0x4ae07bc0U)
#define CSL_MPU_EVE3_PRM_SIZE                                                   (0x28U)
#define CSL_MPU_EVE4_PRM_REGS                                                   (0x4ae07c00U)
#define CSL_MPU_EVE4_PRM_SIZE                                                   (0x28U)
#define CSL_MPU_RTC_PRM_REGS                                                    (0x4ae07c60U)
#define CSL_MPU_RTC_PRM_SIZE                                                    (0x8U)
#define CSL_MPU_VPE_PRM_REGS                                                    (0x4ae07c80U)
#define CSL_MPU_VPE_PRM_SIZE                                                    (0x28U)
#define CSL_MPU_DEVICE_PRM_REGS                                                 (0x4ae07d00U)
#define CSL_MPU_DEVICE_PRM_SIZE                                                 (0x138U)
#define CSL_MPU_INSTR_PRM_REGS                                                  (0x4ae07f00U)
#define CSL_MPU_INSTR_PRM_SIZE                                                  (0x34U)
#define CSL_MPU_CTRL_MODULE_WKUP_REGS                                           (0x4ae0c000U)
#define CSL_MPU_CTRL_MODULE_WKUP_SIZE                                           (0x80U)
#define CSL_MPU_CTRL_MODULE_WKUP_CORE_REGISTERS_REGS                            (0x4ae0c100U)
#define CSL_MPU_CTRL_MODULE_WKUP_CORE_REGISTERS_SIZE                            (0x680U)
#define CSL_MPU_CTRL_MODULE_WKUP_CORE_PAD_REGISTERS_REGS                        (0x4ae0c5a8U)
#define CSL_MPU_CTRL_MODULE_WKUP_CORE_PAD_REGISTERS_SIZE                        (0x54U)
#define CSL_MPU_GPIO1_REGS                                                      (0x4ae10000U)
#define CSL_MPU_GPIO1_SIZE                                                      (0x198U)
#define CSL_MPU_WD_TIMER2_REGS                                                  (0x4ae14000U)
#define CSL_MPU_WD_TIMER2_SIZE                                                  (0x68U)
#define CSL_MPU_TIMER1_REGS                                                     (0x4ae18000U)
#define CSL_MPU_TIMER1_SIZE                                                     (0x70U)
#define CSL_MPU_KBD_REGS                                                        (0x4ae1c000U)
#define CSL_MPU_KBD_SIZE                                                        (0x70U)
#define CSL_MPU_TIMER12_REGS                                                    (0x4ae20000U)
#define CSL_MPU_TIMER12_SIZE                                                    (0x5cU)
#define CSL_MPU_WD_TIMER1_REGS                                                  (0x4ae22000U)
#define CSL_MPU_WD_TIMER1_SIZE                                                  (0x68U)
#define CSL_MPU_SAR_RAM_SPACE1_REGS                                             (0x4ae26000U)
#define CSL_MPU_SAR_RAM_SPACE1_SIZE                                             (0x1000U)
#define CSL_MPU_SAR_RAM_SPACE2_REGS                                             (0x4ae27000U)
#define CSL_MPU_SAR_RAM_SPACE2_SIZE                                             (0x1000U)
#define CSL_MPU_SAR_RAM_SPACE3_REGS                                             (0x4ae28000U)
#define CSL_MPU_SAR_RAM_SPACE3_SIZE                                             (0x1000U)
#define CSL_MPU_SAR_RAM_SPACE4_REGS                                             (0x4ae29000U)
#define CSL_MPU_SAR_RAM_SPACE4_SIZE                                             (0x1000U)
#define CSL_MPU_UART10_REGS                                                     (0x4ae2b000U)
#define CSL_MPU_UART10_SIZE                                                     (0x88U)
#define CSL_MPU_SPARE_SAFETY1_REGS                                              (0x4ae2f000U)
#define CSL_MPU_SPARE_SAFETY1_SIZE                                              (0x2000U)
#define CSL_MPU_SPARE_SAFETY2_REGS                                              (0x4ae31000U)
#define CSL_MPU_SPARE_SAFETY2_SIZE                                              (0x2000U)
#define CSL_MPU_SPARE_SAFETY3_REGS                                              (0x4ae33000U)
#define CSL_MPU_SPARE_SAFETY3_SIZE                                              (0x2000U)
#define CSL_MPU_SPARE_SAFETY4_REGS                                              (0x4ae35000U)
#define CSL_MPU_SPARE_SAFETY4_SIZE                                              (0x2000U)
#define CSL_MPU_SPARE_UNKNOWN2_REGS                                             (0x4ae37000U)
#define CSL_MPU_SPARE_UNKNOWN2_SIZE                                             (0x2000U)
#define CSL_MPU_SPARE_UNKNOWN3_REGS                                             (0x4ae39000U)
#define CSL_MPU_SPARE_UNKNOWN3_SIZE                                             (0x2000U)
#define CSL_MPU_DCAN1_REGS                                                      (0x4ae3c000U)
#define CSL_MPU_DCAN1_SIZE                                                      (0x220U)
#define CSL_MPU_SHA2MD5_1_ADDRSP0_REGS                                          (0x4b000000U)
#define CSL_MPU_SHA2MD5_1_ADDRSP0_SIZE                                          (0x10028cU)
#define CSL_MPU_SHA2MD5_1_ADDRSP1_REGS                                          (0x4b100000U)
#define CSL_MPU_SHA2MD5_1_ADDRSP1_SIZE                                          (0x100000U)
#define CSL_MPU_PRUSS1_U_DATA_RAM0_8KB_REGS                                     (0x4b200000U)
#define CSL_MPU_PRUSS1_U_DATA_RAM0_8KB_SIZE                                     (0x2000U)
#define CSL_MPU_PRUSS1_U_DATA_RAM1_8KB_REGS                                     (0x4b202000U)
#define CSL_MPU_PRUSS1_U_DATA_RAM1_8KB_SIZE                                     (0x2000U)
#define CSL_MPU_PRUSS1_U_DATA_RAM_32KB_REGS                                     (0x4b210000U)
#define CSL_MPU_PRUSS1_U_DATA_RAM_32KB_SIZE                                     (0x8000U)
#define CSL_MPU_PRUSS1_U_INTC_REGS                                              (0x4b220000U)
#define CSL_MPU_PRUSS1_U_INTC_SIZE                                              (0x1504U)
#define CSL_MPU_PRUSS1_U_PRU0_CTRL_REGS                                         (0x4b222000U)
#define CSL_MPU_PRUSS1_U_PRU0_CTRL_SIZE                                         (0x30U)
#define CSL_MPU_PRUSS1_U_PRU0_DEBUG_REGS                                        (0x4b222400U)
#define CSL_MPU_PRUSS1_U_PRU0_DEBUG_SIZE                                        (0x100U)
#define CSL_MPU_PRUSS1_U_PRU1_CTRL_REGS                                         (0x4b224000U)
#define CSL_MPU_PRUSS1_U_PRU1_CTRL_SIZE                                         (0x30U)
#define CSL_MPU_PRUSS1_U_PRU1_DEBUG_REGS                                        (0x4b224400U)
#define CSL_MPU_PRUSS1_U_PRU1_DEBUG_SIZE                                        (0x100U)
#define CSL_MPU_PRUSS1_U_CFG_REGS                                               (0x4b226000U)
#define CSL_MPU_PRUSS1_U_CFG_SIZE                                               (0x44U)
#define CSL_MPU_PRUSS1_U_UART_REGS                                              (0x4b228000U)
#define CSL_MPU_PRUSS1_U_UART_SIZE                                              (0x38U)
#define CSL_MPU_PRUSS1_U_IEP_REGS                                               (0x4b22e000U)
#define CSL_MPU_PRUSS1_U_IEP_SIZE                                               (0x31cU)
#define CSL_MPU_PRUSS1_U_ECAP_REGS                                              (0x4b230000U)
#define CSL_MPU_PRUSS1_U_ECAP_SIZE                                              (0x60U)
#define CSL_MPU_PRUSS1_U_MII_RT_CFG_REGS                                        (0x4b232000U)
#define CSL_MPU_PRUSS1_U_MII_RT_CFG_SIZE                                        (0x58U)
#define CSL_MPU_PRUSS1_U_MII_MDIO_REGS                                          (0x4b232400U)
#define CSL_MPU_PRUSS1_U_MII_MDIO_SIZE                                          (0x90U)
#define CSL_MPU_PRUSS1_U_INST_RAM0_12KB_REGS                                    (0x4b234000U)
#define CSL_MPU_PRUSS1_U_INST_RAM0_12KB_SIZE                                    (0x3000U)
#define CSL_MPU_PRUSS1_U_INST_RAM1_12KB_REGS                                    (0x4b238000U)
#define CSL_MPU_PRUSS1_U_INST_RAM1_12KB_SIZE                                    (0x3000U)
#define CSL_MPU_PRUSS2_U_DATA_RAM0_8KB_REGS                                     (0x4b280000U)
#define CSL_MPU_PRUSS2_U_DATA_RAM0_8KB_SIZE                                     (0x2000U)
#define CSL_MPU_PRUSS2_U_DATA_RAM1_8KB_REGS                                     (0x4b282000U)
#define CSL_MPU_PRUSS2_U_DATA_RAM1_8KB_SIZE                                     (0x2000U)
#define CSL_MPU_PRUSS2_U_DATA_RAM_32KB_REGS                                     (0x4b290000U)
#define CSL_MPU_PRUSS2_U_DATA_RAM_32KB_SIZE                                     (0x8000U)
#define CSL_MPU_PRUSS2_U_INTC_REGS                                              (0x4b2a0000U)
#define CSL_MPU_PRUSS2_U_INTC_SIZE                                              (0x1504U)
#define CSL_MPU_PRUSS2_U_PRU0_CTRL_REGS                                         (0x4b2a2000U)
#define CSL_MPU_PRUSS2_U_PRU0_CTRL_SIZE                                         (0x30U)
#define CSL_MPU_PRUSS2_U_PRU0_DEBUG_REGS                                        (0x4b2a2400U)
#define CSL_MPU_PRUSS2_U_PRU0_DEBUG_SIZE                                        (0x100U)
#define CSL_MPU_PRUSS2_U_PRU1_CTRL_REGS                                         (0x4b2a4000U)
#define CSL_MPU_PRUSS2_U_PRU1_CTRL_SIZE                                         (0x30U)
#define CSL_MPU_PRUSS2_U_PRU1_DEBUG_REGS                                        (0x4b2a4400U)
#define CSL_MPU_PRUSS2_U_PRU1_DEBUG_SIZE                                        (0x100U)
#define CSL_MPU_PRUSS2_U_CFG_REGS                                               (0x4b2a6000U)
#define CSL_MPU_PRUSS2_U_CFG_SIZE                                               (0x44U)
#define CSL_MPU_PRUSS2_U_UART_REGS                                              (0x4b2a8000U)
#define CSL_MPU_PRUSS2_U_UART_SIZE                                              (0x38U)
#define CSL_MPU_PRUSS2_U_IEP_REGS                                               (0x4b2ae000U)
#define CSL_MPU_PRUSS2_U_IEP_SIZE                                               (0x31cU)
#define CSL_MPU_PRUSS2_U_ECAP_REGS                                              (0x4b2b0000U)
#define CSL_MPU_PRUSS2_U_ECAP_SIZE                                              (0x60U)
#define CSL_MPU_PRUSS2_U_MII_RT_CFG_REGS                                        (0x4b2b2000U)
#define CSL_MPU_PRUSS2_U_MII_RT_CFG_SIZE                                        (0x58U)
#define CSL_MPU_PRUSS2_U_MII_MDIO_REGS                                          (0x4b2b2400U)
#define CSL_MPU_PRUSS2_U_MII_MDIO_SIZE                                          (0x90U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS2_U_INST_RAM0_12KB_REGS                                    (0x4b2b4000U)
#define CSL_MPU_PRUSS2_U_INST_RAM0_12KB_SIZE                                    (0x3000U)
#define CSL_MPU_PRUSS2_U_INST_RAM1_12KB_REGS                                    (0x4b2b8000U)
#define CSL_MPU_PRUSS2_U_INST_RAM1_12KB_SIZE                                    (0x3000U)
/* End of CSL Modification */
#define CSL_MPU_QSPI_ADDRSP0_REGS                                               (0x4b300000U)
#define CSL_MPU_QSPI_ADDRSP0_SIZE                                               (0x80U)
#define CSL_MPU_AES1_ADDRSP0_REGS                                               (0x4b400000U)
#define CSL_MPU_AES1_ADDRSP0_SIZE                                               (0x100094U)
#define CSL_MPU_AES1_ADDRSP1_REGS                                               (0x4b500000U)
#define CSL_MPU_AES1_ADDRSP1_SIZE                                               (0x100000U)
#define CSL_MPU_AES2_ADDRSP0_REGS                                               (0x4b600000U)
#define CSL_MPU_AES2_ADDRSP0_SIZE                                               (0x100094U)
#define CSL_MPU_AES2_ADDRSP1_REGS                                               (0x4b700000U)
#define CSL_MPU_AES2_ADDRSP1_SIZE                                               (0x100000U)
#define CSL_MPU_EMIF1_CONF_REGS_REGS                                            (0x4c000000U)
#define CSL_MPU_EMIF1_CONF_REGS_SIZE                                            (0x320U)
#define CSL_MPU_EMIF2_CONF_REGS_REGS                                            (0x4d000000U)
#define CSL_MPU_EMIF2_CONF_REGS_SIZE                                            (0x320U)
#define CSL_MPU_DMM_CONF_REGS_REGS                                              (0x4e000000U)
#define CSL_MPU_DMM_CONF_REGS_SIZE                                              (0x4d0U)
#define CSL_MPU_GPMC_CONF_REGS_REGS                                             (0x50000000U)
#define CSL_MPU_GPMC_CONF_REGS_SIZE                                             (0x234U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_RC_CFG_DBICS_REGS                          (0x51000000U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_RC_CFG_DBICS_SIZE                          (0x40U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_PL_CONF_REGS                               (0x51000700U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_PL_CONF_SIZE                               (0x120U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_RC_CFG_DBICS2_REGS                         (0x51001000U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_RC_CFG_DBICS2_SIZE                         (0x40U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_TI_CONF_REGS                               (0x51002000U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_TI_CONF_SIZE                               (0x14cU)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_RC_CFG_DBICS_REGS                          (0x51800000U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_RC_CFG_DBICS_SIZE                          (0x40U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_PL_CONF_REGS                               (0x51800700U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_PL_CONF_SIZE                               (0x120U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_RC_CFG_DBICS2_REGS                         (0x51801000U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_RC_CFG_DBICS2_SIZE                         (0x40U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_TI_CONF_REGS                               (0x51802000U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_TI_CONF_SIZE                               (0x14cU)
#define CSL_MPU_I_CSCTI_MPU_C0_REGS                                             (0x54148000U)
#define CSL_MPU_I_CSCTI_MPU_C0_SIZE                                             (0x1000U)
#define CSL_MPU_I_CSCTI_MPU_C1_REGS                                             (0x54149000U)
#define CSL_MPU_I_CSCTI_MPU_C1_SIZE                                             (0x1000U)
#define CSL_MPU_I_CSTF_REGS                                                     (0x54158000U)
#define CSL_MPU_I_CSTF_SIZE                                                     (0x1000U)
#define CSL_MPU_I_DAP_PC_REGS                                                   (0x54159000U)
#define CSL_MPU_I_DAP_PC_SIZE                                                   (0x10U)
#define CSL_MPU_I_CSSTM_REGS                                                    (0x5415ac04U)
#define CSL_MPU_I_CSSTM_SIZE                                                    (0x3fcU)
#define CSL_MPU_I_SGU_REGS                                                      (0x5415b000U)
#define CSL_MPU_I_SGU_SIZE                                                      (0x20U)
#define CSL_MPU_I_CSCTI_REGS                                                    (0x5415c000U)
#define CSL_MPU_I_CSCTI_SIZE                                                    (0x1000U)
#define CSL_MPU_I_DRM_REGS                                                      (0x54160000U)
#define CSL_MPU_I_DRM_SIZE                                                      (0x104U)
#define CSL_MPU_I_MIPI_STM_REGS                                                 (0x54161000U)
#define CSL_MPU_I_MIPI_STM_SIZE                                                 (0x1000U)
#define CSL_MPU_I_CSTPIU_REGS                                                   (0x54163000U)
#define CSL_MPU_I_CSTPIU_SIZE                                                   (0x1000U)
#define CSL_MPU_I_CSTF1_REGS                                                    (0x54164000U)
#define CSL_MPU_I_CSTF1_SIZE                                                    (0x1000U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_CT_TBR_REGS                           (0x54167004U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_CT_TBR_SIZE                           (0xffcU)
#define CSL_MPU_CT_UART_REGS                                                    (0x54168000U)
#define CSL_MPU_CT_UART_SIZE                                                    (0x34U)
#define CSL_MPU_CSCTI_REGS                                                      (0x54169000U)
#define CSL_MPU_CSCTI_SIZE                                                      (0x1000U)
#define CSL_MPU_OCP2SCP_REGS                                                    (0x54171000U)
#define CSL_MPU_OCP2SCP_SIZE                                                    (0x1cU)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_PLLCTRL_REGS                          (0x54171800U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_PLLCTRL_SIZE                          (0x24U)
#define CSL_MPU_CT_TBR_REGS                                                     (0x54800000U)
#define CSL_MPU_CT_TBR_SIZE                                                     (0x800000U)
#define CSL_MPU_IPU2_TARGET_REGS                                                (0x55000000U)
#define CSL_MPU_IPU2_TARGET_SIZE                                                (0x80U)
#define CSL_MPU_IPU2_TARGET_UNICACHE_MMU_REGS                                   (0x55080800U)
#define CSL_MPU_IPU2_TARGET_UNICACHE_MMU_SIZE                                   (0x4bcU)
#define CSL_MPU_IPU2_TARGET_L2_MMU_REGS                                         (0x55082000U)
#define CSL_MPU_IPU2_TARGET_L2_MMU_SIZE                                         (0x8cU)
#define CSL_MPU_KLIO_REGS                                                       (0x56000000U)
#define CSL_MPU_KLIO_SIZE                                                       (0x1010U)
#define CSL_MPU_HYDRA2_REGS                                                     (0x56004000U)
#define CSL_MPU_HYDRA2_SIZE                                                     (0xf44U)
#define CSL_MPU_KLIO_0_REGS                                                     (0x56008000U)
#define CSL_MPU_KLIO_0_SIZE                                                     (0x1010U)
#define CSL_MPU_KLIO_1_REGS                                                     (0x5600c000U)
#define CSL_MPU_KLIO_1_SIZE                                                     (0x1010U)
#define CSL_MPU_KLIO_HL_REGS                                                    (0x5600fe00U)
#define CSL_MPU_KLIO_HL_SIZE                                                    (0x200U)
#define CSL_MPU_DSS_FAMILY_REGS                                                 (0x58000000U)
#define CSL_MPU_DSS_FAMILY_SIZE                                                 (0x60U)
#define CSL_MPU_DISPC_REGS                                                      (0x58001000U)
#define CSL_MPU_DISPC_SIZE                                                      (0x1a0U)
#define CSL_MPU_RFBI_REGS                                                       (0x58002000U)
#define CSL_MPU_RFBI_SIZE                                                       (0x60U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE1_REGS                                       (0x58004000U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE1_SIZE                                       (0xa0U)
#define CSL_MPU_DSI_PHY1_REGS                                                   (0x58004200U)
#define CSL_MPU_DSI_PHY1_SIZE                                                   (0x40U)
#define CSL_MPU_PLLCTRL1_REGS                                                   (0x58004300U)
#define CSL_MPU_PLLCTRL1_SIZE                                                   (0x24U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE2_REGS                                       (0x58005000U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE2_SIZE                                       (0xa0U)
#define CSL_MPU_DSI_PHY2_REGS                                                   (0x58005200U)
#define CSL_MPU_DSI_PHY2_SIZE                                                   (0x40U)
#define CSL_MPU_PLLCTRL2_REGS                                                   (0x58005300U)
#define CSL_MPU_PLLCTRL2_SIZE                                                   (0x24U)
#define CSL_MPU_DESHDCP_REGS                                                    (0x58007000U)
#define CSL_MPU_DESHDCP_SIZE                                                    (0x180U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE3_REGS                                       (0x58009000U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE3_SIZE                                       (0xa0U)
#define CSL_MPU_DSI_PHY3_REGS                                                   (0x58009200U)
#define CSL_MPU_DSI_PHY3_SIZE                                                   (0x40U)
#define CSL_MPU_PLLCTRL3_REGS                                                   (0x58009300U)
#define CSL_MPU_PLLCTRL3_SIZE                                                   (0x24U)
#define CSL_MPU_HDMI_WP_REGS                                                    (0x58040000U)
#define CSL_MPU_HDMI_WP_SIZE                                                    (0x98U)
#define CSL_MPU_HDMI_PLLCTRL_REGS                                               (0x58040200U)
#define CSL_MPU_HDMI_PLLCTRL_SIZE                                               (0x24U)
#define CSL_MPU_HDMI_PHY_REGS                                                   (0x58040300U)
#define CSL_MPU_HDMI_PHY_SIZE                                                   (0x40U)
#define CSL_MPU_HDMI_DWC_TX_REGS                                                (0x58060000U)
#define CSL_MPU_HDMI_DWC_TX_SIZE                                                (0xa64U)
#define CSL_MPU_IPU1_TARGET_REGS                                                (0x58800000U)
#define CSL_MPU_IPU1_TARGET_SIZE                                                (0x80U)
#define CSL_MPU_IPU1_TARGET_UNICACHE_MMU_REGS                                   (0x58880800U)
#define CSL_MPU_IPU1_TARGET_UNICACHE_MMU_SIZE                                   (0x4bcU)
#define CSL_MPU_IPU1_TARGET_L2_MMU_REGS                                         (0x58882000U)
#define CSL_MPU_IPU1_TARGET_L2_MMU_SIZE                                         (0x8cU)
#define CSL_MPU_BB2DIP_GC320_REGS                                               (0x59000000U)
#define CSL_MPU_BB2DIP_GC320_SIZE                                               (0x670U)
#define CSL_MPU_IVA_CONFIG_REGS                                                 (0x5a000000U)
#define CSL_MPU_IVA_CONFIG_SIZE                                                 (0x80U)
#define CSL_MPU_ICONT1_DMEM_REGS                                                (0x5a000000U)
#define CSL_MPU_ICONT1_DMEM_SIZE                                                (0x4000U)
#define CSL_MPU_ICONT1_IMEM_REGS                                                (0x5a008000U)
#define CSL_MPU_ICONT1_IMEM_SIZE                                                (0x8000U)
#define CSL_MPU_ICONT2_DMEM_REGS                                                (0x5a010000U)
#define CSL_MPU_ICONT2_DMEM_SIZE                                                (0x4000U)
#define CSL_MPU_ICONT2_IMEM_REGS                                                (0x5a018000U)
#define CSL_MPU_ICONT2_IMEM_SIZE                                                (0x8000U)
#define CSL_MPU_ECD3_MEM_REGS                                                   (0x5a020000U)
#define CSL_MPU_ECD3_MEM_SIZE                                                   (0x7000U)
#define CSL_MPU_CALC3_MEM_REGS                                                  (0x5a028000U)
#define CSL_MPU_CALC3_MEM_SIZE                                                  (0x4000U)
#define CSL_MPU_MC3_MEM_REGS                                                    (0x5a030000U)
#define CSL_MPU_MC3_MEM_SIZE                                                    (0x5800U)
#define CSL_MPU_IPE3_MEM_REGS                                                   (0x5a038000U)
#define CSL_MPU_IPE3_MEM_SIZE                                                   (0x1000U)
#define CSL_MPU_ICECRUSHER1_CFG_IC968_REGS                                      (0x5a040000U)
#define CSL_MPU_ICECRUSHER1_CFG_IC968_SIZE                                      (0x100U)
#define CSL_MPU_CONF_REGS                                                       (0x5a041000U)
#define CSL_MPU_CONF_SIZE                                                       (0x50U)
#define CSL_MPU_VDMA_CFG_REGS                                                   (0x5a050000U)
#define CSL_MPU_VDMA_CFG_SIZE                                                   (0xa00U)
#define CSL_MPU_ILF3_CFG_REGS                                                   (0x5a052000U)
#define CSL_MPU_ILF3_CFG_SIZE                                                   (0x1000U)
#define CSL_MPU_IME3_CFG_REGS                                                   (0x5a054000U)
#define CSL_MPU_IME3_CFG_SIZE                                                   (0x3b98U)
#define CSL_MPU_CALC3_CFG_MMR_REGS                                              (0x5a058000U)
#define CSL_MPU_CALC3_CFG_MMR_SIZE                                              (0x28U)
#define CSL_MPU_CALC3_CFG_BFSW_REGS                                             (0x5a058200U)
#define CSL_MPU_CALC3_CFG_BFSW_SIZE                                             (0x8U)
#define CSL_MPU_CALC3_CFG_LSE_REGS                                              (0x5a058300U)
#define CSL_MPU_CALC3_CFG_LSE_SIZE                                              (0x8U)
#define CSL_MPU_CALC3_CFG_IPGW_REGS                                             (0x5a058408U)
#define CSL_MPU_CALC3_CFG_IPGW_SIZE                                             (0xbcU)
#define CSL_MPU_IPE3_CFG_MMR_REGS                                               (0x5a058800U)
#define CSL_MPU_IPE3_CFG_MMR_SIZE                                               (0x54U)
#define CSL_MPU_IPE3_CFG_BFSW_REGS                                              (0x5a058a00U)
#define CSL_MPU_IPE3_CFG_BFSW_SIZE                                              (0x8U)
#define CSL_MPU_IPE3_CFG_LSE_REGS                                               (0x5a058b00U)
#define CSL_MPU_IPE3_CFG_LSE_SIZE                                               (0x8U)
#define CSL_MPU_IPE3_CFG_IPGW_REGS                                              (0x5a058c08U)
#define CSL_MPU_IPE3_CFG_IPGW_SIZE                                              (0xbcU)
#define CSL_MPU_MC3_CFG_MMR_REGS                                                (0x5a059000U)
#define CSL_MPU_MC3_CFG_MMR_SIZE                                                (0x28U)
#define CSL_MPU_MC3_CFG_BFSW_REGS                                               (0x5a059200U)
#define CSL_MPU_MC3_CFG_BFSW_SIZE                                               (0xcU)
#define CSL_MPU_MC3_CFG_LSE_REGS                                                (0x5a059300U)
#define CSL_MPU_MC3_CFG_LSE_SIZE                                                (0x8U)
#define CSL_MPU_MC3_CFG_IPGW_REGS                                               (0x5a059408U)
#define CSL_MPU_MC3_CFG_IPGW_SIZE                                               (0xbcU)
#define CSL_MPU_ECD3_CFG_MMR_REGS                                               (0x5a059800U)
#define CSL_MPU_ECD3_CFG_MMR_SIZE                                               (0xfcU)
#define CSL_MPU_ECD3_CFG_BFSW_REGS                                              (0x5a059a00U)
#define CSL_MPU_ECD3_CFG_BFSW_SIZE                                              (0xcU)
#define CSL_MPU_ECD3_CFG_LSE_REGS                                               (0x5a059b00U)
#define CSL_MPU_ECD3_CFG_LSE_SIZE                                               (0x8U)
#define CSL_MPU_ECD3_CFG_IPGW_REGS                                              (0x5a059c08U)
#define CSL_MPU_ECD3_CFG_IPGW_SIZE                                              (0xbcU)
#define CSL_MPU_SYSCTRL_REGS                                                    (0x5a05a400U)
#define CSL_MPU_SYSCTRL_SIZE                                                    (0x5cU)
#define CSL_MPU_MAILBOX_REGS                                                    (0x5a05a800U)
#define CSL_MPU_MAILBOX_SIZE                                                    (0x80U)
#define CSL_MPU_ICONT1_SB_SYNCBOX_REGS                                          (0x5a060000U)
#define CSL_MPU_ICONT1_SB_SYNCBOX_SIZE                                          (0x98U)
#define CSL_MPU_ICONT1_MMR_CFG_REGS                                             (0x5a070000U)
#define CSL_MPU_ICONT1_MMR_CFG_SIZE                                             (0x14U)
#define CSL_MPU_ICONT1_MMR_IRQ_REGS                                             (0x5a070420U)
#define CSL_MPU_ICONT1_MMR_IRQ_SIZE                                             (0x74U)
#define CSL_MPU_ICONT1_MMR_DM_REGS                                              (0x5a070820U)
#define CSL_MPU_ICONT1_MMR_DM_SIZE                                              (0x20U)
#define CSL_MPU_ICONT1_MMR_SBH_REGS                                             (0x5a070c00U)
#define CSL_MPU_ICONT1_MMR_SBH_SIZE                                             (0x44U)
#define CSL_MPU_ICONT2_MMR_CFG_REGS                                             (0x5a071000U)
#define CSL_MPU_ICONT2_MMR_CFG_SIZE                                             (0x14U)
#define CSL_MPU_ICONT2_MMR_IRQ_REGS                                             (0x5a071420U)
#define CSL_MPU_ICONT2_MMR_IRQ_SIZE                                             (0x74U)
#define CSL_MPU_ICONT2_MMR_DM_REGS                                              (0x5a071820U)
#define CSL_MPU_ICONT2_MMR_DM_SIZE                                              (0x20U)
#define CSL_MPU_ICONT2_MMR_SBH_REGS                                             (0x5a071c00U)
#define CSL_MPU_ICONT2_MMR_SBH_SIZE                                             (0x44U)
#define CSL_MPU_SPARE_IVA2_CONFIG_REGS                                          (0x5a400000U)
#define CSL_MPU_SPARE_IVA2_CONFIG_SIZE                                          (0x2000U)
#define CSL_MPU_IVA_SL2IF_REGS                                                  (0x5b000000U)
#define CSL_MPU_IVA_SL2IF_SIZE                                                  (0x80U)
#define CSL_MPU_SL2_MEM_REGS                                                    (0x5b000000U)
#define CSL_MPU_SL2_MEM_SIZE                                                    (0x40000U)
#define CSL_MPU_SPARE_IVA2_SL2IF_REGS                                           (0x5b400000U)
#define CSL_MPU_SPARE_IVA2_SL2IF_SIZE                                           (0x400000U)
#define CSL_MPU_QSPI_ADDRSP1_REGS                                               (0x5c000000U)
#define CSL_MPU_QSPI_ADDRSP1_SIZE                                               (0x4000000U)
#define CSL_MPU_TILER_REGS                                                      (0x60000000U)
#define CSL_MPU_TILER_SIZE                                                      (0x20000000U)
#define CSL_MPU_EMIF1_SDRAM_CS0_REGS                                            (0x80000000U)
#define CSL_MPU_EMIF1_SDRAM_CS0_SIZE                                            (0x40000000U)
#define CSL_MPU_EMIF2_SDRAM_CS0_REGS                                            (0x80000000U)
#define CSL_MPU_EMIF2_SDRAM_CS0_SIZE                                            (0x40000000U)
#define CSL_MPU_EMIF2_SDRAM_CS1_REGS                                            (0xc0000000U)
#define CSL_MPU_EMIF2_SDRAM_CS1_SIZE                                            (0x40000000U)
#define CSL_MPU_EMIF1_SDRAM_CS1_REGS                                            (0xc0000000U)
#define CSL_MPU_EMIF1_SDRAM_CS1_SIZE                                            (0x40000000U)

/* Auto-Generated Instance ID List */
#define CSL_MPU_GPMC                                                            (0U)
#define CSL_MPU_PCIE_SS1                                                        (0U)
#define CSL_MPU_PCIE_SS2                                                        (0U)
#define CSL_MPU_MPU_ROM_BOOT_SEC                                                (0U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_REST                                           (0U)
#define CSL_MPU_MPU_ROM_BOOT_PUBLIC                                             (0U)
#define CSL_MPU_MPU_RAM                                                         (0U)
#define CSL_MPU_OCMC_RAM1                                                       (0U)
#define CSL_MPU_OCMC_RAM2                                                       (1U)
#define CSL_MPU_OCMC_RAM3                                                       (2U)
#define CSL_MPU_DSP1_L2_SRAM                                                    (0U)
#define CSL_MPU_DSP1_SYSTEM                                                     (0U)
#define CSL_MPU_DSP1_MMU0CFG                                                    (0U)
#define CSL_MPU_DSP1_MMU1CFG                                                    (1U)
#define CSL_MPU_DSP1_FW0CFG                                                     (0U)
#define CSL_MPU_DSP1_FW1CFG                                                     (0U)
#define CSL_MPU_DSP1_EDMA_TC0                                                   (0U)
#define CSL_MPU_DSP1_EDMA_TC1                                                   (1U)
#define CSL_MPU_DSP1_NOC                                                        (0U)
#define CSL_MPU_DSP1_DFT                                                        (0U)
#define CSL_MPU_DSP1_EDMA_CC                                                    (0U)
#define CSL_MPU_DSP1_L1P_SRAM                                                   (0U)
#define CSL_MPU_DSP1_L1D_SRAM                                                   (0U)
#define CSL_MPU_DSP2_L2_SRAM                                                    (1U)
#define CSL_MPU_DSP2_SYSTEM                                                     (1U)
#define CSL_MPU_DSP2_MMU0CFG                                                    (2U)
#define CSL_MPU_DSP2_MMU1CFG                                                    (3U)
#define CSL_MPU_DSP2_FW0CFG                                                     (1U)
#define CSL_MPU_DSP2_FW1CFG                                                     (1U)
#define CSL_MPU_DSP2_EDMA_TC0                                                   (2U)
#define CSL_MPU_DSP2_EDMA_TC1                                                   (3U)
#define CSL_MPU_DSP2_NOC                                                        (1U)
#define CSL_MPU_DSP2_DFT                                                        (1U)
#define CSL_MPU_DSP2_EDMA_CC                                                    (1U)
#define CSL_MPU_DSP2_L1P_SRAM                                                   (1U)
#define CSL_MPU_DSP2_L1D_SRAM                                                   (1U)
#define CSL_MPU_OCMC_RAM1_CBUF                                                  (0U)
#define CSL_MPU_EVE1_DMEM                                                       (0U)
#define CSL_MPU_EVE1_WBUF                                                       (1U)
#define CSL_MPU_EVE1_IBUFLA                                                     (0U)
#define CSL_MPU_EVE1_IBUFHA                                                     (1U)
#define CSL_MPU_EVE1_IBUFLB                                                     (2U)
#define CSL_MPU_EVE1_IBUFHB                                                     (3U)
#define CSL_MPU_EVE1_EVE_CONTROL                                                (0U)
#define CSL_MPU_EVE1_MMU0                                                       (0U)
#define CSL_MPU_EVE1_MMU1                                                       (1U)
#define CSL_MPU_EVE1_T16                                                        (0U)
#define CSL_MPU_EVE1_VCOP                                                       (0U)
#define CSL_MPU_EVE1_CTM                                                        (0U)
#define CSL_MPU_EVE1_TPTC0                                                      (0U)
#define CSL_MPU_EVE1_TPTC1                                                      (1U)
#define CSL_MPU_EVE1_SMSET_CONF                                                 (0U)
#define CSL_MPU_EVE1_SMSET_SW                                                   (0U)
#define CSL_MPU_EVE1_L2_FNOC_EVE                                                (0U)
#define CSL_MPU_EVE1_MLB0                                                       (0U)
#define CSL_MPU_EVE1_MLB1                                                       (1U)
#define CSL_MPU_EVE1_MLB2                                                       (2U)
#define CSL_MPU_EVE1_MLB3                                                       (3U)
#define CSL_MPU_EVE1_MLB4                                                       (4U)
#define CSL_MPU_EVE1_PCACHE_RAW                                                 (0U)
#define CSL_MPU_EVE1_PCACHE_TAGS                                                (0U)
#define CSL_MPU_EVE1_TPCC0                                                      (0U)
#define CSL_MPU_EVE2_DMEM                                                       (0U)
#define CSL_MPU_EVE2_WBUF                                                       (1U)
#define CSL_MPU_EVE2_IBUFLA                                                     (0U)
#define CSL_MPU_EVE2_IBUFHA                                                     (1U)
#define CSL_MPU_EVE2_IBUFLB                                                     (2U)
#define CSL_MPU_EVE2_IBUFHB                                                     (3U)
#define CSL_MPU_EVE2_EVE_CONTROL                                                (0U)
#define CSL_MPU_EVE2_MMU0                                                       (0U)
#define CSL_MPU_EVE2_MMU1                                                       (1U)
#define CSL_MPU_EVE2_T16                                                        (0U)
#define CSL_MPU_EVE2_VCOP                                                       (0U)
#define CSL_MPU_EVE2_CTM                                                        (0U)
#define CSL_MPU_EVE2_TPTC0                                                      (0U)
#define CSL_MPU_EVE2_TPTC1                                                      (1U)
#define CSL_MPU_EVE2_SMSET_CONF                                                 (0U)
#define CSL_MPU_EVE2_SMSET_SW                                                   (0U)
#define CSL_MPU_EVE2_L2_FNOC_EVE                                                (0U)
#define CSL_MPU_EVE2_MLB0                                                       (0U)
#define CSL_MPU_EVE2_MLB1                                                       (1U)
#define CSL_MPU_EVE2_MLB2                                                       (2U)
#define CSL_MPU_EVE2_MLB3                                                       (3U)
#define CSL_MPU_EVE2_MLB4                                                       (4U)
#define CSL_MPU_EVE2_PCACHE_RAW                                                 (0U)
#define CSL_MPU_EVE2_PCACHE_TAGS                                                (0U)
#define CSL_MPU_EVE2_TPCC0                                                      (0U)
#define CSL_MPU_EVE3_DMEM                                                       (0U)
#define CSL_MPU_EVE3_WBUF                                                       (1U)
#define CSL_MPU_EVE3_IBUFLA                                                     (0U)
#define CSL_MPU_EVE3_IBUFHA                                                     (1U)
#define CSL_MPU_EVE3_IBUFLB                                                     (2U)
#define CSL_MPU_EVE3_IBUFHB                                                     (3U)
#define CSL_MPU_EVE3_EVE_CONTROL                                                (0U)
#define CSL_MPU_EVE3_MMU0                                                       (0U)
#define CSL_MPU_EVE3_MMU1                                                       (1U)
#define CSL_MPU_EVE3_T16                                                        (0U)
#define CSL_MPU_EVE3_VCOP                                                       (0U)
#define CSL_MPU_EVE3_CTM                                                        (0U)
#define CSL_MPU_EVE3_TPTC0                                                      (0U)
#define CSL_MPU_EVE3_TPTC1                                                      (1U)
#define CSL_MPU_EVE3_SMSET_CONF                                                 (0U)
#define CSL_MPU_EVE3_SMSET_SW                                                   (0U)
#define CSL_MPU_EVE3_L2_FNOC_EVE                                                (0U)
#define CSL_MPU_EVE3_MLB0                                                       (0U)
#define CSL_MPU_EVE3_MLB1                                                       (1U)
#define CSL_MPU_EVE3_MLB2                                                       (2U)
#define CSL_MPU_EVE3_MLB3                                                       (3U)
#define CSL_MPU_EVE3_MLB4                                                       (4U)
#define CSL_MPU_EVE3_PCACHE_RAW                                                 (0U)
#define CSL_MPU_EVE3_PCACHE_TAGS                                                (0U)
#define CSL_MPU_EVE3_TPCC0                                                      (0U)
#define CSL_MPU_EVE4_DMEM                                                       (0U)
#define CSL_MPU_EVE4_WBUF                                                       (1U)
#define CSL_MPU_EVE4_IBUFLA                                                     (0U)
#define CSL_MPU_EVE4_IBUFHA                                                     (1U)
#define CSL_MPU_EVE4_IBUFLB                                                     (2U)
#define CSL_MPU_EVE4_IBUFHB                                                     (3U)
#define CSL_MPU_EVE4_EVE_CONTROL                                                (0U)
#define CSL_MPU_EVE4_MMU0                                                       (0U)
#define CSL_MPU_EVE4_MMU1                                                       (1U)
#define CSL_MPU_EVE4_T16                                                        (0U)
#define CSL_MPU_EVE4_VCOP                                                       (0U)
#define CSL_MPU_EVE4_CTM                                                        (0U)
#define CSL_MPU_EVE4_TPTC0                                                      (0U)
#define CSL_MPU_EVE4_TPTC1                                                      (1U)
#define CSL_MPU_EVE4_SMSET_CONF                                                 (0U)
#define CSL_MPU_EVE4_SMSET_SW                                                   (0U)
#define CSL_MPU_EVE4_L2_FNOC_EVE                                                (0U)
#define CSL_MPU_EVE4_MLB0                                                       (0U)
#define CSL_MPU_EVE4_MLB1                                                       (1U)
#define CSL_MPU_EVE4_MLB2                                                       (2U)
#define CSL_MPU_EVE4_MLB3                                                       (3U)
#define CSL_MPU_EVE4_MLB4                                                       (4U)
#define CSL_MPU_EVE4_PCACHE_RAW                                                 (0U)
#define CSL_MPU_EVE4_PCACHE_TAGS                                                (0U)
#define CSL_MPU_EVE4_TPCC0                                                      (0U)
#define CSL_MPU_SHA2MD5_2_ADDRSP0                                               (0U)
#define CSL_MPU_SHA2MD5_2_ADDRSP1                                               (0U)
#define CSL_MPU_SPARE_TSC_ADC                                                   (0U)
#define CSL_MPU_EDMA_TPCC                                                       (0U)
#define CSL_MPU_EDMA_TC0                                                        (0U)
#define CSL_MPU_EDMA_TC1                                                        (1U)
#define CSL_MPU_OCMC_ROM                                                        (0U)
#define CSL_MPU_L3_MAIN                                                         (0U)
#define CSL_MPU_MCASP1                                                          (0U)
#define CSL_MPU_MCASP2                                                          (1U)
#define CSL_MPU_MCASP3                                                          (2U)
#define CSL_MPU_VCP1                                                            (0U)
#define CSL_MPU_VCP2                                                            (1U)
#define CSL_MPU_MPU_CS_STM                                                      (0U)
#define CSL_MPU_UART3                                                           (0U)
#define CSL_MPU_TIMER2                                                          (0U)
#define CSL_MPU_TIMER3                                                          (0U)
#define CSL_MPU_TIMER4                                                          (1U)
#define CSL_MPU_TIMER9                                                          (2U)
#define CSL_MPU_GPIO7                                                           (0U)
#define CSL_MPU_GPIO8                                                           (1U)
#define CSL_MPU_GPIO2                                                           (2U)
#define CSL_MPU_GPIO3                                                           (3U)
#define CSL_MPU_GPIO4                                                           (4U)
#define CSL_MPU_GPIO5                                                           (5U)
#define CSL_MPU_GPIO6                                                           (6U)
#define CSL_MPU_I2C3                                                            (0U)
#define CSL_MPU_UART5                                                           (1U)
#define CSL_MPU_UART6                                                           (2U)
#define CSL_MPU_UART1                                                           (3U)
#define CSL_MPU_UART2                                                           (4U)
#define CSL_MPU_UART4                                                           (5U)
#define CSL_MPU_I2C1                                                            (1U)
#define CSL_MPU_I2C2                                                            (2U)
#define CSL_MPU_ELM                                                             (0U)
#define CSL_MPU_I2C4                                                            (3U)
#define CSL_MPU_I2C5                                                            (4U)
#define CSL_MPU_TIMER10                                                         (1U)
#define CSL_MPU_TIMER11                                                         (3U)
#define CSL_MPU_RNG                                                             (0U)
#define CSL_MPU_MCSPI1                                                          (0U)
#define CSL_MPU_MCSPI2                                                          (1U)
#define CSL_MPU_MMC1                                                            (0U)
#define CSL_MPU_DMA_CRYPTO                                                      (0U)
#define CSL_MPU_DES3DES_ADDRSP0                                                 (0U)
#define CSL_MPU_DES3DES_ADDRSP1                                                 (0U)
#define CSL_MPU_FPKA                                                            (0U)
#define CSL_MPU_MMC3                                                            (1U)
#define CSL_MPU_HDQ1W                                                           (0U)
#define CSL_MPU_MMC2                                                            (2U)
#define CSL_MPU_MCSPI3                                                          (2U)
#define CSL_MPU_MCSPI4                                                          (3U)
#define CSL_MPU_MMC4                                                            (3U)
#define CSL_MPU_INTC_MPU_DISTRIBUTOR                                            (0U)
#define CSL_MPU_INTC_MPU_PHYS_CPU_IF                                            (0U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_HYP                                        (0U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_VM                                         (0U)
#define CSL_MPU_MPU_PRCM                                                        (0U)
#define CSL_MPU_PRCM_MPU_OCP_SOCKET                                             (0U)
#define CSL_MPU_PRCM_MPU_DEVICE                                                 (0U)
#define CSL_MPU_PRCM_MPU_PRM_C0                                                 (0U)
#define CSL_MPU_PRCM_MPU_CM_C0                                                  (0U)
#define CSL_MPU_PRCM_MPU_PRM_C1                                                 (0U)
#define CSL_MPU_PRCM_MPU_CM_C1                                                  (0U)
#define CSL_MPU_MPU_SCM                                                         (0U)
#define CSL_MPU_MPU_WUGEN                                                       (0U)
#define CSL_MPU_MPU_CMU                                                         (0U)
#define CSL_MPU_WATCHDOGTIMER                                                   (0U)
#define CSL_MPU_AXI2OCP_RPT                                                     (0U)
#define CSL_MPU_AXI2OCP_MISC                                                    (0U)
#define CSL_MPU_MA_MPU_LSM                                                      (0U)
#define CSL_MPU_MA_MPU_WP                                                       (0U)
#define CSL_MPU_UART7                                                           (6U)
#define CSL_MPU_UART8                                                           (7U)
#define CSL_MPU_UART9                                                           (8U)
#define CSL_MPU_MLB                                                             (0U)
#define CSL_MPU_MCASP4_DAT                                                      (3U)
#define CSL_MPU_MCASP5_DAT                                                      (4U)
#define CSL_MPU_ATL                                                             (0U)
#define CSL_MPU_PWMSS1_IPWMSS                                                   (0U)
#define CSL_MPU_PWMSS1_IECAP                                                    (0U)
#define CSL_MPU_PWMSS1_IEQEP                                                    (0U)
#define CSL_MPU_PWMSS1_IEPWM                                                    (0U)
#define CSL_MPU_PWMSS2_IPWMSS                                                   (0U)
#define CSL_MPU_PWMSS2_IECAP                                                    (0U)
#define CSL_MPU_PWMSS2_IEQEP                                                    (0U)
#define CSL_MPU_PWMSS2_IEPWM                                                    (0U)
#define CSL_MPU_PWMSS3_IPWMSS                                                   (0U)
#define CSL_MPU_PWMSS3_IECAP                                                    (0U)
#define CSL_MPU_PWMSS3_IEQEP                                                    (0U)
#define CSL_MPU_PWMSS3_IEPWM                                                    (0U)
#define CSL_MPU_VCP1_CFG                                                        (2U)
#define CSL_MPU_VCP2_CFG                                                        (3U)
#define CSL_MPU_DELAYLINE                                                       (0U)
#define CSL_MPU_MCASP6_DAT                                                      (5U)
#define CSL_MPU_MCASP7_DAT                                                      (6U)
#define CSL_MPU_MCASP8_DAT                                                      (7U)
#define CSL_MPU_SPARE_UNKNOWN4                                                  (0U)
#define CSL_MPU_SPARE_UNKNOWN5                                                  (1U)
#define CSL_MPU_SPARE_UNKNOWN6                                                  (2U)
#define CSL_MPU_MCASP1_CFG                                                      (8U)
#define CSL_MPU_MCASP2_CFG                                                      (9U)
#define CSL_MPU_MCASP3_CFG                                                      (10U)
#define CSL_MPU_MCASP4_CFG                                                      (11U)
#define CSL_MPU_MCASP5_CFG                                                      (12U)
#define CSL_MPU_MCASP6_CFG                                                      (13U)
#define CSL_MPU_MCASP7_CFG                                                      (14U)
#define CSL_MPU_MCASP8_CFG                                                      (15U)
#define CSL_MPU_DCAN2                                                           (0U)
#define CSL_MPU_ISS                                                             (0U)
#define CSL_MPU_IPORT                                                           (0U)
#define CSL_MPU_ICPDMA                                                          (0U)
#define CSL_MPU_ISTATERAM                                                       (0U)
#define CSL_MPU_ICPTS                                                           (0U)
#define CSL_MPU_IALE                                                            (0U)
#define CSL_MPU_ISL1                                                            (0U)
#define CSL_MPU_ISL2                                                            (1U)
#define CSL_MPU_IMDIO                                                           (0U)
#define CSL_MPU_IWR                                                             (0U)
#define CSL_MPU_MAILBOX13                                                       (0U)
#define CSL_MPU_OCMC_RAM1_CFG                                                   (0U)
#define CSL_MPU_OCMC_RAM2_CFG                                                   (0U)
#define CSL_MPU_OCMC_RAM3_CFG                                                   (0U)
#define CSL_MPU_SPARE_SATA2                                                     (0U)
#define CSL_MPU_L4_PER3_MMU1                                                    (0U)
#define CSL_MPU_MMU2                                                            (0U)
#define CSL_MPU_TIMER5                                                          (4U)
#define CSL_MPU_TIMER6                                                          (5U)
#define CSL_MPU_TIMER7                                                          (6U)
#define CSL_MPU_TIMER8                                                          (7U)
#define CSL_MPU_TIMER13                                                         (8U)
#define CSL_MPU_TIMER14                                                         (9U)
#define CSL_MPU_TIMER15                                                         (10U)
#define CSL_MPU_TIMER16                                                         (11U)
#define CSL_MPU_RTC_SS                                                          (0U)
#define CSL_MPU_MAILBOX2                                                        (1U)
#define CSL_MPU_MAILBOX3                                                        (2U)
#define CSL_MPU_MAILBOX4                                                        (3U)
#define CSL_MPU_MAILBOX5                                                        (4U)
#define CSL_MPU_MAILBOX6                                                        (5U)
#define CSL_MPU_MAILBOX7                                                        (6U)
#define CSL_MPU_MAILBOX8                                                        (7U)
#define CSL_MPU_SPARE_ICM                                                       (3U)
#define CSL_MPU_SPARE_HDMI_RX                                                   (4U)
#define CSL_MPU_SPARE_LVDS_TX1                                                  (5U)
#define CSL_MPU_CSI2_2                                                          (6U)
#define CSL_MPU_SPARE_VENC                                                      (7U)
#define CSL_MPU_LVDS_RX                                                         (8U)
#define CSL_MPU_CSI2_1                                                          (9U)
#define CSL_MPU_SPARE_VIDEOPLL1                                                 (10U)
#define CSL_MPU_SPARE_VIDEOPLL2                                                 (11U)
#define CSL_MPU_SPARE_VIDEOPLL3                                                 (12U)
#define CSL_MPU_SPARE_CME                                                       (13U)
#define CSL_MPU_MAILBOX9                                                        (8U)
#define CSL_MPU_MAILBOX10                                                       (9U)
#define CSL_MPU_MAILBOX11                                                       (10U)
#define CSL_MPU_MAILBOX12                                                       (11U)
#define CSL_MPU_USB1_CFG_USBOTGSS_WRAPPER                                       (0U)
#define CSL_MPU_USB1_CFG_DWC_USB3                                               (0U)
#define CSL_MPU_USB2_CFG_USBOTGSS_WRAPPER                                       (0U)
#define CSL_MPU_USB2_CFG_DWC_USB3                                               (0U)
#define CSL_MPU_USB3_CFG_USBOTGSS_WRAPPER                                       (0U)
#define CSL_MPU_USB3_CFG_DWC_USB3                                               (0U)
#define CSL_MPU_USB4_CFG_USBOTGSS_WRAPPER                                       (0U)
#define CSL_MPU_USB4_CFG_DWC_USB3                                               (0U)
#define CSL_MPU_VIP1_VIP_REGS                                                   (0U)
#define CSL_MPU_VIP1_VIP_PARSER_SLICE0_REGS                                     (0U)
#define CSL_MPU_VIP1_VIP_CSC_SLICE0_REGS                                        (0U)
#define CSL_MPU_VIP1_VIP_SC_SLICE0_REGS                                         (0U)
#define CSL_MPU_VIP1_VIP_PARSER_SLICE1_REGS                                     (1U)
#define CSL_MPU_VIP1_VIP_CSC_SLICE1_REGS                                        (1U)
#define CSL_MPU_VIP1_VIP_SC_SLICE1_REGS                                         (1U)
#define CSL_MPU_VIP1_VIP_VPDMA_REGS                                             (0U)
#define CSL_MPU_VIP2_VIP_REGS                                                   (0U)
#define CSL_MPU_VIP2_VIP_PARSER_SLICE0_REGS                                     (0U)
#define CSL_MPU_VIP2_VIP_CSC_SLICE0_REGS                                        (0U)
#define CSL_MPU_VIP2_VIP_SC_SLICE0_REGS                                         (0U)
#define CSL_MPU_VIP2_VIP_PARSER_SLICE1_REGS                                     (1U)
#define CSL_MPU_VIP2_VIP_CSC_SLICE1_REGS                                        (1U)
#define CSL_MPU_VIP2_VIP_SC_SLICE1_REGS                                         (1U)
#define CSL_MPU_VIP2_VIP_VPDMA_REGS                                             (0U)
#define CSL_MPU_VIP3_VIP_REGS                                                   (0U)
#define CSL_MPU_VIP3_VIP_PARSER_SLICE0_REGS                                     (0U)
#define CSL_MPU_VIP3_VIP_CSC_SLICE0_REGS                                        (0U)
#define CSL_MPU_VIP3_VIP_SC_SLICE0_REGS                                         (0U)
#define CSL_MPU_VIP3_VIP_PARSER_SLICE1_REGS                                     (1U)
#define CSL_MPU_VIP3_VIP_CSC_SLICE1_REGS                                        (1U)
#define CSL_MPU_VIP3_VIP_SC_SLICE1_REGS                                         (1U)
#define CSL_MPU_VIP3_VIP_VPDMA_REGS                                             (0U)
#define CSL_MPU_VPE_REGS                                                        (0U)
#define CSL_MPU_CHR_US_INST0_REGS                                               (0U)
#define CSL_MPU_CHR_US_INST1_REGS                                               (1U)
#define CSL_MPU_CHR_US_INST2_REGS                                               (2U)
#define CSL_MPU_DEI_REGS                                                        (0U)
#define CSL_MPU_SC_REGS                                                         (0U)
#define CSL_MPU_CSC_REGS                                                        (0U)
#define CSL_MPU_VPDMA_REGS                                                      (0U)
#define CSL_MPU_OCMC_RAM2_CBUF                                                  (0U)
#define CSL_MPU_OCMC_RAM3_CBUF                                                  (0U)
#define CSL_MPU_IA_IP0                                                          (0U)
#define CSL_MPU_CTRL_MODULE_CORE                                                (0U)
#define CSL_MPU_CTRL_MODULE_CORE_CORE_REGISTERS                                 (0U)
#define CSL_MPU_IRQ_DMARQ_CROSSBAR_REGISTERS                                    (0U)
#define CSL_MPU_CTRL_MODULE_CORE_CORE_PAD_REGISTERS                             (0U)
#define CSL_MPU_CORE_PAD_IO_REGISTERS                                           (0U)
#define CSL_MPU_SEC_EFUSE_REGISTERS                                             (0U)
#define CSL_MPU_TA_CTRL_MODULE_CORE_TARG                                        (0U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_AON                                          (0U)
#define CSL_MPU_CKGEN_CM_CORE_AON                                               (0U)
#define CSL_MPU_MPU_CM_CORE_AON                                                 (0U)
#define CSL_MPU_DSP1_CM_CORE_AON                                                (0U)
#define CSL_MPU_IPU_CM_CORE_AON                                                 (0U)
#define CSL_MPU_DSP2_CM_CORE_AON                                                (0U)
#define CSL_MPU_EVE1_CM_CORE_AON                                                (0U)
#define CSL_MPU_EVE2_CM_CORE_AON                                                (0U)
#define CSL_MPU_EVE3_CM_CORE_AON                                                (0U)
#define CSL_MPU_EVE4_CM_CORE_AON                                                (0U)
#define CSL_MPU_RTC_CM_CORE_AON                                                 (0U)
#define CSL_MPU_VPE_CM_CORE_AON                                                 (0U)
#define CSL_MPU_RESTORE_CM_CORE_AON                                             (0U)
#define CSL_MPU_INSTR_CM_CORE_AON                                               (0U)
#define CSL_MPU_TA_CM_CORE_AON_TARG                                             (0U)
#define CSL_MPU_OCP_SOCKET_CM_CORE                                              (0U)
#define CSL_MPU_CKGEN_CM_CORE                                                   (0U)
#define CSL_MPU_COREAON_CM_CORE                                                 (0U)
#define CSL_MPU_CORE_CM_CORE                                                    (0U)
#define CSL_MPU_IVA_CM_CORE                                                     (0U)
#define CSL_MPU_CAM_CM_CORE                                                     (0U)
#define CSL_MPU_DSS_CM_CORE                                                     (0U)
#define CSL_MPU_GPU_CM_CORE                                                     (0U)
#define CSL_MPU_L3INIT_CM_CORE                                                  (0U)
#define CSL_MPU_CUSTEFUSE_CM_CORE                                               (0U)
#define CSL_MPU_L4PER_CM_CORE                                                   (0U)
#define CSL_MPU_RESTORE_CM_CORE                                                 (0U)
#define CSL_MPU_TA_CM_CORE_TARG                                                 (0U)
#define CSL_MPU_DMA_SYSTEM                                                      (0U)
#define CSL_MPU_TA_DMA_SYSTEM_TARG                                              (0U)
#define CSL_MPU_SAR_ROM                                                         (0U)
#define CSL_MPU_TA_SAR_ROM_TARG                                                 (0U)
#define CSL_MPU_OCP2SCP1                                                        (0U)
#define CSL_MPU_OCP2SCP1_USB_PHY1_CORE                                          (0U)
#define CSL_MPU_OCP2SCP1_USB3RX_PHY_USB                                         (0U)
#define CSL_MPU_OCP2SCP1_USB3TX_PHY_USB                                         (0U)
#define CSL_MPU_OCP2SCP1_DPLLCTRL_USB_OTG_SS                                    (0U)
#define CSL_MPU_OCP2SCP1_USB_PHY2_CORE                                          (1U)
#define CSL_MPU_TA_OCP2SCP1_TARG                                                (0U)
#define CSL_MPU_OCP2SCP3                                                        (1U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_PCIE1                                       (1U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_PCIE1                                       (1U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_PCIE1                                         (0U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_PCIE2                                       (2U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_PCIE2                                       (2U)
#define CSL_MPU_OCP2SCP3_USB3RX_PHY_SATA                                        (3U)
#define CSL_MPU_OCP2SCP3_USB3TX_PHY_SATA                                        (3U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_SATA                                          (0U)
#define CSL_MPU_TA_OCP2SCP3_TARG                                                (0U)
#define CSL_MPU_OCP2SCP2                                                        (2U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO1                                        (0U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO2                                        (0U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_HDMI                                          (0U)
#define CSL_MPU_TA_OCP2SCP2_TARG                                                (0U)
#define CSL_MPU_SMARTREFLEX_MPU                                                 (0U)
#define CSL_MPU_TA_SMARTREFLEX_MPU_TARG                                         (0U)
#define CSL_MPU_SMARTREFLEX_CORE                                                (1U)
#define CSL_MPU_TA_SMARTREFLEX_CORE_TARG                                        (0U)
#define CSL_MPU_EFUSE_CTRL_CUST                                                 (0U)
#define CSL_MPU_TA_EFUSE_CTRL_CUST_TARG                                         (0U)
#define CSL_MPU_MAILBOX1                                                        (12U)
#define CSL_MPU_TA_MAILBOX1_TARG                                                (0U)
#define CSL_MPU_SPINLOCK                                                        (0U)
#define CSL_MPU_TA_SPINLOCK_TARG                                                (0U)
#define CSL_MPU_OCP_WP_NOC                                                      (0U)
#define CSL_MPU_TA_OCP_WP_NOC_TARG                                              (0U)
#define CSL_MPU_IEEE1500_2_OCP                                                  (0U)
#define CSL_MPU_TA_IEEE1500_2_OCP_TARG                                          (0U)
#define CSL_MPU_DWC_AHSATA                                                      (0U)
#define CSL_MPU_SATAMAC_WRAPPER                                                 (0U)
#define CSL_MPU_TA_SATA_TARG                                                    (0U)
#define CSL_MPU_SECURITYCORE_EVE1                                               (0U)
#define CSL_MPU_TA_EVE1_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_EVE2                                               (0U)
#define CSL_MPU_TA_EVE2_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_EVE3                                               (0U)
#define CSL_MPU_TA_EVE3_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_EVE4                                               (0U)
#define CSL_MPU_TA_EVE4_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_PCIE2                                              (0U)
#define CSL_MPU_TA_PCIE_SS2_FW_CFG_TARG                                         (0U)
#define CSL_MPU_SECURITYCORE_IPU1                                               (0U)
#define CSL_MPU_TA_IPU1_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_VCP1                                               (0U)
#define CSL_MPU_TA_VCP1_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_VCP2                                               (0U)
#define CSL_MPU_TA_VCP2_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_TPCC                                               (0U)
#define CSL_MPU_TA_EDMA_TPCC_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_TPTC                                               (0U)
#define CSL_MPU_TA_EDMA_TC0_FW_CFG_TARG                                         (0U)
#define CSL_MPU_SECURITYCORE_PCIE1                                              (0U)
#define CSL_MPU_TA_PCIE_SS1_FW_CFG_TARG                                         (0U)
#define CSL_MPU_SECURITYCORE_MCASP1                                             (0U)
#define CSL_MPU_TA_MCASP1_FW_CFG_TARG                                           (0U)
#define CSL_MPU_SECURITYCORE_MCASP2                                             (0U)
#define CSL_MPU_TA_MCASP2_FW_CFG_TARG                                           (0U)
#define CSL_MPU_SECURITYCORE_MCASP3                                             (0U)
#define CSL_MPU_TA_MCASP3_FW_CFG_TARG                                           (0U)
#define CSL_MPU_SECURITYCORE_TSC_ADC                                            (0U)
#define CSL_MPU_TA_SPARE_TSC_ADC_FW_CFG_TARG                                    (0U)
#define CSL_MPU_SECURITYCORE_DSP1_SDMA                                          (0U)
#define CSL_MPU_TA_DSP1_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_DSP2_SDMA                                          (0U)
#define CSL_MPU_TA_DSP2_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_PRUSS1                                             (0U)
#define CSL_MPU_TA_PRUSS1_FW_CFG_TARG                                           (0U)
#define CSL_MPU_SECURITYCORE_PRUSS2                                             (0U)
#define CSL_MPU_TA_PRUSS2_FW_CFG_TARG                                           (0U)
#define CSL_MPU_SECURITYCORE_QSPI                                               (0U)
#define CSL_MPU_TA_QSPI_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SPARE_SMARTREFLEX_RTC                                           (0U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_RTC_TARG                                   (0U)
#define CSL_MPU_SPARE_SMARTREFLEX_WKUP                                          (1U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_WKUP_TARG                                  (0U)
#define CSL_MPU_SPARE_SMARTREFLEX_SDRAM                                         (0U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_SDRAM_TARG                                 (0U)
#define CSL_MPU_SMARTREFLEX_DSPEVE                                              (2U)
#define CSL_MPU_TA_SMARTREFLEX_DSPEVE_TARG                                      (0U)
#define CSL_MPU_SMARTREFLEX_GPU                                                 (3U)
#define CSL_MPU_TA_SMARTREFLEX_GPU_TARG                                         (0U)
#define CSL_MPU_SMARTREFLEX_IVA                                                 (4U)
#define CSL_MPU_TA_SMARTREFLEX_IVA_TARG                                         (0U)
#define CSL_MPU_SECURITYCORE_OCMC_ROM                                           (0U)
#define CSL_MPU_TA_OCMC_ROM_FW_CFG_TARG                                         (0U)
#define CSL_MPU_MA_MPU_NTTP_FW_CFG                                              (0U)
#define CSL_MPU_TA_MA_MPU_NTTP_FW_CFG_TARG                                      (0U)
#define CSL_MPU_SECURITYCORE_OCP_FW_EMIF_5430                                   (0U)
#define CSL_MPU_TA_EMIF_OCP_FW_CFG_TARG                                         (0U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM2                                          (0U)
#define CSL_MPU_TA_OCMC_RAM2_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_GPMC                                               (0U)
#define CSL_MPU_TA_GPMC_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM1                                          (0U)
#define CSL_MPU_TA_OCMC_RAM1_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_GPU                                                (0U)
#define CSL_MPU_TA_GPU_FW_CFG_TARG                                              (0U)
#define CSL_MPU_SECURITYCORE_IPU2                                               (0U)
#define CSL_MPU_TA_IPU2_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_GRPX2D                                             (0U)
#define CSL_MPU_TA_BB2D_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_DSS                                                (0U)
#define CSL_MPU_TA_DSS_FW_CFG_TARG                                              (0U)
#define CSL_MPU_SECURITYCORE_IVA1_SL2IF                                         (0U)
#define CSL_MPU_TA_IVA_SL2IF_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_IVA1_CONFIG                                        (0U)
#define CSL_MPU_TA_IVA_CONFIG_FW_CFG_TARG                                       (0U)
#define CSL_MPU_SECURITYCORE_DEBUGSS_CT_TBR                                     (0U)
#define CSL_MPU_TA_DEBUGSS_CT_TBR_FW_CFG_TARG                                   (0U)
#define CSL_MPU_SECURITYCORE_L3_INSTR                                           (0U)
#define CSL_MPU_TA_L3_INSTR_FW_CFG_TARG                                         (0U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM3                                          (0U)
#define CSL_MPU_TA_OCMC_RAM3_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_AES1                                               (0U)
#define CSL_MPU_TA_AES1_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_AES2                                               (0U)
#define CSL_MPU_TA_AES2_FW_CFG_TARG                                             (0U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P1                                         (0U)
#define CSL_MPU_TA_SHA2MD5_1_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P2                                         (0U)
#define CSL_MPU_TA_SHA2MD5_2_FW_CFG_TARG                                        (0U)
#define CSL_MPU_SECURITYCORE_IVA2_SL2IF                                         (0U)
#define CSL_MPU_TA_SPARE_IVA2_SL2IF_FW_CFG_TARG                                 (0U)
#define CSL_MPU_SECURITYCORE_IVA2_CONFIG                                        (0U)
#define CSL_MPU_TA_SPARE_IVA2_CONFIG_FW_CFG_TARG                                (0U)
#define CSL_MPU_COUNTER_32K                                                     (0U)
#define CSL_MPU_OCP_SOCKET_PRM                                                  (0U)
#define CSL_MPU_CKGEN_PRM                                                       (0U)
#define CSL_MPU_MPU_PRM                                                         (0U)
#define CSL_MPU_DSP1_PRM                                                        (0U)
#define CSL_MPU_IPU_PRM                                                         (0U)
#define CSL_MPU_COREAON_PRM                                                     (0U)
#define CSL_MPU_CORE_PRM                                                        (0U)
#define CSL_MPU_IVA_PRM                                                         (0U)
#define CSL_MPU_CAM_PRM                                                         (0U)
#define CSL_MPU_DSS_PRM                                                         (0U)
#define CSL_MPU_GPU_PRM                                                         (0U)
#define CSL_MPU_L3INIT_PRM                                                      (0U)
#define CSL_MPU_L4PER_PRM                                                       (0U)
#define CSL_MPU_CUSTEFUSE_PRM                                                   (0U)
#define CSL_MPU_WKUPAON_PRM                                                     (0U)
#define CSL_MPU_WKUPAON_CM                                                      (0U)
#define CSL_MPU_EMU_PRM                                                         (0U)
#define CSL_MPU_EMU_CM                                                          (0U)
#define CSL_MPU_DSP2_PRM                                                        (0U)
#define CSL_MPU_EVE1_PRM                                                        (0U)
#define CSL_MPU_EVE2_PRM                                                        (0U)
#define CSL_MPU_EVE3_PRM                                                        (0U)
#define CSL_MPU_EVE4_PRM                                                        (0U)
#define CSL_MPU_RTC_PRM                                                         (0U)
#define CSL_MPU_VPE_PRM                                                         (0U)
#define CSL_MPU_DEVICE_PRM                                                      (0U)
#define CSL_MPU_INSTR_PRM                                                       (0U)
#define CSL_MPU_CTRL_MODULE_WKUP                                                (0U)
#define CSL_MPU_CTRL_MODULE_WKUP_CORE_REGISTERS                                 (0U)
#define CSL_MPU_CTRL_MODULE_WKUP_CORE_PAD_REGISTERS                             (0U)
#define CSL_MPU_GPIO1                                                           (7U)
#define CSL_MPU_WD_TIMER2                                                       (0U)
#define CSL_MPU_TIMER1                                                          (2U)
#define CSL_MPU_KBD                                                             (0U)
#define CSL_MPU_TIMER12                                                         (12U)
#define CSL_MPU_WD_TIMER1                                                       (1U)
#define CSL_MPU_SAR_RAM_SPACE1                                                  (0U)
#define CSL_MPU_SAR_RAM_SPACE2                                                  (1U)
#define CSL_MPU_SAR_RAM_SPACE3                                                  (2U)
#define CSL_MPU_SAR_RAM_SPACE4                                                  (3U)
#define CSL_MPU_UART10                                                          (9U)
#define CSL_MPU_SPARE_SAFETY1                                                   (14U)
#define CSL_MPU_SPARE_SAFETY2                                                   (15U)
#define CSL_MPU_SPARE_SAFETY3                                                   (16U)
#define CSL_MPU_SPARE_SAFETY4                                                   (17U)
#define CSL_MPU_SPARE_UNKNOWN2                                                  (18U)
#define CSL_MPU_SPARE_UNKNOWN3                                                  (19U)
#define CSL_MPU_DCAN1                                                           (1U)
#define CSL_MPU_SHA2MD5_1_ADDRSP0                                               (1U)
#define CSL_MPU_SHA2MD5_1_ADDRSP1                                               (0U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS1_U_DATA_RAM0_8KB                                          (0U)
#define CSL_MPU_PRUSS1_U_DATA_RAM1_8KB                                          (1U)
#define CSL_MPU_PRUSS1_U_DATA_RAM_32KB                                          (0U)
/* End of CSL Modification*/
#define CSL_MPU_PRUSS1_U_INTC                                                   (0U)
#define CSL_MPU_PRUSS1_U_PRU0_CTRL                                              (0U)
#define CSL_MPU_PRUSS1_U_PRU0_DEBUG                                             (0U)
#define CSL_MPU_PRUSS1_U_PRU1_CTRL                                              (1U)
#define CSL_MPU_PRUSS1_U_PRU1_DEBUG                                             (1U)
#define CSL_MPU_PRUSS1_U_CFG                                                    (0U)
#define CSL_MPU_PRUSS1_U_UART                                                   (0U)
#define CSL_MPU_PRUSS1_U_IEP                                                    (0U)
#define CSL_MPU_PRUSS1_U_ECAP                                                   (0U)
#define CSL_MPU_PRUSS1_U_MII_RT_CFG                                             (0U)
#define CSL_MPU_PRUSS1_U_MII_MDIO                                               (0U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS1_U_INST_RAM0_12KB                                         (0U)
#define CSL_MPU_PRUSS1_U_INST_RAM1_12KB                                         (1U)
#define CSL_MPU_PRUSS2_U_DATA_RAM0_8KB                                          (0U)
#define CSL_MPU_PRUSS2_U_DATA_RAM1_8KB                                          (1U)
#define CSL_MPU_PRUSS2_U_DATA_RAM_32KB                                          (0U)
/* End of CSL Modification*/
#define CSL_MPU_PRUSS2_U_INTC                                                   (0U)
#define CSL_MPU_PRUSS2_U_PRU0_CTRL                                              (0U)
#define CSL_MPU_PRUSS2_U_PRU0_DEBUG                                             (0U)
#define CSL_MPU_PRUSS2_U_PRU1_CTRL                                              (1U)
#define CSL_MPU_PRUSS2_U_PRU1_DEBUG                                             (1U)
#define CSL_MPU_PRUSS2_U_CFG                                                    (0U)
#define CSL_MPU_PRUSS2_U_UART                                                   (0U)
#define CSL_MPU_PRUSS2_U_IEP                                                    (0U)
#define CSL_MPU_PRUSS2_U_ECAP                                                   (0U)
#define CSL_MPU_PRUSS2_U_MII_RT_CFG                                             (0U)
#define CSL_MPU_PRUSS2_U_MII_MDIO                                               (0U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS2_U_INST_RAM0_12KB                                         (0U)
#define CSL_MPU_PRUSS2_U_INST_RAM1_12KB                                         (1U)
/* End of CSL Modification*/
#define CSL_MPU_QSPI_ADDRSP0                                                    (0U)
#define CSL_MPU_AES1_ADDRSP0                                                    (0U)
#define CSL_MPU_AES1_ADDRSP1                                                    (0U)
#define CSL_MPU_AES2_ADDRSP0                                                    (1U)
#define CSL_MPU_AES2_ADDRSP1                                                    (0U)
#define CSL_MPU_EMIF1_CONF_REGS                                                 (0U)
#define CSL_MPU_EMIF2_CONF_REGS                                                 (1U)
#define CSL_MPU_DMM_CONF_REGS                                                   (0U)
#define CSL_MPU_GPMC_CONF_REGS                                                  (0U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_RC_CFG_DBICS                               (0U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_PL_CONF                                    (0U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_RC_CFG_DBICS2                              (0U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_I_TI_CONF                                    (0U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_RC_CFG_DBICS                               (0U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_PL_CONF                                    (0U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_RC_CFG_DBICS2                              (0U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_I_TI_CONF                                    (0U)
#define CSL_MPU_I_CSCTI_MPU_C0                                                  (0U)
#define CSL_MPU_I_CSCTI_MPU_C1                                                  (1U)
#define CSL_MPU_I_CSTF                                                          (0U)
#define CSL_MPU_I_DAP_PC                                                        (0U)
#define CSL_MPU_I_CSSTM                                                         (0U)
#define CSL_MPU_I_SGU                                                           (0U)
#define CSL_MPU_I_CSCTI                                                         (2U)
#define CSL_MPU_I_DRM                                                           (0U)
#define CSL_MPU_I_MIPI_STM                                                      (0U)
#define CSL_MPU_I_CSTPIU                                                        (0U)
#define CSL_MPU_I_CSTF1                                                         (1U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_CT_TBR                                (0U)
#define CSL_MPU_CT_UART                                                         (0U)
#define CSL_MPU_CSCTI                                                           (3U)
#define CSL_MPU_OCP2SCP                                                         (3U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_PLLCTRL                               (0U)
#define CSL_MPU_CT_TBR                                                          (0U)
#define CSL_MPU_IPU2_TARGET                                                     (0U)
#define CSL_MPU_IPU2_TARGET_UNICACHE_MMU                                        (0U)
#define CSL_MPU_IPU2_TARGET_L2_MMU                                              (0U)
#define CSL_MPU_KLIO                                                            (0U)
#define CSL_MPU_HYDRA2                                                          (0U)
#define CSL_MPU_KLIO_0                                                          (1U)
#define CSL_MPU_KLIO_1                                                          (2U)
#define CSL_MPU_KLIO_HL                                                         (0U)
#define CSL_MPU_DSS_FAMILY                                                      (0U)
#define CSL_MPU_DISPC                                                           (0U)
#define CSL_MPU_RFBI                                                            (0U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE1                                            (0U)
#define CSL_MPU_DSI_PHY1                                                        (0U)
#define CSL_MPU_PLLCTRL1                                                        (0U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE2                                            (1U)
#define CSL_MPU_DSI_PHY2                                                        (1U)
#define CSL_MPU_PLLCTRL2                                                        (1U)
#define CSL_MPU_DESHDCP                                                         (0U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE3                                            (2U)
#define CSL_MPU_DSI_PHY3                                                        (2U)
#define CSL_MPU_PLLCTRL3                                                        (2U)
#define CSL_MPU_HDMI_WP                                                         (0U)
#define CSL_MPU_HDMI_PLLCTRL                                                    (0U)
#define CSL_MPU_HDMI_PHY                                                        (0U)
#define CSL_MPU_HDMI_DWC_TX                                                     (0U)
#define CSL_MPU_IPU1_TARGET                                                     (1U)
#define CSL_MPU_IPU1_TARGET_UNICACHE_MMU                                        (0U)
#define CSL_MPU_IPU1_TARGET_L2_MMU                                              (0U)
#define CSL_MPU_BB2DIP_GC320                                                    (0U)
#define CSL_MPU_IVA_CONFIG                                                      (0U)
#define CSL_MPU_ICONT1_DMEM                                                     (0U)
#define CSL_MPU_ICONT1_IMEM                                                     (0U)
#define CSL_MPU_ICONT2_DMEM                                                     (1U)
#define CSL_MPU_ICONT2_IMEM                                                     (1U)
#define CSL_MPU_ECD3_MEM                                                        (0U)
#define CSL_MPU_CALC3_MEM                                                       (0U)
#define CSL_MPU_MC3_MEM                                                         (0U)
#define CSL_MPU_IPE3_MEM                                                        (0U)
#define CSL_MPU_ICECRUSHER1_CFG_IC968                                           (0U)
#define CSL_MPU_CONF                                                            (0U)
#define CSL_MPU_VDMA_CFG                                                        (0U)
#define CSL_MPU_ILF3_CFG                                                        (0U)
#define CSL_MPU_IME3_CFG                                                        (0U)
#define CSL_MPU_CALC3_CFG_MMR                                                   (0U)
#define CSL_MPU_CALC3_CFG_BFSW                                                  (0U)
#define CSL_MPU_CALC3_CFG_LSE                                                   (0U)
#define CSL_MPU_CALC3_CFG_IPGW                                                  (0U)
#define CSL_MPU_IPE3_CFG_MMR                                                    (0U)
#define CSL_MPU_IPE3_CFG_BFSW                                                   (0U)
#define CSL_MPU_IPE3_CFG_LSE                                                    (0U)
#define CSL_MPU_IPE3_CFG_IPGW                                                   (0U)
#define CSL_MPU_MC3_CFG_MMR                                                     (0U)
#define CSL_MPU_MC3_CFG_BFSW                                                    (0U)
#define CSL_MPU_MC3_CFG_LSE                                                     (0U)
#define CSL_MPU_MC3_CFG_IPGW                                                    (0U)
#define CSL_MPU_ECD3_CFG_MMR                                                    (0U)
#define CSL_MPU_ECD3_CFG_BFSW                                                   (0U)
#define CSL_MPU_ECD3_CFG_LSE                                                    (0U)
#define CSL_MPU_ECD3_CFG_IPGW                                                   (0U)
#define CSL_MPU_SYSCTRL                                                         (0U)
#define CSL_MPU_MAILBOX                                                         (13U)
#define CSL_MPU_ICONT1_SB_SYNCBOX                                               (0U)
#define CSL_MPU_ICONT1_MMR_CFG                                                  (0U)
#define CSL_MPU_ICONT1_MMR_IRQ                                                  (0U)
#define CSL_MPU_ICONT1_MMR_DM                                                   (0U)
#define CSL_MPU_ICONT1_MMR_SBH                                                  (0U)
#define CSL_MPU_ICONT2_MMR_CFG                                                  (0U)
#define CSL_MPU_ICONT2_MMR_IRQ                                                  (0U)
#define CSL_MPU_ICONT2_MMR_DM                                                   (0U)
#define CSL_MPU_ICONT2_MMR_SBH                                                  (0U)
#define CSL_MPU_SPARE_IVA2_CONFIG                                               (20U)
#define CSL_MPU_IVA_SL2IF                                                       (1U)
#define CSL_MPU_SL2_MEM                                                         (0U)
#define CSL_MPU_SPARE_IVA2_SL2IF                                                (0U)
#define CSL_MPU_QSPI_ADDRSP1                                                    (0U)
#define CSL_MPU_TILER                                                           (0U)
#define CSL_MPU_EMIF1_SDRAM_CS0                                                 (0U)
#define CSL_MPU_EMIF2_SDRAM_CS0                                                 (0U)
#define CSL_MPU_EMIF2_SDRAM_CS1                                                 (0U)
#define CSL_MPU_EMIF1_SDRAM_CS1                                                 (0U)

/* Auto-Generated Instance CNT List */
#define CSL_MPU_GPMC_DUMMY_CNT                                                  (1U)
#define CSL_MPU_PCIE_SS1_DUMMY_CNT                                              (1U)
#define CSL_MPU_PCIE_SS2_DUMMY_CNT                                              (1U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_CNT                                            (1U)
#define CSL_MPU_MPU_ROM_BOOT_SEC_REST_CNT                                       (1U)
#define CSL_MPU_MPU_ROM_BOOT_PUBLIC_CNT                                         (1U)
#define CSL_MPU_MPU_RAM_CNT                                                     (1U)
#define CSL_MPU_OCMC_ECC_CNT                                                    (3U)
#define CSL_MPU_TURING_SS_DSP_L2_MEM_CNT                                        (2U)
#define CSL_MPU_TURING_SYSTEM_CNT                                               (2U)
#define CSL_MPU_TURING_SS_MMU_CNT                                               (4U)
#define CSL_MPU_TURING_SS_DSP_L2_FNOC_CNT                                       (2U)
#define CSL_MPU_DSP_FW1_CNT                                                     (2U)
#define CSL_MPU_DSP_TPTC_CNT                                                    (4U)
#define CSL_MPU_DSP_NOC_CNT                                                     (2U)
#define CSL_MPU_DSP_DFT_CNT                                                     (2U)
#define CSL_MPU_DSP_TPCC_CNT                                                    (2U)
#define CSL_MPU_TURING_SS_DSP_L1P_MEM_CNT                                       (2U)
#define CSL_MPU_TURING_SS_DSP_L1D_MEM_CNT                                       (2U)
#define CSL_MPU_OCMC_RAM1_CBUF_DUMMY_CNT                                        (1U)
#define CSL_MPU_EVE1_EVE_DMEM_CNT                                               (2U)
#define CSL_MPU_EVE1_EVE_IBUFHA_CNT                                             (4U)
#define CSL_MPU_EVE1_EVE_CONTROL_CNT                                            (1U)
#define CSL_MPU_EVE1_EVE_MMU_CNT                                                (2U)
#define CSL_MPU_EVE1_ARP32_CNT                                                  (1U)
#define CSL_MPU_EVE1_VCOP_CNT                                                   (1U)
#define CSL_MPU_EVE1_CTM_CNT                                                    (1U)
#define CSL_MPU_EVE1_EVE_TPTC_CNT                                               (2U)
#define CSL_MPU_EVE1_SMSET_CONF_CNT                                             (1U)
#define CSL_MPU_EVE1_SMSET_SW_CNT                                               (1U)
#define CSL_MPU_EVE1_L2_FNOC_EVE_CNT                                            (1U)
#define CSL_MPU_EVE1_MLB_CNT                                                    (5U)
#define CSL_MPU_EVE1_PCACHE_RAW_CNT                                             (1U)
#define CSL_MPU_EVE1_PCACHE_TAGS_CNT                                            (1U)
#define CSL_MPU_EVE1_EVE_TPCC_CNT                                               (1U)
#define CSL_MPU_EVE2_EVE_DMEM_CNT                                               (2U)
#define CSL_MPU_EVE2_EVE_IBUFHA_CNT                                             (4U)
#define CSL_MPU_EVE2_EVE_CONTROL_CNT                                            (1U)
#define CSL_MPU_EVE2_EVE_MMU_CNT                                                (2U)
#define CSL_MPU_EVE2_ARP32_CNT                                                  (1U)
#define CSL_MPU_EVE2_VCOP_CNT                                                   (1U)
#define CSL_MPU_EVE2_CTM_CNT                                                    (1U)
#define CSL_MPU_EVE2_EVE_TPTC_CNT                                               (2U)
#define CSL_MPU_EVE2_SMSET_CONF_CNT                                             (1U)
#define CSL_MPU_EVE2_SMSET_SW_CNT                                               (1U)
#define CSL_MPU_EVE2_L2_FNOC_EVE_CNT                                            (1U)
#define CSL_MPU_EVE2_MLB_CNT                                                    (5U)
#define CSL_MPU_EVE2_PCACHE_RAW_CNT                                             (1U)
#define CSL_MPU_EVE2_PCACHE_TAGS_CNT                                            (1U)
#define CSL_MPU_EVE2_EVE_TPCC_CNT                                               (1U)
#define CSL_MPU_EVE3_EVE_DMEM_CNT                                               (2U)
#define CSL_MPU_EVE3_EVE_IBUFHA_CNT                                             (4U)
#define CSL_MPU_EVE3_EVE_CONTROL_CNT                                            (1U)
#define CSL_MPU_EVE3_EVE_MMU_CNT                                                (2U)
#define CSL_MPU_EVE3_ARP32_CNT                                                  (1U)
#define CSL_MPU_EVE3_VCOP_CNT                                                   (1U)
#define CSL_MPU_EVE3_CTM_CNT                                                    (1U)
#define CSL_MPU_EVE3_EVE_TPTC_CNT                                               (2U)
#define CSL_MPU_EVE3_SMSET_CONF_CNT                                             (1U)
#define CSL_MPU_EVE3_SMSET_SW_CNT                                               (1U)
#define CSL_MPU_EVE3_L2_FNOC_EVE_CNT                                            (1U)
#define CSL_MPU_EVE3_MLB_CNT                                                    (5U)
#define CSL_MPU_EVE3_PCACHE_RAW_CNT                                             (1U)
#define CSL_MPU_EVE3_PCACHE_TAGS_CNT                                            (1U)
#define CSL_MPU_EVE3_EVE_TPCC_CNT                                               (1U)
#define CSL_MPU_EVE4_EVE_DMEM_CNT                                               (2U)
#define CSL_MPU_EVE4_EVE_IBUFHA_CNT                                             (4U)
#define CSL_MPU_EVE4_EVE_CONTROL_CNT                                            (1U)
#define CSL_MPU_EVE4_EVE_MMU_CNT                                                (2U)
#define CSL_MPU_EVE4_ARP32_CNT                                                  (1U)
#define CSL_MPU_EVE4_VCOP_CNT                                                   (1U)
#define CSL_MPU_EVE4_CTM_CNT                                                    (1U)
#define CSL_MPU_EVE4_EVE_TPTC_CNT                                               (2U)
#define CSL_MPU_EVE4_SMSET_CONF_CNT                                             (1U)
#define CSL_MPU_EVE4_SMSET_SW_CNT                                               (1U)
#define CSL_MPU_EVE4_L2_FNOC_EVE_CNT                                            (1U)
#define CSL_MPU_EVE4_MLB_CNT                                                    (5U)
#define CSL_MPU_EVE4_PCACHE_RAW_CNT                                             (1U)
#define CSL_MPU_EVE4_PCACHE_TAGS_CNT                                            (1U)
#define CSL_MPU_EVE4_EVE_TPCC_CNT                                               (1U)
#define CSL_MPU_SHAEIP58T_CNT                                                   (2U)
#define CSL_MPU_SHA2MD5_2_ADDRSP1_DUMMY_CNT                                     (1U)
#define CSL_MPU_SPARE_TSC_ADC_CNT                                               (1U)
#define CSL_MPU_TPCC_CNT                                                        (1U)
#define CSL_MPU_TPTC_CNT                                                        (2U)
#define CSL_MPU_OCMC_ROM_CNT                                                    (1U)
/*
   CSL Modification: Removed AVATAR entries for matching to TRM spec and external
   friendly names Added them by hand for compatibility.
*/
#define CSL_MPU_L3_NOC_CNT                                               (1U)
/* End of CSL Modification*/
#define CSL_MPU_MCASP_CNT                                                       (16U)
#define CSL_MPU_VCP_CNT                                                         (4U)
#define CSL_MPU_MPU_CS_STM_CNT                                                  (1U)
#define CSL_MPU_UART_CNT                                                        (10U)
#define CSL_MPU_DMTIMER_DMC1MS_CNT                                              (3U)
#define CSL_MPU_DMTIMER_CNT                                                     (13U)
#define CSL_MPU_GPIO_V2_CNT                                                     (8U)
#define CSL_MPU_MSHSI2COCP_CNT                                                  (5U)
#define CSL_MPU_ELM_CNT                                                         (1U)
#define CSL_MPU_RNGEIP75T_CNT                                                   (1U)
#define CSL_MPU_MCSPI_CNT                                                       (4U)
#define CSL_MPU_MMCHS_CNT                                                       (4U)
#define CSL_MPU_CDMA_CNT                                                        (1U)
#define CSL_MPU_DESEIP16T_CNT                                                   (1U)
#define CSL_MPU_DES3DES_ADDRSP1_DUMMY_CNT                                       (1U)
#define CSL_MPU_PKA4KEIP29T_CNT                                                 (1U)
#define CSL_MPU_HDQW_CNT                                                        (1U)
#define CSL_MPU_INTC_MPU_DISTRIBUTOR_CNT                                        (1U)
#define CSL_MPU_INTC_MPU_PHYS_CPU_IF_CNT                                        (1U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_HYP_CNT                                    (1U)
#define CSL_MPU_INTC_MPU_VIRT_CPU_IF_VM_CNT                                     (1U)
#define CSL_MPU_PRCM_MPU_CNT                                                    (1U)
#define CSL_MPU_PRCM_MPU_OCP_SOCKET_CNT                                         (1U)
#define CSL_MPU_PRCM_MPU_DEVICE_CNT                                             (1U)
#define CSL_MPU_PRCM_MPU_PRM_C0_CNT                                             (1U)
#define CSL_MPU_PRCM_MPU_CM_C0_CNT                                              (1U)
#define CSL_MPU_PRCM_MPU_PRM_C1_CNT                                             (1U)
#define CSL_MPU_PRCM_MPU_CM_C1_CNT                                              (1U)
#define CSL_MPU_SCM_CNT                                                         (1U)
#define CSL_MPU_WUGEN_MPU_CNT                                                   (1U)
#define CSL_MPU_CMU_MPU_CNT                                                     (1U)
#define CSL_MPU_WATCHDOGTIMER_CNT                                               (1U)
#define CSL_MPU_AXI2OCP_RPT_CNT                                                 (1U)
#define CSL_MPU_AXI2OCP_MISC_CNT                                                (1U)
#define CSL_MPU_MA_MPU_LSM_CNT                                                  (1U)
#define CSL_MPU_MA_MPU_WP_CNT                                                   (1U)
#define CSL_MPU_MOST_150_CNT                                                    (1U)
#define CSL_MPU_ATL_CNT                                                         (1U)
#define CSL_MPU_PWMSS1_PWMSS_CNT                                                (1U)
#define CSL_MPU_PWMSS1_ECAP_CNT                                                 (1U)
#define CSL_MPU_PWMSS1_EQEP_CNT                                                 (1U)
#define CSL_MPU_PWMSS1_EPWM_CNT                                                 (1U)
#define CSL_MPU_PWMSS2_PWMSS_CNT                                                (1U)
#define CSL_MPU_PWMSS2_ECAP_CNT                                                 (1U)
#define CSL_MPU_PWMSS2_EQEP_CNT                                                 (1U)
#define CSL_MPU_PWMSS2_EPWM_CNT                                                 (1U)
#define CSL_MPU_PWMSS3_PWMSS_CNT                                                (1U)
#define CSL_MPU_PWMSS3_ECAP_CNT                                                 (1U)
#define CSL_MPU_PWMSS3_EQEP_CNT                                                 (1U)
#define CSL_MPU_PWMSS3_EPWM_CNT                                                 (1U)
#define CSL_MPU_IODELAYCONFIG_CNT                                               (1U)
#define CSL_MPU_SPARE_CNT                                                       (21U)
#define CSL_MPU_DCAN_CNT                                                        (2U)
#define CSL_MPU_CPSW_SS_CNT                                                     (1U)
#define CSL_MPU_CPSW_PORT_CNT                                                   (1U)
#define CSL_MPU_CPSW_CPDMA_CNT                                                  (1U)
#define CSL_MPU_CPDMA_STATERAM_CNT                                              (1U)
#define CSL_MPU_CPSW_CPTS_CNT                                                   (1U)
#define CSL_MPU_CPSW_ALE_CNT                                                    (1U)
#define CSL_MPU_CPSW_SL_CNT                                                     (2U)
#define CSL_MPU_MDIO_CNT                                                        (1U)
#define CSL_MPU_CPSW_WR_CNT                                                     (1U)
#define CSL_MPU_MLB_CNT                                                         (14U)
#define CSL_MPU_OCMC_RAM1_CFG_DUMMY_CNT                                         (1U)
#define CSL_MPU_OCMC_RAM2_CFG_DUMMY_CNT                                         (1U)
#define CSL_MPU_OCMC_RAM3_CFG_DUMMY_CNT                                         (1U)
#define CSL_MPU_SPARE_SATA2_CNT                                                 (1U)
#define CSL_MPU_L4_PER3_MMU_FUNC_CNT                                            (1U)
#define CSL_MPU_MMU_FUNC_CNT                                                    (1U)
#define CSL_MPU_RTC_CNT                                                         (1U)
#define CSL_MPU_USB1_CFG_USBOTGSS_WRAPPER_CNT                                   (1U)
#define CSL_MPU_USB1_CFG_DWC_USB3_CNT                                           (1U)
#define CSL_MPU_USB2_CFG_USBOTGSS_WRAPPER_CNT                                   (1U)
#define CSL_MPU_USB2_CFG_DWC_USB3_CNT                                           (1U)
#define CSL_MPU_USB3_CFG_USBOTGSS_WRAPPER_CNT                                   (1U)
#define CSL_MPU_USB3_CFG_DWC_USB3_CNT                                           (1U)
#define CSL_MPU_USB4_CFG_USBOTGSS_WRAPPER_CNT                                   (1U)
#define CSL_MPU_USB4_CFG_DWC_USB3_CNT                                           (1U)
#define CSL_MPU_VIP1_VIP_REGISTERS_CNT                                          (1U)
#define CSL_MPU_VIP1_VIP_PARSER_REGISTER_CNT                                    (2U)
#define CSL_MPU_VIP1_CSC_REGISTERS_CNT                                          (2U)
#define CSL_MPU_VIP1_SC_REGISTER_CNT                                            (2U)
#define CSL_MPU_VIP1_VPDMA_REGISTER_CNT                                         (1U)
#define CSL_MPU_VIP2_VIP_REGISTERS_CNT                                          (1U)
#define CSL_MPU_VIP2_VIP_PARSER_REGISTER_CNT                                    (2U)
#define CSL_MPU_VIP2_CSC_REGISTERS_CNT                                          (2U)
#define CSL_MPU_VIP2_SC_REGISTER_CNT                                            (2U)
#define CSL_MPU_VIP2_VPDMA_REGISTER_CNT                                         (1U)
#define CSL_MPU_VIP3_VIP_REGISTERS_CNT                                          (1U)
#define CSL_MPU_VIP3_VIP_PARSER_REGISTER_CNT                                    (2U)
#define CSL_MPU_VIP3_CSC_REGISTERS_CNT                                          (2U)
#define CSL_MPU_VIP3_SC_REGISTER_CNT                                            (2U)
#define CSL_MPU_VIP3_VPDMA_REGISTER_CNT                                         (1U)
#define CSL_MPU_VPE_REGISTER_CNT                                                (1U)
#define CSL_MPU_CHR_US_REGISTERS_CNT                                            (3U)
#define CSL_MPU_DEI_REGISTERS_CNT                                               (1U)
#define CSL_MPU_SC_REGISTER_CNT                                                 (1U)
#define CSL_MPU_CSC_REGISTERS_CNT                                               (1U)
#define CSL_MPU_VPDMA_REGISTER_CNT                                              (1U)
#define CSL_MPU_OCMC_RAM2_CBUF_DUMMY_CNT                                        (1U)
#define CSL_MPU_OCMC_RAM3_CBUF_DUMMY_CNT                                        (1U)
#define CSL_MPU_IA_IP0_CNT                                                      (1U)
/*
   CSL Modification: Removed AVATAR entries formatching to TRM spec and external
   friendly names Added them by hand for compatibility.
*/
#define CSL_MPU_CTRL_MODULE_CORE_CNT                                         (1U)
#define CSL_MPU_CTRL_MODULE_CORE_CONTROL_CORE_OCPINTF_CNT                (1U)
#define CSL_MPU_CTRL_MODULE_INTR_DMA_OCPINTF_CNT                                     (1U)
#define CSL_MPU_CTRL_MODULE_CORE_CONTROL_CORE_PAD_OCPINTF_CNT            (1U)
#define CSL_MPU_CTRL_MODULE_CORE_PAD_IO_OCPINTF_CNT                          (1U)
#define CSL_MPU_CTRL_MODULE_CORE_SEC_OCPINTF_CNT                             (1U)
/* End of CSL Modification */
#define CSL_MPU_TA_CTRL_MODULE_CORE_TARG_CNT                                    (1U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_AON_CNT                                      (1U)
#define CSL_MPU_CKGEN_CM_CORE_AON_CNT                                           (1U)
#define CSL_MPU_MPU_CM_CORE_AON_CNT                                             (1U)
#define CSL_MPU_DSP1_CM_CORE_AON_CNT                                            (1U)
#define CSL_MPU_IPU_CM_CORE_AON_CNT                                             (1U)
#define CSL_MPU_DSP2_CM_CORE_AON_CNT                                            (1U)
#define CSL_MPU_EVE1_CM_CORE_AON_CNT                                            (1U)
#define CSL_MPU_EVE2_CM_CORE_AON_CNT                                            (1U)
#define CSL_MPU_EVE3_CM_CORE_AON_CNT                                            (1U)
#define CSL_MPU_EVE4_CM_CORE_AON_CNT                                            (1U)
#define CSL_MPU_RTC_CM_CORE_AON_CNT                                             (1U)
#define CSL_MPU_VPE_CM_CORE_AON_CNT                                             (1U)
#define CSL_MPU_RESTORE_CM_CORE_AON_CNT                                         (1U)
#define CSL_MPU_CMI_CNT                                                         (1U)
#define CSL_MPU_TA_CM_CORE_AON_TARG_CNT                                         (1U)
#define CSL_MPU_OCP_SOCKET_CM_CORE_CNT                                          (1U)
#define CSL_MPU_CKGEN_CM_CORE_CNT                                               (1U)
#define CSL_MPU_COREAON_CM_CORE_CNT                                             (1U)
#define CSL_MPU_CORE_CM_CORE_CNT                                                (1U)
#define CSL_MPU_IVA_CM_CORE_CNT                                                 (1U)
#define CSL_MPU_CAM_CM_CORE_CNT                                                 (1U)
#define CSL_MPU_DSS_CM_CORE_CNT                                                 (1U)
#define CSL_MPU_GPU_CM_CORE_CNT                                                 (1U)
#define CSL_MPU_L3INIT_CM_CORE_CNT                                              (1U)
#define CSL_MPU_CUSTEFUSE_CM_CORE_CNT                                           (1U)
#define CSL_MPU_L4PER_CM_CORE_CNT                                               (1U)
#define CSL_MPU_RESTORE_CM_CORE_CNT                                             (1U)
#define CSL_MPU_TA_CM_CORE_TARG_CNT                                             (1U)
#define CSL_MPU_SDMA_CNT                                                        (1U)
#define CSL_MPU_TA_DMA_SYSTEM_TARG_CNT                                          (1U)
#define CSL_MPU_SAR_ROM_CNT                                                     (1U)
#define CSL_MPU_TA_SAR_ROM_TARG_CNT                                             (1U)
#define CSL_MPU_OCP2SCP_CNT                                                     (4U)
#define CSL_MPU_USB2PHY_CNT                                                     (2U)
#define CSL_MPU_GANGARX_SCP_CNT                                                 (4U)
#define CSL_MPU_SHANTANUTX_SCP_CNT                                              (4U)
#define CSL_MPU_OCP2SCP1_DPLLCTRL_USB_OTG_SS_DUMMY_CNT                          (1U)
#define CSL_MPU_TA_OCP2SCP1_TARG_CNT                                            (1U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_PCIE1_DUMMY_CNT                               (1U)
#define CSL_MPU_OCP2SCP3_DPLLCTRL_SATA_DUMMY_CNT                                (1U)
#define CSL_MPU_TA_OCP2SCP3_TARG_CNT                                            (1U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO1_DUMMY_CNT                              (1U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_VIDEO2_DUMMY_CNT                              (1U)
#define CSL_MPU_OCP2SCP2_DPLLCTRL_HDMI_DUMMY_CNT                                (1U)
#define CSL_MPU_TA_OCP2SCP2_TARG_CNT                                            (1U)
#define CSL_MPU_SMARTREFLEX_C3_CNT                                              (5U)
#define CSL_MPU_TA_SMARTREFLEX_MPU_TARG_CNT                                     (1U)
#define CSL_MPU_TA_SMARTREFLEX_CORE_TARG_CNT                                    (1U)
#define CSL_MPU_FUSEFARM_CNT                                                    (1U)
#define CSL_MPU_TA_EFUSE_CTRL_CUST_TARG_CNT                                     (1U)
#define CSL_MPU_TA_MAILBOX1_TARG_CNT                                            (1U)
#define CSL_MPU_SPINLOCK_CNT                                                    (1U)
#define CSL_MPU_TA_SPINLOCK_TARG_CNT                                            (1U)
#define CSL_MPU_OCP_WP_NOC_C1_CNT                                               (1U)
#define CSL_MPU_TA_OCP_WP_NOC_TARG_CNT                                          (1U)
#define CSL_MPU_IEEE1500_2_OCP_CNT                                              (1U)
#define CSL_MPU_TA_IEEE1500_2_OCP_TARG_CNT                                      (1U)
#define CSL_MPU_DWC_AHSATA_CNT                                                  (1U)
#define CSL_MPU_SATAMAC_WRAPPER_CNT                                             (1U)
#define CSL_MPU_TA_SATA_TARG_CNT                                                (1U)
#define CSL_MPU_SECURITYCORE_EVE1_CNT                                           (1U)
#define CSL_MPU_TA_EVE1_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_EVE2_CNT                                           (1U)
#define CSL_MPU_TA_EVE2_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_EVE3_CNT                                           (1U)
#define CSL_MPU_TA_EVE3_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_EVE4_CNT                                           (1U)
#define CSL_MPU_TA_EVE4_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_PCIE2_CNT                                          (1U)
#define CSL_MPU_TA_PCIE_SS2_FW_CFG_TARG_CNT                                     (1U)
#define CSL_MPU_SECURITYCORE_IPU1_CNT                                           (1U)
#define CSL_MPU_TA_IPU1_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_VCP1_CNT                                           (1U)
#define CSL_MPU_TA_VCP1_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_VCP2_CNT                                           (1U)
#define CSL_MPU_TA_VCP2_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_TPCC_CNT                                           (1U)
#define CSL_MPU_TA_EDMA_TPCC_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_TPTC_CNT                                           (1U)
#define CSL_MPU_TA_EDMA_TC0_FW_CFG_TARG_CNT                                     (1U)
#define CSL_MPU_SECURITYCORE_PCIE1_CNT                                          (1U)
#define CSL_MPU_TA_PCIE_SS1_FW_CFG_TARG_CNT                                     (1U)
#define CSL_MPU_SECURITYCORE_MCASP1_CNT                                         (1U)
#define CSL_MPU_TA_MCASP1_FW_CFG_TARG_CNT                                       (1U)
#define CSL_MPU_SECURITYCORE_MCASP2_CNT                                         (1U)
#define CSL_MPU_TA_MCASP2_FW_CFG_TARG_CNT                                       (1U)
#define CSL_MPU_SECURITYCORE_MCASP3_CNT                                         (1U)
#define CSL_MPU_TA_MCASP3_FW_CFG_TARG_CNT                                       (1U)
#define CSL_MPU_SECURITYCORE_TSC_ADC_CNT                                        (1U)
#define CSL_MPU_TA_SPARE_TSC_ADC_FW_CFG_TARG_CNT                                (1U)
#define CSL_MPU_SECURITYCORE_DSP1_SDMA_CNT                                      (1U)
#define CSL_MPU_TA_DSP1_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_DSP2_SDMA_CNT                                      (1U)
#define CSL_MPU_TA_DSP2_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_PRUSS1_CNT                                         (1U)
#define CSL_MPU_TA_PRUSS1_FW_CFG_TARG_CNT                                       (1U)
#define CSL_MPU_SECURITYCORE_PRUSS2_CNT                                         (1U)
#define CSL_MPU_TA_PRUSS2_FW_CFG_TARG_CNT                                       (1U)
#define CSL_MPU_SECURITYCORE_QSPI_CNT                                           (1U)
#define CSL_MPU_TA_QSPI_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SPARE_SMARTREFLEX_CNT                                           (2U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_RTC_TARG_CNT                               (1U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_WKUP_TARG_CNT                              (1U)
#define CSL_MPU_SPARE_SMARTREFLEX_SDRAM_CNT                                     (1U)
#define CSL_MPU_TA_SPARE_SMARTREFLEX_SDRAM_TARG_CNT                             (1U)
#define CSL_MPU_TA_SMARTREFLEX_DSPEVE_TARG_CNT                                  (1U)
#define CSL_MPU_TA_SMARTREFLEX_GPU_TARG_CNT                                     (1U)
#define CSL_MPU_TA_SMARTREFLEX_IVA_TARG_CNT                                     (1U)
#define CSL_MPU_SECURITYCORE_OCMC_ROM_CNT                                       (1U)
#define CSL_MPU_TA_OCMC_ROM_FW_CFG_TARG_CNT                                     (1U)
#define CSL_MPU_MA_MPU_NTTP_FW_CFG_CNT                                          (1U)
#define CSL_MPU_TA_MA_MPU_NTTP_FW_CFG_TARG_CNT                                  (1U)
#define CSL_MPU_SECURITYCORE_OCP_FW_EMIF_5430_CNT                               (1U)
#define CSL_MPU_TA_EMIF_OCP_FW_CFG_TARG_CNT                                     (1U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM2_CNT                                      (1U)
#define CSL_MPU_TA_OCMC_RAM2_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_GPMC_CNT                                           (1U)
#define CSL_MPU_TA_GPMC_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM1_CNT                                      (1U)
#define CSL_MPU_TA_OCMC_RAM1_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_GPU_CNT                                            (1U)
#define CSL_MPU_TA_GPU_FW_CFG_TARG_CNT                                          (1U)
#define CSL_MPU_SECURITYCORE_IPU2_CNT                                           (1U)
#define CSL_MPU_TA_IPU2_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_GRPX2D_CNT                                         (1U)
#define CSL_MPU_TA_BB2D_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_DSS_CNT                                            (1U)
#define CSL_MPU_TA_DSS_FW_CFG_TARG_CNT                                          (1U)
#define CSL_MPU_SECURITYCORE_IVA1_SL2IF_CNT                                     (1U)
#define CSL_MPU_TA_IVA_SL2IF_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_IVA1_CONFIG_CNT                                    (1U)
#define CSL_MPU_TA_IVA_CONFIG_FW_CFG_TARG_CNT                                   (1U)
#define CSL_MPU_SECURITYCORE_DEBUGSS_CT_TBR_CNT                                 (1U)
#define CSL_MPU_TA_DEBUGSS_CT_TBR_FW_CFG_TARG_CNT                               (1U)
#define CSL_MPU_SECURITYCORE_L3_INSTR_CNT                                       (1U)
#define CSL_MPU_TA_L3_INSTR_FW_CFG_TARG_CNT                                     (1U)
#define CSL_MPU_SECURITYCORE_OCMC_RAM3_CNT                                      (1U)
#define CSL_MPU_TA_OCMC_RAM3_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_AES1_CNT                                           (1U)
#define CSL_MPU_TA_AES1_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_AES2_CNT                                           (1U)
#define CSL_MPU_TA_AES2_FW_CFG_TARG_CNT                                         (1U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P1_CNT                                     (1U)
#define CSL_MPU_TA_SHA2MD5_1_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_SHA2MD5_P2_CNT                                     (1U)
#define CSL_MPU_TA_SHA2MD5_2_FW_CFG_TARG_CNT                                    (1U)
#define CSL_MPU_SECURITYCORE_IVA2_SL2IF_CNT                                     (1U)
#define CSL_MPU_TA_SPARE_IVA2_SL2IF_FW_CFG_TARG_CNT                             (1U)
#define CSL_MPU_SECURITYCORE_IVA2_CONFIG_CNT                                    (1U)
#define CSL_MPU_TA_SPARE_IVA2_CONFIG_FW_CFG_TARG_CNT                            (1U)
#define CSL_MPU_SYNCTIMER32K_CNT                                                (1U)
#define CSL_MPU_OCP_SOCKET_PRM_CNT                                              (1U)
#define CSL_MPU_CKGEN_PRM_CNT                                                   (1U)
#define CSL_MPU_MPU_PRM_CNT                                                     (1U)
#define CSL_MPU_DSP1_PRM_CNT                                                    (1U)
#define CSL_MPU_IPU_PRM_CNT                                                     (1U)
#define CSL_MPU_COREAON_PRM_CNT                                                 (1U)
#define CSL_MPU_CORE_PRM_CNT                                                    (1U)
#define CSL_MPU_IVA_PRM_CNT                                                     (1U)
#define CSL_MPU_CAM_PRM_CNT                                                     (1U)
#define CSL_MPU_DSS_PRM_CNT                                                     (1U)
#define CSL_MPU_GPU_PRM_CNT                                                     (1U)
#define CSL_MPU_L3INIT_PRM_CNT                                                  (1U)
#define CSL_MPU_L4PER_PRM_CNT                                                   (1U)
#define CSL_MPU_CUSTEFUSE_PRM_CNT                                               (1U)
#define CSL_MPU_WKUPAON_PRM_CNT                                                 (1U)
#define CSL_MPU_WKUPAON_CM_CNT                                                  (1U)
#define CSL_MPU_EMU_PRM_CNT                                                     (1U)
#define CSL_MPU_EMU_CM_CNT                                                      (1U)
#define CSL_MPU_DSP2_PRM_CNT                                                    (1U)
#define CSL_MPU_EVE1_PRM_CNT                                                    (1U)
#define CSL_MPU_EVE2_PRM_CNT                                                    (1U)
#define CSL_MPU_EVE3_PRM_CNT                                                    (1U)
#define CSL_MPU_EVE4_PRM_CNT                                                    (1U)
#define CSL_MPU_RTC_PRM_CNT                                                     (1U)
#define CSL_MPU_VPE_PRM_CNT                                                     (1U)
#define CSL_MPU_DEVICE_PRM_CNT                                                  (1U)
#define CSL_MPU_PMI_CNT                                                         (1U)
/*
   CSL Modification: Removed AVATAR entries formatching to TRM spec and external
   friendly names Added them by hand for compatibility.
*/
#define CSL_MPU_CTRL_MODULE_WKUP_CNT                                         (1U)
#define CSL_MPU_CTRL_MODULE_WKUP_CONTROL_WKUP_OCPINTF_CNT                (1U)
#define CSL_MPU_CTRL_MODULE_WKUP_CONTROL_WKUP_PAD_OCPINTF_CNT            (1U)
/* End of CSL Modification */
#define CSL_MPU_WATCHDOGOCP2_CNT                                                (2U)
#define CSL_MPU_KBDOCP_CNT                                                      (1U)
#define CSL_MPU_SAR_RAM_CNT                                                     (4U)
#define CSL_MPU_SHA2MD5_1_ADDRSP1_DUMMY_CNT                                     (1U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS1_DATA_RAM_8KB_CNT                                         (2U)
#define CSL_MPU_PRUSS1_DATA_RAM_32KB_CNT                                        (1U)
/* End of CSL Modification*/
#define CSL_MPU_PRUSS1_INTC_CNT                                                 (1U)
#define CSL_MPU_PRUSS1_PRU_CTRL_CNT                                             (2U)
#define CSL_MPU_PRUSS1_PRU_DEBUG_CNT                                            (2U)
#define CSL_MPU_PRUSS1_CFG_CNT                                                  (1U)
#define CSL_MPU_PRUSS1_ICSSM_UART_CNT                                           (1U)
#define CSL_MPU_PRUSS1_IEP_CNT                                                  (1U)
#define CSL_MPU_PRUSS1_ECAP_CNT                                                 (1U)
#define CSL_MPU_PRUSS1_MII_RT_CFG_CNT                                           (1U)
#define CSL_MPU_PRUSS1_MII_MDIO_CNT                                             (1U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS1_INST_RAM_12KB_CNT                                        (2U)
#define CSL_MPU_PRUSS2_DATA_RAM_8KB_CNT                                         (2U)
#define CSL_MPU_PRUSS2_DATA_RAM_32KB_CNT                                        (1U)
/* End of CSL Modification*/
#define CSL_MPU_PRUSS2_INTC_CNT                                                 (1U)
#define CSL_MPU_PRUSS2_PRU_CTRL_CNT                                             (2U)
#define CSL_MPU_PRUSS2_PRU_DEBUG_CNT                                            (2U)
#define CSL_MPU_PRUSS2_CFG_CNT                                                  (1U)
#define CSL_MPU_PRUSS2_ICSSM_UART_CNT                                           (1U)
#define CSL_MPU_PRUSS2_IEP_CNT                                                  (1U)
#define CSL_MPU_PRUSS2_ECAP_CNT                                                 (1U)
#define CSL_MPU_PRUSS2_MII_RT_CFG_CNT                                           (1U)
#define CSL_MPU_PRUSS2_MII_MDIO_CNT                                             (1U)
/*
   CSL Modification: Not Auto-Generated due to source issue
*/
#define CSL_MPU_PRUSS2_INST_RAM_12KB_CNT                                        (2U)
/* End of CSL Modification*/
#define CSL_MPU_QSPI_CNT                                                        (1U)
#define CSL_MPU_AESEIP37T_CNT                                                   (2U)
#define CSL_MPU_AES1_ADDRSP1_DUMMY_CNT                                          (1U)
#define CSL_MPU_AES2_ADDRSP1_DUMMY_CNT                                          (1U)
#define CSL_MPU_EMIF4D5_CNT                                                     (2U)
#define CSL_MPU_DMM_CORE_CNT                                                    (1U)
#define CSL_MPU_GPMC_CNT                                                        (1U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_RC_CFG_DBICS_CNT                             (1U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_PL_CONF_CNT                                  (1U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_RC_CFG_DBICS2_CNT                            (1U)
#define CSL_MPU_PCIE_SS1_CONF_REGS_TI_CONF_CNT                                  (1U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_RC_CFG_DBICS_CNT                             (1U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_PL_CONF_CNT                                  (1U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_RC_CFG_DBICS2_CNT                            (1U)
#define CSL_MPU_PCIE_SS2_CONF_REGS_TI_CONF_CNT                                  (1U)
#define CSL_MPU_CSCTI_CNT                                                       (4U)
#define CSL_MPU_CSTF_CNT                                                        (2U)
#define CSL_MPU_DAP_PC_CNT                                                      (1U)
#define CSL_MPU_CSSTM_CNT                                                       (1U)
#define CSL_MPU_SGU_CNT                                                         (1U)
#define CSL_MPU_DRM_CNT                                                         (1U)
#define CSL_MPU_MIPI_STM_CNT                                                    (1U)
#define CSL_MPU_CSTPIU_CNT                                                      (1U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_CT_TBR_CNT                            (1U)
#define CSL_MPU_CT_UART_CNT                                                     (1U)
#define CSL_MPU_I_DEBUGSS_OMAP5430_CFGBUS_PLLCTRL_CNT                           (1U)
#define CSL_MPU_CT_TBR_DUMMY_CNT                                                (1U)
#define CSL_MPU_DUCATI_SS_CNT                                                   (2U)
#define CSL_MPU_IPU2_TARGET_UNICACHE_MMU_CNT                                    (1U)
#define CSL_MPU_IPU2_TARGET_TESLASS_MMU_CNT                                     (1U)
#define CSL_MPU_KLIO_CNT                                                        (3U)
#define CSL_MPU_HYDRA2_CNT                                                      (1U)
#define CSL_MPU_KLIO_HL_CNT                                                     (1U)
#define CSL_MPU_DSS_FAMILY_CNT                                                  (1U)
#define CSL_MPU_DISPC_CNT                                                       (1U)
#define CSL_MPU_RFBI_CNT                                                        (1U)
#define CSL_MPU_DSI_PROTOCOL_ENGINE_CNT                                         (3U)
#define CSL_MPU_DSI_PHY_CNT                                                     (3U)
#define CSL_MPU_PLLCTRL_CNT                                                     (3U)
#define CSL_MPU_DESHDCP_CNT                                                     (1U)
#define CSL_MPU_HDMI_WP_CNT                                                     (1U)
#define CSL_MPU_HDMI_PLLCTRL_CNT                                                (1U)
#define CSL_MPU_HDMITXPHY_CNT                                                   (1U)
#define CSL_MPU_HDMI_DWC_TX_CNT                                                 (1U)
#define CSL_MPU_IPU1_TARGET_UNICACHE_MMU_CNT                                    (1U)
#define CSL_MPU_IPU1_TARGET_TESLASS_MMU_CNT                                     (1U)
#define CSL_MPU_BB2DIP_GC320_CNT                                                (1U)
#define CSL_MPU_IVAHD_CNT                                                       (2U)
#define CSL_MPU_ICONT_DMEM_CNT                                                  (2U)
#define CSL_MPU_ICONT_IMEM_CNT                                                  (2U)
#define CSL_MPU_ECD3_MEM_CNT                                                    (1U)
#define CSL_MPU_CALC3_MEM_CNT                                                   (1U)
#define CSL_MPU_MC3_MEM_CNT                                                     (1U)
#define CSL_MPU_IPE3_MEM_CNT                                                    (1U)
#define CSL_MPU_ICECRUSHER1_CFG_ICECR968OCP_CNT                                 (1U)
#define CSL_MPU_SMSET_CONF_CNT                                                  (1U)
#define CSL_MPU_VDMA_CNT                                                        (1U)
#define CSL_MPU_ILF3_CNT                                                        (1U)
#define CSL_MPU_IME3_CNT                                                        (1U)
#define CSL_MPU_CALC3_CFG_CALC3_MMR_CNT                                         (1U)
#define CSL_MPU_CALC3_CFG_CALC3_BFSW_CNT                                        (1U)
#define CSL_MPU_CALC3_CFG_LSE_CNT                                               (1U)
#define CSL_MPU_CALC3_CFG_CALC3_IPGW_CNT                                        (1U)
#define CSL_MPU_IPE3_CFG_IPE3_MMR_CNT                                           (1U)
#define CSL_MPU_IPE3_CFG_IPE3_BFSW_CNT                                          (1U)
#define CSL_MPU_IPE3_CFG_LSE_CNT                                                (1U)
#define CSL_MPU_IPE3_CFG_IPE3_IPGW_CNT                                          (1U)
#define CSL_MPU_MC3_CFG_MC3_MMR_CNT                                             (1U)
#define CSL_MPU_MC3_CFG_MC3_BFSW_CNT                                            (1U)
#define CSL_MPU_MC3_CFG_LSE_CNT                                                 (1U)
#define CSL_MPU_MC3_CFG_MC3_IPGW_CNT                                            (1U)
#define CSL_MPU_ECD3_CFG_ECD3_MMR_CNT                                           (1U)
#define CSL_MPU_ECD3_CFG_ECD3_BFSW_CNT                                          (1U)
#define CSL_MPU_ECD3_CFG_LSE_CNT                                                (1U)
#define CSL_MPU_ECD3_CFG_ECD3_IPGW_CNT                                          (1U)
#define CSL_MPU_IVAHD_SYSCTRL_CNT                                               (1U)
#define CSL_MPU_ICONT1_SB_SYNCBOXGEN_CNT                                        (1U)
#define CSL_MPU_ICONT1_MMR_ICONT_CFGREG_CNT                                     (1U)
#define CSL_MPU_ICONT1_MMR_ICONT_IRQREG_CNT                                     (1U)
#define CSL_MPU_ICONT1_MMR_ICONT_DMREG_CNT                                      (1U)
#define CSL_MPU_ICONT1_MMR_ICONT_SBHREG_CNT                                     (1U)
#define CSL_MPU_ICONT2_MMR_ICONT_CFGREG_CNT                                     (1U)
#define CSL_MPU_ICONT2_MMR_ICONT_IRQREG_CNT                                     (1U)
#define CSL_MPU_ICONT2_MMR_ICONT_DMREG_CNT                                      (1U)
#define CSL_MPU_ICONT2_MMR_ICONT_SBHREG_CNT                                     (1U)
#define CSL_MPU_SL2_MEM_CNT                                                     (1U)
#define CSL_MPU_SPARE_IVA2_SL2IF_DUMMY_CNT                                      (1U)
#define CSL_MPU_QSPI_ADDRSP1_DUMMY_CNT                                          (1U)
#define CSL_MPU_TILER_CNT                                                       (1U)
#define CSL_MPU_EMIF1_SDRAM_CS0_DUMMY_CNT                                       (1U)
#define CSL_MPU_EMIF2_SDRAM_CS0_DUMMY_CNT                                       (1U)
#define CSL_MPU_EMIF2_SDRAM_CS1_DUMMY_CNT                                       (1U)
#define CSL_MPU_EMIF1_SDRAM_CS1_DUMMY_CNT                                       (1U)

#ifdef __cplusplus
}
#endif
#endif /* CSLR_SOC_MPU_BASEADDRESS_H */
